from __future__ import absolute_import, division, print_function
from numpy import array, float64

SPACE_GROUP_INFO = {   1: {   'bravais_lattice': 'aP',
           'crystal_system': 'triclinic',
           'pointgroup': '1'},
    2: {   'bravais_lattice': 'aP',
           'crystal_system': 'triclinic',
           'pointgroup': '-1'},
    3: {   'bravais_lattice': 'mP',
           'crystal_system': 'monoclinic',
           'pointgroup': '2'},
    4: {   'bravais_lattice': 'mP',
           'crystal_system': 'monoclinic',
           'pointgroup': '2'},
    5: {   'bravais_lattice': 'mC',
           'crystal_system': 'monoclinic',
           'pointgroup': '2'},
    6: {   'bravais_lattice': 'mP',
           'crystal_system': 'monoclinic',
           'pointgroup': 'm'},
    7: {   'bravais_lattice': 'mP',
           'crystal_system': 'monoclinic',
           'pointgroup': 'm'},
    8: {   'bravais_lattice': 'mC',
           'crystal_system': 'monoclinic',
           'pointgroup': 'm'},
    9: {   'bravais_lattice': 'mC',
           'crystal_system': 'monoclinic',
           'pointgroup': 'm'},
    10: {   'bravais_lattice': 'mP',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    11: {   'bravais_lattice': 'mP',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    12: {   'bravais_lattice': 'mC',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    13: {   'bravais_lattice': 'mP',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    14: {   'bravais_lattice': 'mP',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    15: {   'bravais_lattice': 'mC',
            'crystal_system': 'monoclinic',
            'pointgroup': '2/m'},
    16: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    17: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    18: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    19: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    20: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    21: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    22: {   'bravais_lattice': 'oF',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    23: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    24: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': '222'},
    25: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    26: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    27: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    28: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    29: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    30: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    31: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    32: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    33: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    34: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    35: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    36: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    37: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    38: {   'bravais_lattice': 'oA',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    39: {   'bravais_lattice': 'oA',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    40: {   'bravais_lattice': 'oA',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    41: {   'bravais_lattice': 'oA',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    42: {   'bravais_lattice': 'oF',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    43: {   'bravais_lattice': 'oF',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    44: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    45: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    46: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mm2'},
    47: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    48: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    49: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    50: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    51: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    52: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    53: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    54: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    55: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    56: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    57: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    58: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    59: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    60: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    61: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    62: {   'bravais_lattice': 'oP',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    63: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    64: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    65: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    66: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    67: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    68: {   'bravais_lattice': 'oB',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    69: {   'bravais_lattice': 'oF',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    70: {   'bravais_lattice': 'oF',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    71: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    72: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    73: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    74: {   'bravais_lattice': 'oI',
            'crystal_system': 'orthorhombic',
            'pointgroup': 'mmm'},
    75: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    76: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    77: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    78: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    79: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    80: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '4'},
    81: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '-4'},
    82: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '-4'},
    83: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    84: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    85: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    86: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    87: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    88: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '4/m'},
    89: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    90: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    91: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    92: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    93: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    94: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    95: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    96: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    97: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    98: {   'bravais_lattice': 'tI',
            'crystal_system': 'tetragonal',
            'pointgroup': '422'},
    99: {   'bravais_lattice': 'tP',
            'crystal_system': 'tetragonal',
            'pointgroup': '4mm'},
    100: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    101: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    102: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    103: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    104: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    105: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    106: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    107: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    108: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    109: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    110: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4mm'},
    111: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    112: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    113: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    114: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    115: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    116: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    117: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    118: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    119: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    120: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    121: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    122: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '-42m'},
    123: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    124: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    125: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    126: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    127: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    128: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    129: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    130: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    131: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    132: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    133: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    134: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    135: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    136: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    137: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    138: {   'bravais_lattice': 'tP',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    139: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    140: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    141: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    142: {   'bravais_lattice': 'tI',
             'crystal_system': 'tetragonal',
             'pointgroup': '4/mmm'},
    143: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3'},
    144: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3'},
    145: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3'},
    146: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '3'},
    147: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '-3'},
    148: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '-3'},
    149: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    150: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    151: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    152: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    153: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    154: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    155: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '32'},
    156: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    157: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    158: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    159: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    160: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    161: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '3m'},
    162: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    163: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    164: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    165: {   'bravais_lattice': 'hP',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    166: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    167: {   'bravais_lattice': 'hR',
             'crystal_system': 'trigonal',
             'pointgroup': '-3m'},
    168: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    169: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    170: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    171: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    172: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    173: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6'},
    174: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '-6'},
    175: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/m'},
    176: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/m'},
    177: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    178: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    179: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    180: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    181: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    182: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '622'},
    183: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6mm'},
    184: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6mm'},
    185: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6mm'},
    186: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6mm'},
    187: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '-6m2'},
    188: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '-6m2'},
    189: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '-6m2'},
    190: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '-6m2'},
    191: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/mmm'},
    192: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/mmm'},
    193: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/mmm'},
    194: {   'bravais_lattice': 'hP',
             'crystal_system': 'hexagonal',
             'pointgroup': '6/mmm'},
    195: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '23'},
    196: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': '23'},
    197: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '23'},
    198: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '23'},
    199: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '23'},
    200: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    201: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    202: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    203: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    204: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    205: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    206: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3'},
    207: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    208: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    209: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    210: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    211: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    212: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    213: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    214: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '432'},
    215: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    216: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    217: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    218: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    219: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    220: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': '-43m'},
    221: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    222: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    223: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    224: {   'bravais_lattice': 'cP',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    225: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    226: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    227: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    228: {   'bravais_lattice': 'cF',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    229: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'},
    230: {   'bravais_lattice': 'cI',
             'crystal_system': 'cubic',
             'pointgroup': 'm-3m'}}

WYCKOFF_SETS = {
    1: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    2: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    3: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', 'y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    4: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y+1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    5: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    6: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['x', '-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    7: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['x', '-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    8: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "b": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['x', '-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    9: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['x', '-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    10: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "l": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', 'y', '1/2'], ['1/2', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z'], ['-x', '-y', '-z'], ['x', '-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    11: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x', '1/4', 'z'], ['-x', '3/4', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y+1/2', '-z'], ['-x', '-y', '-z'], ['x', '-y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    12: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', '1/2'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z'], ['-x', '-y', '-z'], ['x', '-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    13: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "f": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', 'y', '1/4'], ['1/2', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z+1/2'], ['-x', '-y', '-z'], ['x', '-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    14: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x', '-y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    15: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', '1/2'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', 'y', '-z+1/2'], ['-x', '-y', '-z'], ['x', '-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    16: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "o": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "p": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', 'y', '1/2'], ['1/2', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "q": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "r": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "s": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "t": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "translations": array([]),
        "u": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
    },
    17: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "d": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', 'y', '1/4'], ['1/2', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    18: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    19: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    20: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    21: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "k": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '1/4', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    22: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '1/4', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.  , 0.25]]),
            "expressions": [['1/4', 'y', '1/4'], ['3/4', '-y', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    23: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    24: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.25, 0.  , 0.5 ]]),
            "expressions": [['1/4', 'y', '0'], ['1/4', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ]]),
            "expressions": [['0', '1/4', 'z'], ['0', '3/4', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    25: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    26: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    27: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    28: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', 'y', 'z'], ['3/4', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y', 'z'], ['-x+1/2', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    29: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['x+1/2', '-y', 'z'], ['-x+1/2', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    30: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y+1/2', 'z+1/2'], ['-x', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    31: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', 'y', 'z'], ['1/2', '-y', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['x+1/2', '-y', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    32: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    33: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    34: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    35: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['1/4', '3/4', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    36: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    37: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['1/4', '1/4', 'z'], ['1/4', '3/4', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    38: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5]]),
    },
    39: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x', '1/4', 'z'], ['-x', '3/4', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y+1/2', 'z'], ['-x', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5]]),
    },
    40: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', 'y', 'z'], ['3/4', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y', 'z'], ['-x+1/2', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5]]),
    },
    41: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5]]),
    },
    42: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['1/4', '3/4', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    43: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.25, 0.25, 0.25]]),
            "expressions": [['0', '0', 'z'], ['1/4', '1/4', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.25, 0.25, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/4', '-y+1/4', 'z+1/4'], ['-x+1/4', 'y+1/4', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
    },
    44: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    45: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    46: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', 'y', 'z'], ['3/4', '-y', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['x+1/2', '-y', 'z'], ['-x+1/2', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    47: {
        "A": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "o": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "p": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', 'y', '1/2'], ['1/2', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "q": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "r": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "s": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "t": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "translations": array([]),
        "u": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "v": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z'], ['1/2', 'y', '-z'], ['1/2', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "w": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['-x', '0', '-z'], ['x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "x": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z'], ['-x', '1/2', '-z'], ['x', '1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "y": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '0'], ['x', '-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "z": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-x', 'y', '1/2'], ['x', '-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
    },
    48: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.5 ], [ 0.25, 0.5 , 0.5 ]]),
            "expressions": [['x+3/4', '0', '0'], ['-x+1/4', '0', '0'], ['-x+3/4', '1/2', '1/2'], ['x+1/4', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['x+3/4', '0', '1/2'], ['-x+1/4', '0', '1/2'], ['-x+3/4', '1/2', '0'], ['x+1/4', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.25, 0.5 ]]),
            "expressions": [['0', 'y+3/4', '0'], ['0', '-y+1/4', '0'], ['1/2', '-y+3/4', '1/2'], ['1/2', 'y+1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.25, 0.5 ]]),
            "expressions": [['1/2', 'y+3/4', '0'], ['1/2', '-y+1/4', '0'], ['0', '-y+3/4', '1/2'], ['0', 'y+1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z+3/4'], ['0', '0', '-z+1/4'], ['1/2', '1/2', '-z+3/4'], ['1/2', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', 'z+3/4'], ['0', '1/2', '-z+1/4'], ['1/2', '0', '-z+3/4'], ['1/2', '0', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "m": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['x+3/4', 'y+3/4', 'z+3/4'], ['-x+1/4', '-y+1/4', 'z+3/4'], ['-x+1/4', 'y+3/4', '-z+1/4'], ['x+3/4', '-y+1/4', '-z+1/4'], ['-x+3/4', '-y+3/4', '-z+3/4'], ['x+1/4', 'y+1/4', '-z+3/4'], ['x+1/4', '-y+3/4', 'z+1/4'], ['-x+3/4', 'y+1/4', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    49: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "i": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['-x', '0', '3/4'], ['x', '0', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['x', '1/2', '1/4'], ['-x', '1/2', '1/4'], ['-x', '1/2', '3/4'], ['x', '1/2', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '1/4'], ['0', '-y', '3/4'], ['0', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "l": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', 'y', '1/4'], ['1/2', '-y', '1/4'], ['1/2', '-y', '3/4'], ['1/2', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "n": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "o": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z+1/2'], ['0', '1/2', '-z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "p": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '0', '-z+1/2'], ['1/2', '0', '-z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "q": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '1/2'], ['x', '-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "r": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    50: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['3/4', '3/4', '0'], ['1/4', '1/4', '0'], ['1/4', '3/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['3/4', '3/4', '1/2'], ['1/4', '1/4', '1/2'], ['1/4', '3/4', '1/2'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['x+3/4', '0', '0'], ['-x+1/4', '0', '0'], ['-x+3/4', '1/2', '0'], ['x+1/4', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.25, 0.5 , 0.5 ]]),
            "expressions": [['x+3/4', '0', '1/2'], ['-x+1/4', '0', '1/2'], ['-x+3/4', '1/2', '1/2'], ['x+1/4', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ]]),
            "expressions": [['0', 'y+3/4', '0'], ['0', '-y+1/4', '0'], ['1/2', '-y+3/4', '0'], ['1/2', 'y+1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.  , 0.75, 0.5 ], [ 0.  , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.25, 0.5 ]]),
            "expressions": [['0', 'y+3/4', '1/2'], ['0', '-y+1/4', '1/2'], ['1/2', '-y+3/4', '1/2'], ['1/2', 'y+1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', '-z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "m": {
            "constants": array([[ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['x+3/4', 'y+3/4', 'z'], ['-x+1/4', '-y+1/4', 'z'], ['-x+1/4', 'y+3/4', '-z'], ['x+3/4', '-y+1/4', '-z'], ['-x+3/4', '-y+3/4', '-z'], ['x+1/4', 'y+1/4', '-z'], ['x+1/4', '-y+3/4', 'z'], ['-x+3/4', 'y+1/4', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    51: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', '0', 'z'], ['3/4', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ]]),
            "expressions": [['1/4', '1/2', 'z'], ['3/4', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', 'y', '0'], ['1/2', '-y', '0'], ['0', '-y', '0'], ['1/2', 'y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['1/2', '-y', '1/2'], ['0', '-y', '1/2'], ['1/2', 'y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '0', 'z'], ['-x+1/2', '0', 'z'], ['-x', '0', '-z'], ['x+1/2', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x+1/2', '1/2', 'z'], ['-x', '1/2', '-z'], ['x+1/2', '1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', 'y', 'z'], ['1/4', '-y', 'z'], ['3/4', 'y', '-z'], ['3/4', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z'], ['-x', 'y', '-z'], ['x+1/2', '-y', '-z'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z'], ['x', '-y', 'z'], ['-x+1/2', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    52: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '0'], ['1/2', '1/2', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.25, 0.5 , 0.5 ], [ 0.75, 0.  , 0.  ], [ 0.75, 0.5 , 0.5 ]]),
            "expressions": [['1/4', '0', 'z'], ['1/4', '1/2', '-z+1/2'], ['3/4', '0', '-z'], ['3/4', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.5 , 0.75, 0.25], [ 0.  , 0.75, 0.75], [ 0.5 , 0.25, 0.75]]),
            "expressions": [['x', '1/4', '1/4'], ['-x+1/2', '3/4', '1/4'], ['-x', '3/4', '3/4'], ['x+1/2', '1/4', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x', '-y+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    53: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x+1/2', '0', '1/2'], ['-x', '0', '0'], ['x+1/2', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x+1/2', '1/2', '1/2'], ['-x', '1/2', '0'], ['x+1/2', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.75, 0.  , 0.75], [ 0.75, 0.  , 0.25]]),
            "expressions": [['1/4', 'y', '1/4'], ['1/4', '-y', '3/4'], ['3/4', '-y', '3/4'], ['3/4', 'y', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', 'y', 'z'], ['1/2', '-y', 'z+1/2'], ['1/2', 'y', '-z+1/2'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x+1/2', 'y', '-z+1/2'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x+1/2', '-y', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    54: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '0'], ['0', '0', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['1/2', '-y', '1/4'], ['0', '-y', '3/4'], ['1/2', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.5 ]]),
            "expressions": [['1/4', '0', 'z'], ['3/4', '0', '-z+1/2'], ['3/4', '0', '-z'], ['1/4', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.5 ]]),
            "expressions": [['1/4', '1/2', 'z'], ['3/4', '1/2', '-z+1/2'], ['3/4', '1/2', '-z'], ['1/4', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z'], ['-x', 'y', '-z+1/2'], ['x+1/2', '-y', '-z+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z'], ['x', '-y', 'z+1/2'], ['-x+1/2', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    55: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x+1/2', 'y+1/2', '0'], ['x+1/2', '-y+1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-x+1/2', 'y+1/2', '1/2'], ['x+1/2', '-y+1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    56: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2'], ['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '3/4', '-z+1/2'], ['3/4', '3/4', '-z'], ['1/4', '1/4', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['1/4', '3/4', 'z'], ['3/4', '1/4', '-z+1/2'], ['3/4', '1/4', '-z'], ['1/4', '3/4', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y', '-z+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y+1/2', '-z'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    57: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2'], ['0', '1/2', '1/2'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '0', '1/2'], ['1/2', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.5 ]]),
            "expressions": [['x', '1/4', '0'], ['-x', '3/4', '1/2'], ['-x', '3/4', '0'], ['x', '1/4', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-x', '-y', '3/4'], ['-x', 'y+1/2', '1/4'], ['x', '-y+1/2', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    58: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x+1/2', 'y+1/2', '1/2'], ['x+1/2', '-y+1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    59: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['3/4', '3/4', '0'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0'], ['1/4', '3/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['3/4', '3/4', '1/2'], ['1/4', '1/4', '1/2'], ['3/4', '1/4', '1/2'], ['1/4', '3/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ]]),
            "expressions": [['0', 'y+3/4', 'z'], ['0', '-y+1/4', 'z'], ['1/2', 'y+1/4', '-z'], ['1/2', '-y+3/4', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "f": {
            "constants": array([[ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['x+3/4', '0', 'z'], ['-x+1/4', '0', 'z'], ['-x+3/4', '1/2', '-z'], ['x+1/4', '1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "g": {
            "constants": array([[ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x+3/4', 'y+3/4', 'z'], ['-x+1/4', '-y+1/4', 'z'], ['-x+3/4', 'y+1/4', '-z'], ['x+1/4', '-y+3/4', '-z'], ['-x+3/4', '-y+3/4', '-z'], ['x+1/4', 'y+1/4', '-z'], ['x+3/4', '-y+1/4', 'z'], ['-x+1/4', 'y+3/4', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    60: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2'], ['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['0', 'y', '1/4'], ['1/2', '-y+1/2', '3/4'], ['0', '-y', '3/4'], ['1/2', 'y+1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z+1/2'], ['-x', 'y', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x+1/2', 'y+1/2', '-z+1/2'], ['x', '-y', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    61: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    62: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '0', '0'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.5 , 0.75, 0.5 ], [ 0.  , 0.75, 0.  ], [ 0.5 , 0.25, 0.5 ]]),
            "expressions": [['x', '1/4', 'z'], ['-x+1/2', '3/4', 'z+1/2'], ['-x', '3/4', '-z'], ['x+1/2', '1/4', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    63: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "d": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '3/4', '1/2'], ['3/4', '1/4', '1/2'], ['1/4', '3/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '1/2'], ['-x', '0', '0'], ['x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z+1/2'], ['0', 'y', '-z+1/2'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-x', '-y', '3/4'], ['-x', 'y', '1/4'], ['x', '-y', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z+1/2'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    64: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '1/2'], ['3/4', '3/4', '1/2'], ['1/4', '3/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '1/2', '1/2'], ['-x', '0', '0'], ['x', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.5 , 0.75], [ 0.75, 0.  , 0.75], [ 0.25, 0.5 , 0.25]]),
            "expressions": [['1/4', 'y', '1/4'], ['3/4', '-y+1/2', '3/4'], ['3/4', '-y', '3/4'], ['1/4', 'y+1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y+1/2', 'z+1/2'], ['0', 'y+1/2', '-z+1/2'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y+1/2', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y+1/2', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    65: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', '1/2'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "m": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '1/4', '-z'], ['3/4', '3/4', '-z'], ['1/4', '3/4', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['-x', '0', '-z'], ['x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "p": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '0'], ['x', '-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "q": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-x', 'y', '1/2'], ['x', '-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "r": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    66: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.75, 0.5 ]]),
            "expressions": [['1/4', '3/4', '0'], ['3/4', '3/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['-x', '0', '3/4'], ['x', '0', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '1/4'], ['0', '-y', '3/4'], ['0', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', '-z+1/2'], ['0', '1/2', '-z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "k": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '1/4', '-z+1/2'], ['3/4', '3/4', '-z'], ['1/4', '3/4', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '1/2'], ['x', '-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    67: {
        "a": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ]]),
            "expressions": [['1/4', '0', '0'], ['3/4', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['1/4', '1/4', '1/2'], ['3/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['0', '1/4', 'z'], ['0', '3/4', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '0', '0'], ['-x', '1/2', '0'], ['-x', '0', '0'], ['x', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '1/2', '1/2'], ['-x', '0', '1/2'], ['x', '1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['1/4', 'y', '0'], ['3/4', '-y+1/2', '0'], ['3/4', '-y', '0'], ['1/4', 'y+1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.5 , 0.5 ]]),
            "expressions": [['1/4', 'y', '1/2'], ['3/4', '-y+1/2', '1/2'], ['3/4', '-y', '1/2'], ['1/4', 'y+1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "l": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['1/4', '0', 'z'], ['3/4', '1/2', '-z'], ['3/4', '0', '-z'], ['1/4', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y+1/2', 'z'], ['0', 'y+1/2', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "n": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x', '1/4', 'z'], ['-x', '1/4', 'z'], ['-x', '3/4', '-z'], ['x', '3/4', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y+1/2', 'z'], ['-x', 'y+1/2', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y+1/2', '-z'], ['x', '-y+1/2', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    68: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.5 , 0.75], [ 0.25, 0.  , 0.75], [ 0.75, 0.5 , 0.25], [ 0.75, 0.  , 0.25]]),
            "expressions": [['1/4', '1/2', '3/4'], ['1/4', '0', '3/4'], ['3/4', '1/2', '1/4'], ['3/4', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.75, 0.75], [ 0.5 , 0.75, 0.75], [ 0.  , 0.75, 0.25], [ 0.5 , 0.75, 0.25]]),
            "expressions": [['0', '3/4', '3/4'], ['1/2', '3/4', '3/4'], ['0', '3/4', '1/4'], ['1/2', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x+1/2', '1/2', '0'], ['-x', '1/2', '1/2'], ['x+1/2', '0', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.75, 0.5 ]]),
            "expressions": [['0', 'y+3/4', '0'], ['1/2', '-y+3/4', '0'], ['0', '-y+3/4', '1/2'], ['1/2', 'y+3/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z+3/4'], ['0', '0', '-z+1/4'], ['0', '1/2', '-z+3/4'], ['0', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/4', '3/4', 'z+3/4'], ['3/4', '3/4', '-z+1/4'], ['3/4', '3/4', '-z+3/4'], ['1/4', '3/4', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.  , 0.75, 0.75], [ 0.5 , 0.75, 0.75], [ 0.  , 0.75, 0.25], [ 0.5 , 0.75, 0.25], [ 0.  , 0.75, 0.75], [ 0.5 , 0.75, 0.75], [ 0.  , 0.75, 0.25], [ 0.5 , 0.75, 0.25]]),
            "expressions": [['x', 'y+3/4', 'z+3/4'], ['-x+1/2', '-y+3/4', 'z+3/4'], ['-x', 'y+3/4', '-z+1/4'], ['x+1/2', '-y+3/4', '-z+1/4'], ['-x', '-y+3/4', '-z+3/4'], ['x+1/2', 'y+3/4', '-z+3/4'], ['x', '-y+3/4', 'z+1/4'], ['-x+1/2', 'y+3/4', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0. ]]),
    },
    69: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.  , 0.25]]),
            "expressions": [['1/4', '0', '1/4'], ['3/4', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', 'z'], ['3/4', '1/4', '-z'], ['3/4', '3/4', '-z'], ['1/4', '3/4', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "k": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.  , 0.25], [ 0.75, 0.  , 0.75], [ 0.25, 0.  , 0.75]]),
            "expressions": [['1/4', 'y', '1/4'], ['3/4', '-y', '1/4'], ['3/4', '-y', '3/4'], ['1/4', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "l": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.  , 0.75, 0.75], [ 0.  , 0.25, 0.75]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['-x', '3/4', '3/4'], ['x', '1/4', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['-x', '0', '-z'], ['x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '0'], ['x', '-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "p": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    70: {
        "a": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.  , 0.  , 0.  ]]),
            "expressions": [['1/4', '1/4', '1/4'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.75], [ 0.  , 0.  , 0.5 ]]),
            "expressions": [['1/4', '1/4', '3/4'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875]]),
            "expressions": [['1/8', '1/8', '1/8'], ['7/8', '7/8', '1/8'], ['7/8', '1/8', '7/8'], ['1/8', '7/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.375, 0.375, 0.625], [ 0.375, 0.625, 0.375], [ 0.625, 0.375, 0.375]]),
            "expressions": [['5/8', '5/8', '5/8'], ['3/8', '3/8', '5/8'], ['3/8', '5/8', '3/8'], ['5/8', '3/8', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.125, 0.25 , 0.25 ], [ 0.875, 0.75 , 0.25 ], [ 0.125, 0.   , 0.   ], [ 0.375, 0.5  , 0.   ]]),
            "expressions": [['x+1/8', '1/4', '1/4'], ['-x+7/8', '3/4', '1/4'], ['-x+1/8', '0', '0'], ['x+3/8', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.25 , 0.125, 0.25 ], [ 0.75 , 0.875, 0.25 ], [ 0.   , 0.125, 0.   ], [ 0.5  , 0.375, 0.   ]]),
            "expressions": [['1/4', 'y+1/8', '1/4'], ['3/4', '-y+7/8', '1/4'], ['0', '-y+1/8', '0'], ['1/2', 'y+3/8', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "g": {
            "constants": array([[ 0.25 , 0.25 , 0.125], [ 0.75 , 0.25 , 0.875], [ 0.   , 0.   , 0.125], [ 0.5  , 0.   , 0.375]]),
            "expressions": [['1/4', '1/4', 'z+1/8'], ['3/4', '1/4', '-z+7/8'], ['0', '0', '-z+1/8'], ['1/2', '0', 'z+3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.375, 0.125], [ 0.375, 0.125, 0.375], [ 0.125, 0.375, 0.375]]),
            "expressions": [['x+1/8', 'y+1/8', 'z+1/8'], ['-x+7/8', '-y+7/8', 'z+1/8'], ['-x+7/8', 'y+1/8', '-z+7/8'], ['x+1/8', '-y+7/8', '-z+7/8'], ['-x+1/8', '-y+1/8', '-z+1/8'], ['x+3/8', 'y+3/8', '-z+1/8'], ['x+3/8', '-y+1/8', 'z+3/8'], ['-x+1/8', 'y+3/8', 'z+3/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    71: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', '1/2'], ['0', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "k": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['-x', '0', '-z'], ['x', '0', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x', 'y', '0'], ['x', '-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    72: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['1/4', '3/4', '3/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['-x', '0', '3/4'], ['x', '0', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '1/4'], ['0', '-y', '3/4'], ['0', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-x+1/2', 'y+1/2', '0'], ['x+1/2', '-y+1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    73: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['1/4', '3/4', '3/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['-x', '0', '3/4'], ['x+1/2', '0', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.  ], [ 0.75, 0.  , 0.5 ]]),
            "expressions": [['1/4', 'y', '0'], ['1/4', '-y', '1/2'], ['3/4', '-y', '0'], ['3/4', 'y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "e": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.5 ]]),
            "expressions": [['0', '1/4', 'z'], ['0', '3/4', '-z+1/2'], ['0', '3/4', '-z'], ['0', '1/4', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    74: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '3/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['0', '1/4', 'z'], ['0', '3/4', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '0', '0'], ['-x', '1/2', '0'], ['-x', '0', '0'], ['x', '1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.5 , 0.25], [ 0.75, 0.  , 0.75], [ 0.25, 0.5 , 0.75]]),
            "expressions": [['1/4', 'y', '1/4'], ['3/4', '-y+1/2', '1/4'], ['3/4', '-y', '3/4'], ['1/4', 'y+1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y+1/2', 'z'], ['0', 'y+1/2', '-z'], ['0', '-y', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "i": {
            "constants": array([[ 0.  , 0.25, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x', '1/4', 'z'], ['-x', '1/4', 'z'], ['-x', '3/4', '-z'], ['x', '3/4', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y+1/2', 'z'], ['-x', 'y+1/2', '-z'], ['x', '-y', '-z'], ['-x', '-y', '-z'], ['x', 'y+1/2', '-z'], ['x', '-y+1/2', 'z'], ['-x', 'y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    75: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    76: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y', 'x', 'z+1/4'], ['y', '-x', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    77: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    78: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y', 'x', 'z+3/4'], ['y', '-x', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    79: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    80: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z+1/2'], ['-y', 'x+1/2', 'z+1/4'], ['y+1/2', '-x', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    81: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    82: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    83: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-y', 'x', '1/2'], ['y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    84: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '1/2'], ['y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z+1/2'], ['-y', 'x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    85: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '0'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ]]),
            "expressions": [['1/4', '3/4', '0'], ['3/4', '1/4', '0'], ['3/4', '3/4', '0'], ['1/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['1/4', '3/4', '1/2'], ['3/4', '1/4', '1/2'], ['3/4', '3/4', '1/2'], ['1/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ]]),
            "expressions": [['x+1/4', 'y+3/4', 'z'], ['-x+3/4', '-y+1/4', 'z'], ['-y+3/4', 'x+3/4', 'z'], ['y+1/4', '-x+1/4', 'z'], ['-x+1/4', '-y+3/4', '-z'], ['x+3/4', 'y+1/4', '-z'], ['y+3/4', '-x+3/4', '-z'], ['-y+1/4', 'x+1/4', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    86: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['1/4', '3/4', '3/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '3/4'], ['3/4', '3/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', 'z+1/4'], ['0', '1/2', 'z+3/4'], ['1/2', '0', '-z+1/4'], ['1/2', '0', '-z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', 'z+1/4'], ['0', '0', 'z+3/4'], ['0', '0', '-z+1/4'], ['1/2', '1/2', '-z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['x+1/4', 'y+1/4', 'z+1/4'], ['-x+3/4', '-y+3/4', 'z+1/4'], ['-y+1/4', 'x+3/4', 'z+3/4'], ['y+3/4', '-x+1/4', 'z+3/4'], ['-x+1/4', '-y+1/4', '-z+1/4'], ['x+3/4', 'y+3/4', '-z+1/4'], ['y+1/4', '-x+3/4', '-z+3/4'], ['-y+3/4', 'x+1/4', '-z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    87: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    88: {
        "a": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.5 , 0.75], [ 0.5 , 0.5 , 0.  ]]),
            "expressions": [['0', '1/2', '3/4'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.   , 0.25 , 0.125], [ 0.5  , 0.25 , 0.625], [ 0.75 , 0.5  , 0.375], [ 0.75 , 0.   , 0.875]]),
            "expressions": [['0', '1/4', '1/8'], ['1/2', '1/4', '5/8'], ['3/4', '1/2', '3/8'], ['3/4', '0', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.   , 0.25 , 0.625], [ 0.5  , 0.25 , 0.125], [ 0.75 , 0.5  , 0.875], [ 0.75 , 0.   , 0.375]]),
            "expressions": [['0', '1/4', '5/8'], ['1/2', '1/4', '1/8'], ['3/4', '1/2', '7/8'], ['3/4', '0', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.   , 0.5  , 0.125], [ 0.5  , 0.5  , 0.375], [ 0.   , 0.   , 0.125], [ 0.5  , 0.   , 0.875]]),
            "expressions": [['0', '1/2', 'z+1/8'], ['1/2', '1/2', 'z+3/8'], ['0', '0', '-z+1/8'], ['1/2', '0', '-z+7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.   , 0.25 , 0.125], [ 0.5  , 0.25 , 0.625], [ 0.75 , 0.5  , 0.375], [ 0.75 , 0.   , 0.875], [ 0.   , 0.25 , 0.125], [ 0.5  , 0.25 , 0.625], [ 0.25 , 0.   , 0.875], [ 0.25 , 0.5  , 0.375]]),
            "expressions": [['x', 'y+1/4', 'z+1/8'], ['-x+1/2', '-y+1/4', 'z+5/8'], ['-y+3/4', 'x+1/2', 'z+3/8'], ['y+3/4', '-x', 'z+7/8'], ['-x', '-y+1/4', '-z+1/8'], ['x+1/2', 'y+1/4', '-z+5/8'], ['y+1/4', '-x', '-z+7/8'], ['-y+1/4', 'x+1/2', '-z+3/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    89: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x', 'x', '0'], ['x', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', 'x', '1/2'], ['x', '-x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', 'x', '1/2'], ['0', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "o": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', 'x', '0'], ['1/2', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "p": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    90: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x+1/2', 'x+1/2', '0'], ['x+1/2', '-x+1/2', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x+1/2', 'x+1/2', '1/2'], ['x+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y+1/2', 'x+1/2', 'z'], ['y+1/2', '-x+1/2', 'z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    91: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '1/2'], ['-y', '0', '1/4'], ['y', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "b": {
            "constants": array([[ 0.5 , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '1/2'], ['-y', '1/2', '1/4'], ['y', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0.   , 0.   , 0.375], [ 0.   , 0.   , 0.875], [ 0.   , 0.   , 0.625], [ 0.   , 0.   , 0.125]]),
            "expressions": [['x', 'x', '3/8'], ['-x', '-x', '7/8'], ['-x', 'x', '5/8'], ['x', '-x', '1/8']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y', 'x', 'z+1/4'], ['y', '-x', 'z+3/4'], ['-x', 'y', '-z'], ['x', '-y', '-z+1/2'], ['y', 'x', '-z+3/4'], ['-y', '-x', '-z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    92: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '1/2'], ['-x+1/2', 'x+1/2', '1/4'], ['x+1/2', '-x+1/2', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y+1/2', 'x+1/2', 'z+1/4'], ['y+1/2', '-x+1/2', 'z+3/4'], ['-x+1/2', 'y+1/2', '-z+1/4'], ['x+1/2', '-y+1/2', '-z+3/4'], ['y', 'x', '-z'], ['-y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    93: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', 'x', '3/4'], ['x', '-x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "o": {
            "constants": array([[ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'x', '3/4'], ['-x', '-x', '3/4'], ['-x', 'x', '1/4'], ['x', '-x', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "p": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    94: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', '-z+1/2'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x+1/2', 'x+1/2', '1/2'], ['x+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x+1/2', 'x+1/2', '0'], ['x+1/2', '-x+1/2', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z+1/2'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    95: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25]]),
            "expressions": [['0', 'y', '0'], ['0', '-y', '1/2'], ['-y', '0', '3/4'], ['y', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "b": {
            "constants": array([[ 0.5 , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/2', 'y', '0'], ['1/2', '-y', '1/2'], ['-y', '1/2', '3/4'], ['y', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "c": {
            "constants": array([[ 0.   , 0.   , 0.625], [ 0.   , 0.   , 0.125], [ 0.   , 0.   , 0.375], [ 0.   , 0.   , 0.875]]),
            "expressions": [['x', 'x', '5/8'], ['-x', '-x', '1/8'], ['-x', 'x', '3/8'], ['x', '-x', '7/8']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y', 'x', 'z+3/4'], ['y', '-x', 'z+1/4'], ['-x', 'y', '-z'], ['x', '-y', '-z+1/2'], ['y', 'x', '-z+1/4'], ['-y', '-x', '-z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    96: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '1/2'], ['-x+1/2', 'x+1/2', '3/4'], ['x+1/2', '-x+1/2', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.5 ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z+1/2'], ['-y+1/2', 'x+1/2', 'z+3/4'], ['y+1/2', '-x+1/2', 'z+1/4'], ['-x+1/2', 'y+1/2', '-z+3/4'], ['x+1/2', '-y+1/2', '-z+1/4'], ['y', 'x', '-z'], ['-y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    97: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x', 'x', '0'], ['x', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', 'x', '1/2'], ['0', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['-x+1/2', 'x', '1/4'], ['x+1/2', '-x', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    98: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '0', '0'], ['0', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.5 ], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z+1/4'], ['1/2', '0', '-z+3/4'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'x', '0'], ['-x+1/2', '-x+1/2', '1/2'], ['-x', 'x+1/2', '1/4'], ['x+1/2', '-x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['-x', 'x', '0'], ['x+1/2', '-x+1/2', '1/2'], ['-x', '-x+1/2', '1/4'], ['x+1/2', 'x', '3/4']],
            "matrices": array([[[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.   , 0.25 , 0.125], [ 0.5  , 0.25 , 0.625], [ 0.75 , 0.5  , 0.375], [ 0.75 , 0.   , 0.875]]),
            "expressions": [['x', '1/4', '1/8'], ['-x+1/2', '1/4', '5/8'], ['3/4', 'x+1/2', '3/8'], ['3/4', '-x', '7/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z+1/2'], ['-y', 'x+1/2', 'z+1/4'], ['y+1/2', '-x', 'z+3/4'], ['-x+1/2', 'y', '-z+3/4'], ['x', '-y+1/2', '-z+1/4'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    99: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z'], ['x', '-x', 'z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', 'x', 'z'], ['0', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z'], ['1/2', 'x', 'z'], ['1/2', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    100: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', 'z'], ['-x', '-x+1/2', 'z'], ['-x+1/2', 'x', 'z'], ['x+1/2', '-x', 'z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z'], ['-y+1/2', '-x+1/2', 'z'], ['y+1/2', 'x+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    101: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z+1/2'], ['x', '-x', 'z+1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    102: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z+1/2'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x+1/2', 'x+1/2', 'z+1/2'], ['x+1/2', '-x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    103: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    104: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    105: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', 'x', 'z+1/2'], ['0', '-x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z'], ['1/2', 'x', 'z+1/2'], ['1/2', '-x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    106: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['1/2', '0', 'z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    107: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z'], ['x', '-x', 'z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', 'x', 'z'], ['0', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    108: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', 'z'], ['-x', '-x+1/2', 'z'], ['-x+1/2', 'x', 'z'], ['x+1/2', '-x', 'z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    109: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', 'y', 'z'], ['1/2', '-y+1/2', 'z+1/2'], ['-y', '1/2', 'z+1/4'], ['y+1/2', '0', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'z'},
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z+1/2'], ['-y', 'x+1/2', 'z+1/4'], ['y+1/2', '-x', 'z+3/4'], ['x', '-y', 'z'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['-y', '-x+1/2', 'z+1/4'], ['y+1/2', 'x', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    110: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.  , 0.5 ], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '0', 'z'], ['0', '1/2', 'z+1/4'], ['0', '0', 'z+1/2'], ['0', '1/2', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.  , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y+1/2', 'z+1/2'], ['-y', 'x+1/2', 'z+1/4'], ['y+1/2', '-x', 'z+3/4'], ['x', '-y', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z'], ['-y', '-x+1/2', 'z+3/4'], ['y+1/2', 'x', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    111: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['0', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', '-x', '1/2'], ['1/2', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['0', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', '-x', '0'], ['1/2', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['x', '-x', '-z'], ['-x', 'x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    112: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['0', '-x', '3/4'], ['0', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', 'y', '1/4'], ['1/2', '-y', '1/4'], ['y', '1/2', '3/4'], ['-y', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', '1/2', '1/4'], ['-x', '1/2', '1/4'], ['1/2', '-x', '3/4'], ['1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', 'y', '1/4'], ['0', '-y', '1/4'], ['y', '0', '3/4'], ['-y', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['0', '0', '-z+1/2'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z'], ['1/2', '1/2', '-z+1/2'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "m": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z+1/2'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    113: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', '-z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', 'z'], ['-x', '-x+1/2', 'z'], ['x+1/2', '-x', '-z'], ['-x+1/2', 'x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['-y+1/2', '-x+1/2', 'z'], ['y+1/2', 'x+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    114: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', '-z+1/2'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['1/2', '0', '-z+1/2'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    115: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['x', '-x', '0'], ['-x', 'x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['x', '-x', '1/2'], ['-x', 'x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', '-x', '-z'], ['0', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z'], ['1/2', '-x', '-z'], ['1/2', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    116: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['x', '-x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'x', '3/4'], ['-x', '-x', '3/4'], ['x', '-x', '1/4'], ['-x', 'x', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['0', '0', 'z+1/2'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    117: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['1/2', '0', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', '0'], ['-x', '-x+1/2', '0'], ['x+1/2', '-x', '0'], ['-x+1/2', 'x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'x+1/2', '1/2'], ['-x', '-x+1/2', '1/2'], ['x+1/2', '-x', '1/2'], ['-x+1/2', 'x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z'], ['y+1/2', 'x+1/2', '-z'], ['-y+1/2', '-x+1/2', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    118: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '3/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', '-x+1/2', '1/4'], ['-x', 'x+1/2', '1/4'], ['-x+1/2', '-x', '3/4'], ['x+1/2', 'x', '3/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['x+1/2', '-x', '3/4'], ['-x+1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    119: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.5 , 0.25]]),
            "expressions": [['0', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['x', '-x', '0'], ['-x', 'x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['x+1/2', '-x', '3/4'], ['-x+1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', '-x', '-z'], ['0', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['y', 'x', '-z'], ['-y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    120: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['x', '-x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['0', '0', 'z+1/2'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', '0'], ['-x', '-x+1/2', '0'], ['x+1/2', '-x', '0'], ['-x+1/2', 'x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    121: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['0', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['0', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['x', '-x', '-z'], ['-x', 'x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    122: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.5 ], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z'], ['1/2', '0', '-z+3/4'], ['1/2', '0', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.125], [ 0.25 , 0.   , 0.875], [ 0.75 , 0.   , 0.875]]),
            "expressions": [['x', '1/4', '1/8'], ['-x', '3/4', '1/8'], ['1/4', '-x', '7/8'], ['3/4', 'x', '7/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['-x+1/2', 'y', '-z+3/4'], ['x+1/2', '-y', '-z+3/4'], ['-y+1/2', '-x', 'z+3/4'], ['y+1/2', 'x', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    123: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x', 'x', '0'], ['x', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', 'x', '1/2'], ['x', '-x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', 'x', '1/2'], ['0', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', 'x', '0'], ['1/2', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "o": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "p": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x', 'y', '0'], ['x', '-y', '0'], ['y', 'x', '0'], ['-y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "q": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-y', 'x', '1/2'], ['y', '-x', '1/2'], ['-x', 'y', '1/2'], ['x', '-y', '1/2'], ['y', 'x', '1/2'], ['-y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "r": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z'], ['x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['x', 'x', '-z'], ['-x', '-x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "s": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['-x', '0', 'z'], ['0', 'x', 'z'], ['0', '-x', 'z'], ['-x', '0', '-z'], ['x', '0', '-z'], ['0', 'x', '-z'], ['0', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "t": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', 'z'], ['-x', '1/2', 'z'], ['1/2', 'x', 'z'], ['1/2', '-x', 'z'], ['-x', '1/2', '-z'], ['x', '1/2', '-z'], ['1/2', 'x', '-z'], ['1/2', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "translations": array([]),
        "u": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
    },
    124: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4'], ['0', '1/2', '3/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z+1/2'], ['1/2', '0', '-z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', 'x', '1/4'], ['x', '-x', '1/4'], ['-x', '-x', '3/4'], ['x', 'x', '3/4'], ['x', '-x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['0', 'x', '1/4'], ['0', '-x', '1/4'], ['-x', '0', '3/4'], ['x', '0', '3/4'], ['0', '-x', '3/4'], ['0', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', '1/2', '1/4'], ['-x', '1/2', '1/4'], ['1/2', 'x', '1/4'], ['1/2', '-x', '1/4'], ['-x', '1/2', '3/4'], ['x', '1/2', '3/4'], ['1/2', '-x', '3/4'], ['1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x', 'y', '1/2'], ['x', '-y', '1/2'], ['y', 'x', '1/2'], ['-y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    125: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '0'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['1/4', '1/4', '0'], ['3/4', '3/4', '0'], ['3/4', '1/4', '0'], ['1/4', '3/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['1/4', '1/4', '1/2'], ['3/4', '3/4', '1/2'], ['3/4', '1/4', '1/2'], ['1/4', '3/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z'], ['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x+1/4', 'x+1/4', '0'], ['-x+3/4', '-x+3/4', '0'], ['-x+3/4', 'x+1/4', '0'], ['x+1/4', '-x+3/4', '0'], ['-x+1/4', '-x+1/4', '0'], ['x+3/4', 'x+3/4', '0'], ['x+3/4', '-x+1/4', '0'], ['-x+1/4', 'x+3/4', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['x+1/4', 'x+1/4', '1/2'], ['-x+3/4', '-x+3/4', '1/2'], ['-x+3/4', 'x+1/4', '1/2'], ['x+1/4', '-x+3/4', '1/2'], ['-x+1/4', '-x+1/4', '1/2'], ['x+3/4', 'x+3/4', '1/2'], ['x+3/4', '-x+1/4', '1/2'], ['-x+1/4', 'x+3/4', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x+1/4', '1/2', '0'], ['-x+3/4', '1/2', '0'], ['1/2', 'x+1/4', '0'], ['1/2', '-x+3/4', '0'], ['-x+1/4', '0', '0'], ['x+3/4', '0', '0'], ['0', '-x+1/4', '0'], ['0', 'x+3/4', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ]]),
            "expressions": [['x+1/4', '1/2', '1/2'], ['-x+3/4', '1/2', '1/2'], ['1/2', 'x+1/4', '1/2'], ['1/2', '-x+3/4', '1/2'], ['-x+1/4', '0', '1/2'], ['x+3/4', '0', '1/2'], ['0', '-x+1/4', '1/2'], ['0', 'x+3/4', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ]]),
            "expressions": [['x+1/4', '-x+1/4', 'z'], ['-x+3/4', 'x+3/4', 'z'], ['x+3/4', 'x+1/4', 'z'], ['-x+1/4', '-x+3/4', 'z'], ['-x+3/4', '-x+1/4', '-z'], ['x+1/4', 'x+3/4', '-z'], ['-x+1/4', 'x+1/4', '-z'], ['x+3/4', '-x+3/4', '-z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ]]),
            "expressions": [['x+1/4', 'y+1/4', 'z'], ['-x+3/4', '-y+3/4', 'z'], ['-y+3/4', 'x+1/4', 'z'], ['y+1/4', '-x+3/4', 'z'], ['-x+3/4', 'y+1/4', '-z'], ['x+1/4', '-y+3/4', '-z'], ['y+1/4', 'x+1/4', '-z'], ['-y+3/4', '-x+3/4', '-z'], ['-x+1/4', '-y+1/4', '-z'], ['x+3/4', 'y+3/4', '-z'], ['y+3/4', '-x+1/4', '-z'], ['-y+1/4', 'x+3/4', '-z'], ['x+3/4', '-y+1/4', 'z'], ['-x+1/4', 'y+3/4', 'z'], ['-y+1/4', '-x+1/4', 'z'], ['y+3/4', 'x+3/4', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    126: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['0', '1/2', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['1/2', '1/2', 'z+1/4'], ['1/2', '1/2', '-z+3/4'], ['0', '0', '-z+1/4'], ['0', '0', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/2', '0', 'z+1/4'], ['0', '1/2', 'z+1/4'], ['1/2', '0', '-z+3/4'], ['0', '1/2', '-z+3/4'], ['0', '1/2', '-z+1/4'], ['1/2', '0', '-z+1/4'], ['0', '1/2', 'z+3/4'], ['1/2', '0', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x+1/4', 'x+1/4', '1/2'], ['-x+3/4', '-x+3/4', '1/2'], ['-x+3/4', 'x+1/4', '1/2'], ['x+1/4', '-x+3/4', '1/2'], ['-x+1/4', '-x+1/4', '0'], ['x+3/4', 'x+3/4', '0'], ['x+3/4', '-x+1/4', '0'], ['-x+1/4', 'x+3/4', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ]]),
            "expressions": [['x+1/4', '1/2', '1/2'], ['-x+3/4', '1/2', '1/2'], ['1/2', 'x+1/4', '1/2'], ['1/2', '-x+3/4', '1/2'], ['-x+1/4', '0', '0'], ['x+3/4', '0', '0'], ['0', '-x+1/4', '0'], ['0', 'x+3/4', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ]]),
            "expressions": [['x+1/4', '0', '1/2'], ['-x+3/4', '0', '1/2'], ['0', 'x+1/4', '1/2'], ['0', '-x+3/4', '1/2'], ['-x+1/4', '1/2', '0'], ['x+3/4', '1/2', '0'], ['1/2', '-x+1/4', '0'], ['1/2', 'x+3/4', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75]]),
            "expressions": [['x+1/4', 'y+1/4', 'z+1/4'], ['-x+3/4', '-y+3/4', 'z+1/4'], ['-y+3/4', 'x+1/4', 'z+1/4'], ['y+1/4', '-x+3/4', 'z+1/4'], ['-x+3/4', 'y+1/4', '-z+3/4'], ['x+1/4', '-y+3/4', '-z+3/4'], ['y+1/4', 'x+1/4', '-z+3/4'], ['-y+3/4', '-x+3/4', '-z+3/4'], ['-x+1/4', '-y+1/4', '-z+1/4'], ['x+3/4', 'y+3/4', '-z+1/4'], ['y+3/4', '-x+1/4', '-z+1/4'], ['-y+1/4', 'x+3/4', '-z+1/4'], ['x+3/4', '-y+1/4', 'z+3/4'], ['-x+1/4', 'y+3/4', 'z+3/4'], ['-y+1/4', '-x+1/4', 'z+3/4'], ['y+3/4', 'x+3/4', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    127: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', '0'], ['-x', '-x+1/2', '0'], ['-x+1/2', 'x', '0'], ['x+1/2', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'x+1/2', '1/2'], ['-x', '-x+1/2', '1/2'], ['-x+1/2', 'x', '1/2'], ['x+1/2', '-x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x+1/2', 'y+1/2', '0'], ['x+1/2', '-y+1/2', '0'], ['y+1/2', 'x+1/2', '0'], ['-y+1/2', '-x+1/2', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-x', '-y', '1/2'], ['-y', 'x', '1/2'], ['y', '-x', '1/2'], ['-x+1/2', 'y+1/2', '1/2'], ['x+1/2', '-y+1/2', '1/2'], ['y+1/2', 'x+1/2', '1/2'], ['-y+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', 'x+1/2', 'z'], ['-x', '-x+1/2', 'z'], ['-x+1/2', 'x', 'z'], ['x+1/2', '-x', 'z'], ['-x+1/2', 'x', '-z'], ['x+1/2', '-x', '-z'], ['x', 'x+1/2', '-z'], ['-x', '-x+1/2', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['y+1/2', 'x+1/2', '-z'], ['-y+1/2', '-x+1/2', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z'], ['-y+1/2', '-x+1/2', 'z'], ['y+1/2', 'x+1/2', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    128: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4'], ['0', '1/2', '3/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['1/2', '0', '-z+1/2'], ['0', '1/2', '-z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['-x+1/2', 'x', '1/4'], ['x+1/2', '-x', '1/4'], ['-x', '-x+1/2', '3/4'], ['x', 'x+1/2', '3/4'], ['x+1/2', '-x', '3/4'], ['-x+1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x+1/2', 'y+1/2', '1/2'], ['x+1/2', '-y+1/2', '1/2'], ['y+1/2', 'x+1/2', '1/2'], ['-y+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z+1/2'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    129: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ]]),
            "expressions": [['1/4', '3/4', '0'], ['3/4', '1/4', '0'], ['3/4', '3/4', '0'], ['1/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['1/4', '3/4', '1/2'], ['3/4', '1/4', '1/2'], ['3/4', '3/4', '1/2'], ['1/4', '1/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z'], ['1/2', '1/2', '-z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ]]),
            "expressions": [['x+1/4', '-x+3/4', '0'], ['-x+3/4', 'x+1/4', '0'], ['x+3/4', 'x+3/4', '0'], ['-x+1/4', '-x+1/4', '0'], ['-x+1/4', 'x+3/4', '0'], ['x+3/4', '-x+1/4', '0'], ['-x+3/4', '-x+3/4', '0'], ['x+1/4', 'x+1/4', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['x+1/4', '-x+3/4', '1/2'], ['-x+3/4', 'x+1/4', '1/2'], ['x+3/4', 'x+3/4', '1/2'], ['-x+1/4', '-x+1/4', '1/2'], ['-x+1/4', 'x+3/4', '1/2'], ['x+3/4', '-x+1/4', '1/2'], ['-x+3/4', '-x+3/4', '1/2'], ['x+1/4', 'x+1/4', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ]]),
            "expressions": [['1/2', 'y+3/4', 'z'], ['1/2', '-y+1/4', 'z'], ['-y+3/4', '0', 'z'], ['y+1/4', '0', 'z'], ['0', 'y+1/4', '-z'], ['0', '-y+3/4', '-z'], ['y+3/4', '1/2', '-z'], ['-y+1/4', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "j": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x+1/4', 'x+3/4', 'z'], ['-x+3/4', '-x+1/4', 'z'], ['-x+3/4', 'x+3/4', 'z'], ['x+1/4', '-x+1/4', 'z'], ['-x+1/4', 'x+1/4', '-z'], ['x+3/4', '-x+3/4', '-z'], ['x+3/4', 'x+1/4', '-z'], ['-x+1/4', '-x+3/4', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x+1/4', 'y+3/4', 'z'], ['-x+3/4', '-y+1/4', 'z'], ['-y+3/4', 'x+3/4', 'z'], ['y+1/4', '-x+1/4', 'z'], ['-x+1/4', 'y+1/4', '-z'], ['x+3/4', '-y+3/4', '-z'], ['y+3/4', 'x+1/4', '-z'], ['-y+1/4', '-x+3/4', '-z'], ['-x+1/4', '-y+3/4', '-z'], ['x+3/4', 'y+1/4', '-z'], ['y+3/4', '-x+3/4', '-z'], ['-y+1/4', 'x+1/4', '-z'], ['x+1/4', '-y+1/4', 'z'], ['-x+3/4', 'y+3/4', 'z'], ['-y+3/4', '-x+1/4', 'z'], ['y+1/4', 'x+3/4', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    130: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '0'], ['1/2', '1/2', '1/2'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', '-z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['1/4', '3/4', '0'], ['3/4', '1/4', '0'], ['3/4', '3/4', '0'], ['1/4', '1/4', '0'], ['1/4', '1/4', '1/2'], ['3/4', '3/4', '1/2'], ['3/4', '1/4', '1/2'], ['1/4', '3/4', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z+1/2'], ['1/2', '1/2', '-z'], ['0', '0', '-z'], ['0', '0', 'z+1/2'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75]]),
            "expressions": [['x+1/4', '-x+3/4', '1/4'], ['-x+3/4', 'x+1/4', '1/4'], ['x+3/4', 'x+3/4', '1/4'], ['-x+1/4', '-x+1/4', '1/4'], ['-x+1/4', 'x+3/4', '3/4'], ['x+3/4', '-x+1/4', '3/4'], ['-x+3/4', '-x+3/4', '3/4'], ['x+1/4', 'x+1/4', '3/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ]]),
            "expressions": [['x+1/4', 'y+3/4', 'z'], ['-x+3/4', '-y+1/4', 'z'], ['-y+3/4', 'x+3/4', 'z'], ['y+1/4', '-x+1/4', 'z'], ['-x+1/4', 'y+1/4', '-z+1/2'], ['x+3/4', '-y+3/4', '-z+1/2'], ['y+3/4', 'x+1/4', '-z+1/2'], ['-y+1/4', '-x+3/4', '-z+1/2'], ['-x+1/4', '-y+3/4', '-z'], ['x+3/4', 'y+1/4', '-z'], ['y+3/4', '-x+3/4', '-z'], ['-y+1/4', 'x+1/4', '-z'], ['x+1/4', '-y+1/4', 'z+1/2'], ['-x+3/4', 'y+3/4', 'z+1/2'], ['-y+3/4', '-x+1/4', 'z+1/2'], ['y+1/4', 'x+3/4', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    131: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', 'x', '3/4'], ['x', '-x', '3/4'], ['-x', '-x', '3/4'], ['x', 'x', '3/4'], ['x', '-x', '1/4'], ['-x', 'x', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "o": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['-y', '0', 'z+1/2'], ['y', '0', 'z+1/2'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['y', '0', '-z+1/2'], ['-y', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "p": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z'], ['-y', '1/2', 'z+1/2'], ['y', '1/2', 'z+1/2'], ['1/2', 'y', '-z'], ['1/2', '-y', '-z'], ['y', '1/2', '-z+1/2'], ['-y', '1/2', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "q": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '1/2'], ['y', '-x', '1/2'], ['-x', 'y', '0'], ['x', '-y', '0'], ['y', 'x', '1/2'], ['-y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "r": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z+1/2'], ['-y', 'x', '-z+1/2'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    132: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '1/2', '1/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '3/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z+1/2'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z+1/2'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x', 'x', '1/2'], ['x', '-x', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', 'x', '0'], ['x', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['0', '1/2', '-z+1/2'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '0', '-z+1/2'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "l": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['0', 'x', '3/4'], ['0', '-x', '3/4'], ['-x', '0', '3/4'], ['x', '0', '3/4'], ['0', '-x', '1/4'], ['0', 'x', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['x', '1/2', '1/4'], ['-x', '1/2', '1/4'], ['1/2', 'x', '3/4'], ['1/2', '-x', '3/4'], ['-x', '1/2', '3/4'], ['x', '1/2', '3/4'], ['1/2', '-x', '1/4'], ['1/2', 'x', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '1/2'], ['y', '-x', '1/2'], ['-x', 'y', '1/2'], ['x', '-y', '1/2'], ['y', 'x', '0'], ['-y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "o": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z+1/2'], ['x', '-x', 'z+1/2'], ['-x', 'x', '-z+1/2'], ['x', '-x', '-z+1/2'], ['x', 'x', '-z'], ['-x', '-x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "p": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z+1/2'], ['-y', 'x', '-z+1/2'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    133: {
        "a": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['1/2', '1/2', '3/4'], ['1/2', '1/2', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2'], ['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['3/4', '3/4', '1/4'], ['1/4', '1/4', '1/4'], ['1/4', '3/4', '3/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', 'z+1/4'], ['1/2', '0', 'z+3/4'], ['1/2', '0', '-z+1/4'], ['1/2', '0', '-z+3/4'], ['0', '1/2', '-z+1/4'], ['0', '1/2', '-z+3/4'], ['0', '1/2', 'z+1/4'], ['0', '1/2', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', 'z+1/4'], ['1/2', '1/2', 'z+3/4'], ['0', '0', '-z+1/4'], ['1/2', '1/2', '-z+3/4'], ['1/2', '1/2', '-z+1/4'], ['0', '0', '-z+3/4'], ['1/2', '1/2', 'z+1/4'], ['0', '0', 'z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.25, 0.  , 0.25], [ 0.75, 0.  , 0.25], [ 0.5 , 0.75, 0.75], [ 0.5 , 0.25, 0.75], [ 0.25, 0.5 , 0.25], [ 0.75, 0.5 , 0.25], [ 0.  , 0.75, 0.75], [ 0.  , 0.25, 0.75]]),
            "expressions": [['x+1/4', '0', '1/4'], ['-x+3/4', '0', '1/4'], ['1/2', 'x+3/4', '3/4'], ['1/2', '-x+1/4', '3/4'], ['-x+1/4', '1/2', '1/4'], ['x+3/4', '1/2', '1/4'], ['0', '-x+3/4', '3/4'], ['0', 'x+1/4', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.25, 0.  , 0.75], [ 0.75, 0.  , 0.75], [ 0.5 , 0.75, 0.25], [ 0.5 , 0.25, 0.25], [ 0.25, 0.5 , 0.75], [ 0.75, 0.5 , 0.75], [ 0.  , 0.75, 0.25], [ 0.  , 0.25, 0.25]]),
            "expressions": [['x+1/4', '0', '3/4'], ['-x+3/4', '0', '3/4'], ['1/2', 'x+3/4', '1/4'], ['1/2', '-x+1/4', '1/4'], ['-x+1/4', '1/2', '3/4'], ['x+3/4', '1/2', '3/4'], ['0', '-x+3/4', '1/4'], ['0', 'x+1/4', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['x+1/4', 'x+3/4', '1/2'], ['-x+3/4', '-x+1/4', '1/2'], ['-x+3/4', 'x+3/4', '0'], ['x+1/4', '-x+1/4', '0'], ['-x+1/4', '-x+3/4', '0'], ['x+3/4', 'x+1/4', '0'], ['x+3/4', '-x+3/4', '1/2'], ['-x+1/4', 'x+1/4', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75]]),
            "expressions": [['x+1/4', 'y+3/4', 'z+1/4'], ['-x+3/4', '-y+1/4', 'z+1/4'], ['-y+3/4', 'x+3/4', 'z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-x+3/4', 'y+3/4', '-z+1/4'], ['x+1/4', '-y+1/4', '-z+1/4'], ['y+1/4', 'x+3/4', '-z+3/4'], ['-y+3/4', '-x+1/4', '-z+3/4'], ['-x+1/4', '-y+3/4', '-z+1/4'], ['x+3/4', 'y+1/4', '-z+1/4'], ['y+3/4', '-x+3/4', '-z+3/4'], ['-y+1/4', 'x+1/4', '-z+3/4'], ['x+3/4', '-y+3/4', 'z+1/4'], ['-x+1/4', 'y+1/4', 'z+1/4'], ['-y+1/4', '-x+3/4', 'z+3/4'], ['y+3/4', 'x+1/4', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    134: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['1/4', '3/4', '3/4'], ['3/4', '1/4', '3/4'], ['3/4', '3/4', '1/4'], ['1/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75]]),
            "expressions": [['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z+1/4'], ['1/2', '1/2', 'z+3/4'], ['0', '0', '-z+3/4'], ['1/2', '1/2', '-z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/2', '0', 'z+1/4'], ['1/2', '0', 'z+3/4'], ['1/2', '0', '-z+3/4'], ['1/2', '0', '-z+1/4'], ['0', '1/2', '-z+1/4'], ['0', '1/2', '-z+3/4'], ['0', '1/2', 'z+3/4'], ['0', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ]]),
            "expressions": [['x+1/4', '0', '0'], ['-x+3/4', '0', '0'], ['1/2', 'x+3/4', '1/2'], ['1/2', '-x+1/4', '1/2'], ['-x+1/4', '1/2', '1/2'], ['x+3/4', '1/2', '1/2'], ['0', '-x+3/4', '0'], ['0', 'x+1/4', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.25, 0.5 ]]),
            "expressions": [['x+1/4', '0', '1/2'], ['-x+3/4', '0', '1/2'], ['1/2', 'x+3/4', '0'], ['1/2', '-x+1/4', '0'], ['-x+1/4', '1/2', '0'], ['x+3/4', '1/2', '0'], ['0', '-x+3/4', '1/2'], ['0', 'x+1/4', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75]]),
            "expressions": [['x+1/4', 'x+3/4', '1/4'], ['-x+3/4', '-x+1/4', '1/4'], ['-x+3/4', 'x+3/4', '3/4'], ['x+1/4', '-x+1/4', '3/4'], ['-x+1/4', '-x+3/4', '1/4'], ['x+3/4', 'x+1/4', '1/4'], ['x+3/4', '-x+3/4', '3/4'], ['-x+1/4', 'x+1/4', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x+1/4', 'x+3/4', '3/4'], ['-x+3/4', '-x+1/4', '3/4'], ['-x+3/4', 'x+3/4', '1/4'], ['x+1/4', '-x+1/4', '1/4'], ['-x+1/4', '-x+3/4', '3/4'], ['x+3/4', 'x+1/4', '3/4'], ['x+3/4', '-x+3/4', '1/4'], ['-x+1/4', 'x+1/4', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['x+1/4', '-x+3/4', 'z+1/4'], ['-x+3/4', 'x+1/4', 'z+1/4'], ['x+3/4', 'x+3/4', 'z+3/4'], ['-x+1/4', '-x+1/4', 'z+3/4'], ['-x+3/4', '-x+3/4', '-z+3/4'], ['x+1/4', 'x+1/4', '-z+3/4'], ['-x+1/4', 'x+3/4', '-z+1/4'], ['x+3/4', '-x+1/4', '-z+1/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['x+1/4', 'y+3/4', 'z+1/4'], ['-x+3/4', '-y+1/4', 'z+1/4'], ['-y+3/4', 'x+3/4', 'z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-x+3/4', 'y+3/4', '-z+3/4'], ['x+1/4', '-y+1/4', '-z+3/4'], ['y+1/4', 'x+3/4', '-z+1/4'], ['-y+3/4', '-x+1/4', '-z+1/4'], ['-x+1/4', '-y+3/4', '-z+1/4'], ['x+3/4', 'y+1/4', '-z+1/4'], ['y+3/4', '-x+3/4', '-z+3/4'], ['-y+1/4', 'x+1/4', '-z+3/4'], ['x+3/4', '-y+3/4', 'z+3/4'], ['-x+1/4', 'y+1/4', 'z+3/4'], ['-y+1/4', '-x+3/4', 'z+1/4'], ['y+3/4', 'x+1/4', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    135: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2'], ['1/2', '1/2', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4'], ['1/2', '1/2', '3/4'], ['1/2', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '1/2'], ['1/2', '0', '0'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '3/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['1/2', '1/2', '-z'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2'], ['1/2', '1/2', 'z'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z+1/2'], ['1/2', '0', '-z'], ['0', '1/2', '-z+1/2'], ['0', '1/2', '-z'], ['1/2', '0', '-z+1/2'], ['1/2', '0', 'z'], ['0', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['-x+1/2', 'x', '3/4'], ['x+1/2', '-x', '3/4'], ['-x', '-x+1/2', '3/4'], ['x', 'x+1/2', '3/4'], ['x+1/2', '-x', '1/4'], ['-x+1/2', 'x', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '1/2'], ['y', '-x', '1/2'], ['-x+1/2', 'y+1/2', '0'], ['x+1/2', '-y+1/2', '0'], ['y+1/2', 'x+1/2', '1/2'], ['-y+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z+1/2'], ['y', '-x', 'z+1/2'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y+1/2', '-z'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z+1/2'], ['-y', 'x', '-z+1/2'], ['x+1/2', '-y+1/2', 'z'], ['-x+1/2', 'y+1/2', 'z'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    136: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['0', '1/2', '1/4'], ['0', '1/2', '3/4'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['1/2', '1/2', 'z+1/2'], ['1/2', '1/2', '-z+1/2'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x+1/2', 'x+1/2', '1/2'], ['x+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '-x', '0'], ['-x', 'x', '0'], ['x+1/2', 'x+1/2', '1/2'], ['-x+1/2', '-x+1/2', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', '-z+1/2'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['0', '1/2', '-z+1/2'], ['1/2', '0', 'z+1/2'], ['1/2', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y+1/2', 'x+1/2', '1/2'], ['y+1/2', '-x+1/2', '1/2'], ['-x+1/2', 'y+1/2', '1/2'], ['x+1/2', '-y+1/2', '1/2'], ['y', 'x', '0'], ['-y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x+1/2', 'x+1/2', 'z+1/2'], ['x+1/2', '-x+1/2', 'z+1/2'], ['-x+1/2', 'x+1/2', '-z+1/2'], ['x+1/2', '-x+1/2', '-z+1/2'], ['x', 'x', '-z'], ['-x', '-x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z+1/2'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y+1/2', '-x+1/2', '-z+1/2'], ['-y+1/2', 'x+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z+1/2'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    137: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', 'z+1/4'], ['1/2', '1/2', 'z+3/4'], ['1/2', '1/2', '-z+1/4'], ['0', '0', '-z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', 'z+1/4'], ['1/2', '0', 'z+3/4'], ['0', '1/2', '-z+1/4'], ['0', '1/2', '-z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.75, 0.75, 0.  ], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ]]),
            "expressions": [['x+1/4', '-x+3/4', '1/2'], ['-x+3/4', 'x+1/4', '1/2'], ['x+3/4', 'x+3/4', '0'], ['-x+1/4', '-x+1/4', '0'], ['-x+1/4', 'x+3/4', '0'], ['x+3/4', '-x+1/4', '0'], ['-x+3/4', '-x+3/4', '1/2'], ['x+1/4', 'x+1/4', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.5 , 0.75, 0.25], [ 0.5 , 0.25, 0.25], [ 0.75, 0.  , 0.75], [ 0.25, 0.  , 0.75], [ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.75, 0.5 , 0.75], [ 0.25, 0.5 , 0.75]]),
            "expressions": [['1/2', 'y+3/4', 'z+1/4'], ['1/2', '-y+1/4', 'z+1/4'], ['-y+3/4', '0', 'z+3/4'], ['y+1/4', '0', 'z+3/4'], ['0', 'y+1/4', '-z+1/4'], ['0', '-y+3/4', '-z+1/4'], ['y+3/4', '1/2', '-z+3/4'], ['-y+1/4', '1/2', '-z+3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "h": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['x+1/4', 'y+3/4', 'z+1/4'], ['-x+3/4', '-y+1/4', 'z+1/4'], ['-y+3/4', 'x+3/4', 'z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-x+1/4', 'y+1/4', '-z+1/4'], ['x+3/4', '-y+3/4', '-z+1/4'], ['y+3/4', 'x+1/4', '-z+3/4'], ['-y+1/4', '-x+3/4', '-z+3/4'], ['-x+1/4', '-y+3/4', '-z+1/4'], ['x+3/4', 'y+1/4', '-z+1/4'], ['y+3/4', '-x+3/4', '-z+3/4'], ['-y+1/4', 'x+1/4', '-z+3/4'], ['x+1/4', '-y+1/4', 'z+1/4'], ['-x+3/4', 'y+3/4', 'z+1/4'], ['-y+3/4', '-x+1/4', 'z+3/4'], ['y+1/4', 'x+3/4', 'z+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    138: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['1/2', '1/2', '3/4'], ['1/2', '1/2', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2'], ['1/2', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['1/4', '3/4', '3/4'], ['3/4', '1/4', '3/4'], ['3/4', '3/4', '1/4'], ['1/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75]]),
            "expressions": [['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/2', '0', 'z+1/4'], ['1/2', '0', 'z+3/4'], ['0', '1/2', '-z+3/4'], ['0', '1/2', '-z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['0', '0', 'z+1/4'], ['1/2', '1/2', 'z+3/4'], ['1/2', '1/2', '-z+3/4'], ['0', '0', '-z+1/4'], ['1/2', '1/2', '-z+1/4'], ['0', '0', '-z+3/4'], ['0', '0', 'z+3/4'], ['1/2', '1/2', 'z+1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x+1/4', '-x+3/4', '3/4'], ['-x+3/4', 'x+1/4', '3/4'], ['x+3/4', 'x+3/4', '1/4'], ['-x+1/4', '-x+1/4', '1/4'], ['-x+1/4', 'x+3/4', '3/4'], ['x+3/4', '-x+1/4', '3/4'], ['-x+3/4', '-x+3/4', '1/4'], ['x+1/4', 'x+1/4', '1/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75]]),
            "expressions": [['x+1/4', '-x+3/4', '1/4'], ['-x+3/4', 'x+1/4', '1/4'], ['x+3/4', 'x+3/4', '3/4'], ['-x+1/4', '-x+1/4', '3/4'], ['-x+1/4', 'x+3/4', '1/4'], ['x+3/4', '-x+1/4', '1/4'], ['-x+3/4', '-x+3/4', '3/4'], ['x+1/4', 'x+1/4', '3/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25]]),
            "expressions": [['x+1/4', 'x+3/4', 'z+1/4'], ['-x+3/4', '-x+1/4', 'z+1/4'], ['-x+3/4', 'x+3/4', 'z+3/4'], ['x+1/4', '-x+1/4', 'z+3/4'], ['-x+1/4', 'x+1/4', '-z+3/4'], ['x+3/4', '-x+3/4', '-z+3/4'], ['x+3/4', 'x+1/4', '-z+1/4'], ['-x+1/4', '-x+3/4', '-z+1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25]]),
            "expressions": [['x+1/4', 'y+3/4', 'z+1/4'], ['-x+3/4', '-y+1/4', 'z+1/4'], ['-y+3/4', 'x+3/4', 'z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-x+1/4', 'y+1/4', '-z+3/4'], ['x+3/4', '-y+3/4', '-z+3/4'], ['y+3/4', 'x+1/4', '-z+1/4'], ['-y+1/4', '-x+3/4', '-z+1/4'], ['-x+1/4', '-y+3/4', '-z+1/4'], ['x+3/4', 'y+1/4', '-z+1/4'], ['y+3/4', '-x+3/4', '-z+3/4'], ['-y+1/4', 'x+1/4', '-z+3/4'], ['x+1/4', '-y+1/4', 'z+3/4'], ['-x+3/4', 'y+3/4', 'z+3/4'], ['-y+3/4', '-x+1/4', 'z+1/4'], ['y+1/4', 'x+3/4', 'z+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    139: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', '0'], ['-x', '-x', '0'], ['-x', 'x', '0'], ['x', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', 'x', '0'], ['1/2', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x', 'x+1/2', '1/4'], ['-x', '-x+1/2', '1/4'], ['-x+1/2', 'x', '1/4'], ['x+1/2', '-x', '1/4'], ['-x', '-x+1/2', '3/4'], ['x', 'x+1/2', '3/4'], ['x+1/2', '-x', '3/4'], ['-x+1/2', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x', 'y', '0'], ['x', '-y', '0'], ['y', 'x', '0'], ['-y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', 'z'], ['x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['x', 'x', '-z'], ['-x', '-x', '-z']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['-y', '0', 'z'], ['y', '0', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['y', '0', '-z'], ['-y', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-y', '-x', 'z'], ['y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    140: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['0', '1/2', '0'], ['1/2', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '1/4'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['0', '1/2', 'z'], ['1/2', '0', 'z'], ['0', '1/2', '-z+1/2'], ['1/2', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', 'x+1/2', '0'], ['-x', '-x+1/2', '0'], ['-x+1/2', 'x', '0'], ['x+1/2', '-x', '0']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', 'x', '1/4'], ['x', '-x', '1/4'], ['-x', '-x', '3/4'], ['x', 'x', '3/4'], ['x', '-x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x', '0', '1/4'], ['0', 'x', '1/4'], ['0', '-x', '1/4'], ['-x', '0', '3/4'], ['x', '0', '3/4'], ['0', '-x', '3/4'], ['0', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-x', '-y', '0'], ['-y', 'x', '0'], ['y', '-x', '0'], ['-x', 'y', '1/2'], ['x', '-y', '1/2'], ['y', 'x', '1/2'], ['-y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'x+1/2', 'z'], ['-x', '-x+1/2', 'z'], ['-x+1/2', 'x', 'z'], ['x+1/2', '-x', 'z'], ['-x', 'x+1/2', '-z+1/2'], ['x', '-x+1/2', '-z+1/2'], ['x+1/2', 'x', '-z+1/2'], ['-x+1/2', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-y', 'x', 'z'], ['y', '-x', 'z'], ['-x', 'y', '-z+1/2'], ['x', '-y', '-z+1/2'], ['y', 'x', '-z+1/2'], ['-y', '-x', '-z+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', '-y', 'z+1/2'], ['-x', 'y', 'z+1/2'], ['-y', '-x', 'z+1/2'], ['y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    141: {
        "a": {
            "constants": array([[ 0.  , 0.5 , 0.25], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['0', '1/2', '1/4'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.5 ], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875]]),
            "expressions": [['0', '3/4', '1/8'], ['1/2', '3/4', '5/8'], ['1/4', '1/2', '3/8'], ['1/4', '0', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.   , 0.75 , 0.625], [ 0.5  , 0.75 , 0.125], [ 0.25 , 0.5  , 0.875], [ 0.25 , 0.   , 0.375]]),
            "expressions": [['0', '3/4', '5/8'], ['1/2', '3/4', '1/8'], ['1/4', '1/2', '7/8'], ['1/4', '0', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.   , 0.   , 0.125], [ 0.   , 0.5  , 0.375], [ 0.5  , 0.   , 0.625], [ 0.5  , 0.5  , 0.375]]),
            "expressions": [['0', '0', 'z+1/8'], ['0', '1/2', 'z+3/8'], ['1/2', '0', '-z+5/8'], ['1/2', '1/2', '-z+3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.75 , 0.   , 0.875], [ 0.75 , 0.5  , 0.375]]),
            "expressions": [['x', '3/4', '1/8'], ['-x+1/2', '3/4', '5/8'], ['1/4', 'x+1/2', '3/8'], ['1/4', '-x', '7/8'], ['-x', '3/4', '1/8'], ['x+1/2', '3/4', '5/8'], ['3/4', '-x', '7/8'], ['3/4', 'x+1/2', '3/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['x', 'x', '0'], ['-x+1/2', '-x+1/2', '1/2'], ['-x', 'x+1/2', '1/4'], ['x+1/2', '-x', '3/4'], ['-x', '-x+1/2', '1/4'], ['x+1/2', 'x', '3/4'], ['x', '-x', '0'], ['-x+1/2', 'x+1/2', '1/2']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.5  , 0.75 , 0.625], [ 0.   , 0.75 , 0.125], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875]]),
            "expressions": [['0', 'y+3/4', 'z+1/8'], ['1/2', '-y+3/4', 'z+5/8'], ['-y+1/4', '1/2', 'z+3/8'], ['y+1/4', '0', 'z+7/8'], ['1/2', 'y+3/4', '-z+5/8'], ['0', '-y+3/4', '-z+1/8'], ['y+1/4', '1/2', '-z+3/8'], ['-y+1/4', '0', '-z+7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'z'},
        },
        "i": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.5  , 0.75 , 0.625], [ 0.   , 0.75 , 0.125], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.75 , 0.   , 0.875], [ 0.75 , 0.5  , 0.375], [ 0.5  , 0.75 , 0.625], [ 0.   , 0.75 , 0.125], [ 0.75 , 0.   , 0.875], [ 0.75 , 0.5  , 0.375]]),
            "expressions": [['x', 'y+3/4', 'z+1/8'], ['-x+1/2', '-y+3/4', 'z+5/8'], ['-y+1/4', 'x+1/2', 'z+3/8'], ['y+1/4', '-x', 'z+7/8'], ['-x+1/2', 'y+3/4', '-z+5/8'], ['x', '-y+3/4', '-z+1/8'], ['y+1/4', 'x+1/2', '-z+3/8'], ['-y+1/4', '-x', '-z+7/8'], ['-x', '-y+3/4', '-z+1/8'], ['x+1/2', 'y+3/4', '-z+5/8'], ['y+3/4', '-x', '-z+7/8'], ['-y+3/4', 'x+1/2', '-z+3/8'], ['x+1/2', '-y+3/4', 'z+5/8'], ['-x', 'y+3/4', 'z+1/8'], ['-y+3/4', '-x', 'z+7/8'], ['y+3/4', 'x+1/2', 'z+3/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    142: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.5 ], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['0', '0', '1/2'], ['0', '1/2', '3/4'], ['1/2', '0', '3/4'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.5 , 0.  ], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '1/2', '1/2'], ['0', '1/2', '0'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.5  , 0.75 , 0.125], [ 0.   , 0.75 , 0.625], [ 0.25 , 0.5  , 0.875], [ 0.25 , 0.   , 0.375]]),
            "expressions": [['0', '3/4', '1/8'], ['1/2', '3/4', '5/8'], ['1/4', '1/2', '3/8'], ['1/4', '0', '7/8'], ['1/2', '3/4', '1/8'], ['0', '3/4', '5/8'], ['1/4', '1/2', '7/8'], ['1/4', '0', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.   , 0.   , 0.125], [ 0.   , 0.5  , 0.375], [ 0.5  , 0.   , 0.125], [ 0.5  , 0.5  , 0.875], [ 0.   , 0.5  , 0.125], [ 0.   , 0.   , 0.875], [ 0.5  , 0.5  , 0.125], [ 0.5  , 0.   , 0.375]]),
            "expressions": [['0', '0', 'z+1/8'], ['0', '1/2', 'z+3/8'], ['1/2', '0', '-z+1/8'], ['1/2', '1/2', '-z+7/8'], ['0', '1/2', '-z+1/8'], ['0', '0', '-z+7/8'], ['1/2', '1/2', 'z+1/8'], ['1/2', '0', 'z+3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.   , 0.75 , 0.375], [ 0.5  , 0.75 , 0.875], [ 0.25 , 0.5  , 0.625], [ 0.25 , 0.   , 0.125], [ 0.   , 0.75 , 0.875], [ 0.5  , 0.75 , 0.375], [ 0.75 , 0.   , 0.625], [ 0.75 , 0.5  , 0.125]]),
            "expressions": [['x', '3/4', '3/8'], ['-x+1/2', '3/4', '7/8'], ['1/4', 'x+1/2', '5/8'], ['1/4', '-x', '1/8'], ['-x', '3/4', '7/8'], ['x+1/2', '3/4', '3/8'], ['3/4', '-x', '5/8'], ['3/4', 'x+1/2', '1/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.  , 0.  ], [ 0.  , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.  , 0.75], [ 0.5 , 0.5 , 0.25]]),
            "expressions": [['x', 'x', '1/4'], ['-x+1/2', '-x+1/2', '3/4'], ['-x', 'x+1/2', '1/2'], ['x+1/2', '-x', '0'], ['-x', '-x+1/2', '0'], ['x+1/2', 'x', '1/2'], ['x', '-x', '3/4'], ['-x+1/2', 'x+1/2', '1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.25 , 0.5  , 0.375], [ 0.25 , 0.   , 0.875], [ 0.5  , 0.75 , 0.125], [ 0.   , 0.75 , 0.625], [ 0.25 , 0.5  , 0.875], [ 0.25 , 0.   , 0.375], [ 0.   , 0.75 , 0.125], [ 0.5  , 0.75 , 0.625], [ 0.75 , 0.   , 0.875], [ 0.75 , 0.5  , 0.375], [ 0.5  , 0.75 , 0.125], [ 0.   , 0.75 , 0.625], [ 0.75 , 0.   , 0.375], [ 0.75 , 0.5  , 0.875]]),
            "expressions": [['x', 'y+3/4', 'z+1/8'], ['-x+1/2', '-y+3/4', 'z+5/8'], ['-y+1/4', 'x+1/2', 'z+3/8'], ['y+1/4', '-x', 'z+7/8'], ['-x+1/2', 'y+3/4', '-z+1/8'], ['x', '-y+3/4', '-z+5/8'], ['y+1/4', 'x+1/2', '-z+7/8'], ['-y+1/4', '-x', '-z+3/8'], ['-x', '-y+3/4', '-z+1/8'], ['x+1/2', 'y+3/4', '-z+5/8'], ['y+3/4', '-x', '-z+7/8'], ['-y+3/4', 'x+1/2', '-z+3/8'], ['x+1/2', '-y+3/4', 'z+1/8'], ['-x', 'y+3/4', 'z+5/8'], ['-y+3/4', '-x', 'z+3/8'], ['y+3/4', 'x+1/2', 'z+7/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    143: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    144: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    145: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    146: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    147: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    148: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    149: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', '0'], ['x', '2x', '0'], ['-2x', '-x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', '1/2'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    150: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    151: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', '-x', '1/3'], ['x', '2x', '2/3'], ['-2x', '-x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.5       ]]),
            "expressions": [['x', '-x', '5/6'], ['x', '2x', '1/6'], ['-2x', '-x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['-y', '-x', '-z+2/3'], ['-x+y', 'y', '-z+1/3'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    152: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', '0', '1/3'], ['0', 'x', '2/3'], ['-x', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.5       ]]),
            "expressions": [['x', '0', '5/6'], ['0', 'x', '1/6'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['y', 'x', '-z'], ['x-y', '-y', '-z+2/3'], ['-x', '-x+y', '-z+1/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    153: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', '-x', '2/3'], ['x', '2x', '1/3'], ['-2x', '-x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.5       ]]),
            "expressions": [['x', '-x', '1/6'], ['x', '2x', '5/6'], ['-2x', '-x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['-y', '-x', '-z+1/3'], ['-x+y', 'y', '-z+2/3'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    154: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ]]),
            "expressions": [['x', '0', '2/3'], ['0', 'x', '1/3'], ['-x', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.5       ]]),
            "expressions": [['x', '0', '1/6'], ['0', 'x', '5/6'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['y', 'x', '-z'], ['x-y', '-y', '-z+1/3'], ['-x', '-x+y', '-z+2/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    155: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    156: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    157: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    158: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['2/3', '1/3', 'z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    159: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    160: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    161: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    162: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z'], ['2/3', '1/3', '-z'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', '0'], ['x', '2x', '0'], ['-2x', '-x', '0'], ['-x', 'x', '0'], ['-x', '-2x', '0'], ['2x', 'x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', '1/2'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2'], ['-x', 'x', '1/2'], ['-x', '-2x', '1/2'], ['2x', 'x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['0', '-x', '-z'], ['-x', '0', '-z'], ['x', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    163: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.66666667, 0.33333333, 0.25      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['2/3', '1/3', '1/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z+1/2'], ['2/3', '1/3', '-z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '-x', '1/4'], ['x', '2x', '1/4'], ['-2x', '-x', '1/4'], ['-x', 'x', '3/4'], ['-x', '-2x', '3/4'], ['2x', 'x', '3/4']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-y', '-x', '-z+1/2'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    164: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['x', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z'], ['-x', 'x', '-z'], ['2x', 'x', '-z'], ['-x', '-2x', '-z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    165: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', '-z+1/2'], ['2/3', '1/3', '-z'], ['1/3', '2/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['0', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', '0', '3/4'], ['0', '-x', '3/4'], ['x', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z+1/2'], ['x-y', '-y', '-z+1/2'], ['-x', '-x+y', '-z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    166: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['x', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z'], ['-x', 'x', '-z'], ['2x', 'x', '-z'], ['-x', '-2x', '-z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    167: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['0', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', '0', '3/4'], ['0', '-x', '3/4'], ['x', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['y', 'x', '-z+1/2'], ['x-y', '-y', '-z+1/2'], ['-x', '-x+y', '-z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.66666667, 0.33333333, 0.33333333], [ 0.33333333, 0.66666667, 0.66666667]]),
    },
    168: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    169: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+5/6'], ['x-y', 'x', 'z+1/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    170: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/6'], ['x-y', 'x', 'z+5/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    171: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+2/3'], ['0', '0', 'z+1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5       , 0.5       , 0.        ], [ 0.5       , 0.        , 0.66666667], [ 0.        , 0.5       , 0.33333333]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '0', 'z+2/3'], ['0', '1/2', 'z+1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['-x', '-y', 'z'], ['y', '-x+y', 'z+2/3'], ['x-y', 'x', 'z+1/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    172: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/3'], ['0', '0', 'z+2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.5       , 0.5       , 0.        ], [ 0.5       , 0.        , 0.33333333], [ 0.        , 0.5       , 0.66666667]]),
            "expressions": [['1/2', '1/2', 'z'], ['1/2', '0', 'z+1/3'], ['0', '1/2', 'z+2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['-x', '-y', 'z'], ['y', '-x+y', 'z+1/3'], ['x-y', 'x', 'z+2/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    173: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    174: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-y', 'x-y', '1/2'], ['-x+y', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    175: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0'], ['-x', '-y', '0'], ['y', '-x+y', '0'], ['x-y', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-y', 'x-y', '1/2'], ['-x+y', '-x', '1/2'], ['-x', '-y', '1/2'], ['y', '-x+y', '1/2'], ['x-y', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    176: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.66666667, 0.33333333, 0.25      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['2/3', '1/3', '1/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-y', 'x-y', '1/4'], ['-x+y', '-x', '1/4'], ['-x', '-y', '3/4'], ['y', '-x+y', '3/4'], ['x-y', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z+1/2'], ['-y', 'x-y', '-z+1/2'], ['-x+y', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    177: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['x', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', '0'], ['x', '2x', '0'], ['-2x', '-x', '0'], ['-x', 'x', '0'], ['-x', '-2x', '0'], ['2x', 'x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', '1/2'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2'], ['-x', 'x', '1/2'], ['-x', '-2x', '1/2'], ['2x', 'x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    178: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '1/3'], ['-x', '-x', '2/3'], ['-x', '0', '1/2'], ['0', '-x', '5/6'], ['x', 'x', '1/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[  0.        ,  0.        ,  0.25      ], [  0.        ,  0.        ,  0.58333333], [  0.        ,  0.        , 11.        ], [  0.        ,  0.        ,  0.75      ], [  0.        ,  0.        ,  0.08333333], [  0.        ,  0.        ,  0.41666667]]),
            "expressions": [['x', '2x', '1/4'], ['-2x', '-x', '7/12'], ['x', '-x', '11/12'], ['-x', '-2x', '3/4'], ['2x', 'x', '1/12'], ['-x', 'x', '5/12']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+5/6'], ['x-y', 'x', 'z+1/6'], ['y', 'x', '-z+1/3'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z+2/3'], ['-y', '-x', '-z+5/6'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+1/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    179: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '2/3'], ['-x', '-x', '1/3'], ['-x', '0', '1/2'], ['0', '-x', '1/6'], ['x', 'x', '5/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[  0.        ,  0.        ,  0.75      ], [  0.        ,  0.        ,  0.41666667], [  0.        ,  0.        ,  0.08333333], [  0.        ,  0.        ,  0.25      ], [  0.        ,  0.        , 11.        ], [  0.        ,  0.        ,  0.58333333]]),
            "expressions": [['x', '2x', '3/4'], ['-2x', '-x', '5/12'], ['x', '-x', '1/12'], ['-x', '-2x', '1/4'], ['2x', 'x', '11/12'], ['-x', 'x', '7/12']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/6'], ['x-y', 'x', 'z+5/6'], ['y', 'x', '-z+2/3'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z+1/3'], ['-y', '-x', '-z+1/6'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+5/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    180: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['0', '0', '0'], ['0', '0', '2/3'], ['0', '0', '1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['0', '0', '1/2'], ['0', '0', '1/6'], ['0', '0', '5/6']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5       , 0.        , 0.        ], [ 0.        , 0.5       , 0.66666667], [ 0.5       , 0.5       , 0.33333333]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '2/3'], ['1/2', '1/2', '1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5       , 0.        , 0.5       ], [ 0.        , 0.5       , 0.16666667], [ 0.5       , 0.5       , 0.83333333]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/6'], ['1/2', '1/2', '5/6']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+2/3'], ['0', '0', 'z+1/3'], ['0', '0', '-z+2/3'], ['0', '0', '-z'], ['0', '0', '-z+1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5       , 0.        , 0.        ], [ 0.        , 0.5       , 0.66666667], [ 0.5       , 0.5       , 0.33333333], [ 0.        , 0.5       , 0.66666667], [ 0.5       , 0.        , 0.        ], [ 0.5       , 0.5       , 0.33333333]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z+2/3'], ['1/2', '1/2', 'z+1/3'], ['0', '1/2', '-z+2/3'], ['1/2', '0', '-z'], ['1/2', '1/2', '-z+1/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '2/3'], ['-x', '-x', '1/3'], ['-x', '0', '0'], ['0', '-x', '2/3'], ['x', 'x', '1/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/6'], ['-x', '-x', '5/6'], ['-x', '0', '1/2'], ['0', '-x', '1/6'], ['x', 'x', '5/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', '2x', '0'], ['-2x', '-x', '2/3'], ['x', '-x', '1/3'], ['-x', '-2x', '0'], ['2x', 'x', '2/3'], ['-x', 'x', '1/3']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.83333333]]),
            "expressions": [['x', '2x', '1/2'], ['-2x', '-x', '1/6'], ['x', '-x', '5/6'], ['-x', '-2x', '1/2'], ['2x', 'x', '1/6'], ['-x', 'x', '5/6']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+2/3'], ['-x+y', '-x', 'z+1/3'], ['-x', '-y', 'z'], ['y', '-x+y', 'z+2/3'], ['x-y', 'x', 'z+1/3'], ['y', 'x', '-z+2/3'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z+1/3'], ['-y', '-x', '-z+2/3'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z+1/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    181: {
        "a": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/3'], ['0', '0', '2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['0', '0', '1/2'], ['0', '0', '5/6'], ['0', '0', '1/6']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.5       , 0.        , 0.        ], [ 0.        , 0.5       , 0.33333333], [ 0.5       , 0.5       , 0.66666667]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '1/3'], ['1/2', '1/2', '2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5       , 0.        , 0.5       ], [ 0.        , 0.5       , 0.83333333], [ 0.5       , 0.5       , 0.16666667]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '5/6'], ['1/2', '1/2', '1/6']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/3'], ['0', '0', 'z+2/3'], ['0', '0', '-z+1/3'], ['0', '0', '-z'], ['0', '0', '-z+2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5       , 0.        , 0.        ], [ 0.        , 0.5       , 0.33333333], [ 0.5       , 0.5       , 0.66666667], [ 0.        , 0.5       , 0.33333333], [ 0.5       , 0.        , 0.        ], [ 0.5       , 0.5       , 0.66666667]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z+1/3'], ['1/2', '1/2', 'z+2/3'], ['0', '1/2', '-z+1/3'], ['1/2', '0', '-z'], ['1/2', '1/2', '-z+2/3']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '1/3'], ['-x', '-x', '2/3'], ['-x', '0', '0'], ['0', '-x', '1/3'], ['x', 'x', '2/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '5/6'], ['-x', '-x', '1/6'], ['-x', '0', '1/2'], ['0', '-x', '5/6'], ['x', 'x', '1/6']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', '2x', '0'], ['-2x', '-x', '1/3'], ['x', '-x', '2/3'], ['-x', '-2x', '0'], ['2x', 'x', '1/3'], ['-x', 'x', '2/3']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667], [ 0.        , 0.        , 0.5       ], [ 0.        , 0.        , 0.83333333], [ 0.        , 0.        , 0.16666667]]),
            "expressions": [['x', '2x', '1/2'], ['-2x', '-x', '5/6'], ['x', '-x', '1/6'], ['-x', '-2x', '1/2'], ['2x', 'x', '5/6'], ['-x', 'x', '1/6']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667], [ 0.        , 0.        , 0.33333333], [ 0.        , 0.        , 0.        ], [ 0.        , 0.        , 0.66666667]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z+1/3'], ['-x+y', '-x', 'z+2/3'], ['-x', '-y', 'z'], ['y', '-x+y', 'z+1/3'], ['x-y', 'x', 'z+2/3'], ['y', 'x', '-z+1/3'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z+2/3'], ['-y', '-x', '-z+1/3'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z+2/3']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    182: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.75      ], [ 0.66666667, 0.33333333, 0.25      ]]),
            "expressions": [['1/3', '2/3', '3/4'], ['2/3', '1/3', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '2x', '1/4'], ['-2x', '-x', '1/4'], ['x', '-x', '1/4'], ['-x', '-2x', '3/4'], ['2x', 'x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-y', '-x', '-z+1/2'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    183: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['-x', '0', 'z'], ['0', '-x', 'z'], ['x', 'x', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z'], ['-x', 'x', 'z'], ['-x', '-2x', 'z'], ['2x', 'x', 'z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    184: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z'], ['1/3', '2/3', 'z+1/2'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z+1/2'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    185: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2'], ['1/3', '2/3', 'z+1/2'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['-x', '0', 'z+1/2'], ['0', '-x', 'z+1/2'], ['x', 'x', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    186: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "b": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z'], ['-x', 'x', 'z+1/2'], ['-x', '-2x', 'z+1/2'], ['2x', 'x', 'z+1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z', 'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    187: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', '0'], ['x', '2x', '0'], ['-2x', '-x', '0']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', '1/2'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0'], ['-y', '-x', '0'], ['-x+y', 'y', '0'], ['x', 'x-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-y', 'x-y', '1/2'], ['-x+y', '-x', '1/2'], ['-y', '-x', '1/2'], ['-x+y', 'y', '1/2'], ['x', 'x-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '-x', 'z'], ['x', '2x', 'z'], ['-2x', '-x', 'z'], ['x', '-x', '-z'], ['x', '2x', '-z'], ['-2x', '-x', '-z']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    188: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '0'], ['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['2/3', '1/3', '0'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.66666667, 0.33333333, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['2/3', '1/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', 'z+1/2'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z+1/2'], ['1/3', '2/3', 'z+1/2'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['2/3', '1/3', 'z'], ['2/3', '1/3', '-z+1/2'], ['2/3', '1/3', 'z+1/2'], ['2/3', '1/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '-x', '0'], ['x', '2x', '0'], ['-2x', '-x', '0'], ['x', '-x', '1/2'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2']],
            "matrices": array([[[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-y', 'x-y', '1/4'], ['-x+y', '-x', '1/4'], ['-y', '-x', '3/4'], ['-x+y', 'y', '3/4'], ['x', 'x-y', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['x', 'y', '-z+1/2'], ['-y', 'x-y', '-z+1/2'], ['-x+y', '-x', '-z+1/2'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    189: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z'], ['2/3', '1/3', '-z'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['x', '0', '-z'], ['0', 'x', '-z'], ['-x', '-x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0'], ['y', 'x', '0'], ['x-y', '-y', '0'], ['-x', '-x+y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-y', 'x-y', '1/2'], ['-x+y', '-x', '1/2'], ['y', 'x', '1/2'], ['x-y', '-y', '1/2'], ['-x', '-x+y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    190: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.66666667, 0.33333333, 0.25      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['2/3', '1/3', '1/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['1/3', '2/3', '-z+1/2'], ['2/3', '1/3', '-z'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-y', 'x-y', '1/4'], ['-x+y', '-x', '1/4'], ['y', 'x', '3/4'], ['x-y', '-y', '3/4'], ['-x', '-x+y', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['x', 'y', '-z+1/2'], ['-y', 'x-y', '-z+1/2'], ['-x+y', '-x', '-z+1/2'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    191: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', '1/2'], ['2/3', '1/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z'], ['0', '1/2', '-z'], ['1/2', '0', '-z'], ['1/2', '1/2', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '0'], ['0', '-x', '0'], ['x', 'x', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '2x', '0'], ['-2x', '-x', '0'], ['x', '-x', '0'], ['-x', '-2x', '0'], ['2x', 'x', '0'], ['-x', 'x', '0']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '2x', '1/2'], ['-2x', '-x', '1/2'], ['x', '-x', '1/2'], ['-x', '-2x', '1/2'], ['2x', 'x', '1/2'], ['-x', 'x', '1/2']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['-x', '0', 'z'], ['0', '-x', 'z'], ['x', 'x', 'z'], ['0', 'x', '-z'], ['x', '0', '-z'], ['-x', '-x', '-z'], ['0', '-x', '-z'], ['-x', '0', '-z'], ['x', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "o": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '2x', 'z'], ['-2x', '-x', 'z'], ['x', '-x', 'z'], ['-x', '-2x', 'z'], ['2x', 'x', 'z'], ['-x', 'x', 'z'], ['2x', 'x', '-z'], ['-x', '-2x', '-z'], ['-x', 'x', '-z'], ['-2x', '-x', '-z'], ['x', '2x', '-z'], ['x', '-x', '-z']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "p": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0'], ['-x', '-y', '0'], ['y', '-x+y', '0'], ['x-y', 'x', '0'], ['y', 'x', '0'], ['x-y', '-y', '0'], ['-x', '-x+y', '0'], ['-y', '-x', '0'], ['-x+y', 'y', '0'], ['x', 'x-y', '0']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "q": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '1/2'], ['-y', 'x-y', '1/2'], ['-x+y', '-x', '1/2'], ['-x', '-y', '1/2'], ['y', '-x+y', '1/2'], ['x-y', 'x', '1/2'], ['y', 'x', '1/2'], ['x-y', '-y', '1/2'], ['-x', '-x+y', '1/2'], ['-y', '-x', '1/2'], ['-x+y', 'y', '1/2'], ['x', 'x-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "r": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    192: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '1/4'], ['2/3', '1/3', '3/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '0'], ['2/3', '1/3', '1/2'], ['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', '-z+1/2'], ['0', '0', '-z'], ['0', '0', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5 , 0.  , 0.25], [ 0.  , 0.5 , 0.25], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.5 , 0.75]]),
            "expressions": [['1/2', '0', '1/4'], ['0', '1/2', '1/4'], ['1/2', '1/2', '1/4'], ['1/2', '0', '3/4'], ['0', '1/2', '3/4'], ['1/2', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z'], ['2/3', '1/3', '-z+1/2'], ['1/3', '2/3', '-z+1/2'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z'], ['1/3', '2/3', 'z+1/2'], ['2/3', '1/3', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', 'z'], ['0', '1/2', 'z'], ['1/2', '1/2', 'z'], ['0', '1/2', '-z+1/2'], ['1/2', '0', '-z+1/2'], ['1/2', '1/2', '-z+1/2'], ['1/2', '0', '-z'], ['0', '1/2', '-z'], ['1/2', '1/2', '-z'], ['0', '1/2', 'z+1/2'], ['1/2', '0', 'z+1/2'], ['1/2', '1/2', 'z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['0', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', '0', '1/4'], ['0', '-x', '1/4'], ['x', 'x', '1/4'], ['-x', '0', '3/4'], ['0', '-x', '3/4'], ['x', 'x', '3/4'], ['x', '0', '3/4'], ['0', 'x', '3/4'], ['-x', '-x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '2x', '1/4'], ['-2x', '-x', '1/4'], ['x', '-x', '1/4'], ['-x', '-2x', '1/4'], ['2x', 'x', '1/4'], ['-x', 'x', '1/4'], ['-x', '-2x', '3/4'], ['2x', 'x', '3/4'], ['-x', 'x', '3/4'], ['x', '2x', '3/4'], ['-2x', '-x', '3/4'], ['x', '-x', '3/4']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', '0'], ['-y', 'x-y', '0'], ['-x+y', '-x', '0'], ['-x', '-y', '0'], ['y', '-x+y', '0'], ['x-y', 'x', '0'], ['y', 'x', '1/2'], ['x-y', '-y', '1/2'], ['-x', '-x+y', '1/2'], ['-y', '-x', '1/2'], ['-x+y', 'y', '1/2'], ['x', 'x-y', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z'], ['y', '-x+y', 'z'], ['x-y', 'x', 'z'], ['y', 'x', '-z+1/2'], ['x-y', '-y', '-z+1/2'], ['-x', '-x+y', '-z+1/2'], ['-y', '-x', '-z+1/2'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z'], ['-y', 'x-y', '-z'], ['-x+y', '-x', '-z'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    193: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ], [ 0.66666667, 0.33333333, 0.25      ], [ 0.33333333, 0.66666667, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4'], ['2/3', '1/3', '1/4'], ['1/3', '2/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', '0'], ['2/3', '1/3', '1/2'], ['2/3', '1/3', '0'], ['1/3', '2/3', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z+1/2'], ['0', '0', '-z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '0', '1/4'], ['0', 'x', '1/4'], ['-x', '-x', '1/4'], ['-x', '0', '3/4'], ['0', '-x', '3/4'], ['x', 'x', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.33333333, 0.66666667, 0.5       ], [ 0.66666667, 0.33333333, 0.        ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2'], ['2/3', '1/3', '-z+1/2'], ['1/3', '2/3', '-z'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z+1/2'], ['1/3', '2/3', 'z+1/2'], ['2/3', '1/3', 'z']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]]]),
            "variables": {'z'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '2x', '0'], ['-2x', '-x', '0'], ['x', '-x', '0'], ['-x', '-2x', '1/2'], ['2x', 'x', '1/2'], ['-x', 'x', '1/2'], ['-x', '-2x', '0'], ['2x', 'x', '0'], ['-x', 'x', '0'], ['x', '2x', '1/2'], ['-2x', '-x', '1/2'], ['x', '-x', '1/2']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', 'y', '1/4'], ['-y', 'x-y', '1/4'], ['-x+y', '-x', '1/4'], ['-x', '-y', '3/4'], ['y', '-x+y', '3/4'], ['x-y', 'x', '3/4'], ['y', 'x', '1/4'], ['x-y', '-y', '1/4'], ['-x', '-x+y', '1/4'], ['-y', '-x', '3/4'], ['-x+y', 'y', '3/4'], ['x', 'x-y', '3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', '0', 'z'], ['0', 'x', 'z'], ['-x', '-x', 'z'], ['-x', '0', 'z+1/2'], ['0', '-x', 'z+1/2'], ['x', 'x', 'z+1/2'], ['0', 'x', '-z+1/2'], ['x', '0', '-z+1/2'], ['-x', '-x', '-z+1/2'], ['0', '-x', '-z'], ['-x', '0', '-z'], ['x', 'x', '-z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['y', 'x', '-z+1/2'], ['x-y', '-y', '-z+1/2'], ['-x', '-x+y', '-z+1/2'], ['-y', '-x', '-z'], ['-x+y', 'y', '-z'], ['x', 'x-y', '-z'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z+1/2'], ['-y', 'x-y', '-z+1/2'], ['-x+y', '-x', '-z+1/2'], ['-y', '-x', 'z+1/2'], ['-x+y', 'y', 'z+1/2'], ['x', 'x-y', 'z+1/2'], ['y', 'x', 'z'], ['x-y', '-y', 'z'], ['-x', '-x+y', 'z']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    194: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.33333333, 0.66666667, 0.25      ], [ 0.66666667, 0.33333333, 0.75      ]]),
            "expressions": [['1/3', '2/3', '1/4'], ['2/3', '1/3', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.33333333, 0.66666667, 0.75      ], [ 0.66666667, 0.33333333, 0.25      ]]),
            "expressions": [['1/3', '2/3', '3/4'], ['2/3', '1/3', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '0', 'z'], ['0', '0', 'z+1/2'], ['0', '0', '-z'], ['0', '0', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "f": {
            "constants": array([[ 0.33333333, 0.66666667, 0.        ], [ 0.66666667, 0.33333333, 0.5       ], [ 0.66666667, 0.33333333, 0.        ], [ 0.33333333, 0.66666667, 0.5       ]]),
            "expressions": [['1/3', '2/3', 'z'], ['2/3', '1/3', 'z+1/2'], ['2/3', '1/3', '-z'], ['1/3', '2/3', '-z+1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z'},
        },
        "g": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['1/2', '1/2', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x', '2x', '1/4'], ['-2x', '-x', '1/4'], ['x', '-x', '1/4'], ['-x', '-2x', '3/4'], ['2x', 'x', '3/4'], ['-x', 'x', '3/4']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '0', '0'], ['0', 'x', '0'], ['-x', '-x', '0'], ['-x', '0', '1/2'], ['0', '-x', '1/2'], ['x', 'x', '1/2'], ['-x', '0', '0'], ['0', '-x', '0'], ['x', 'x', '0'], ['x', '0', '1/2'], ['0', 'x', '1/2'], ['-x', '-x', '1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25]]),
            "expressions": [['x', 'y', '1/4'], ['-y', 'x-y', '1/4'], ['-x+y', '-x', '1/4'], ['-x', '-y', '3/4'], ['y', '-x+y', '3/4'], ['x-y', 'x', '3/4'], ['y', 'x', '3/4'], ['x-y', '-y', '3/4'], ['-x', '-x+y', '3/4'], ['-y', '-x', '1/4'], ['-x+y', 'y', '1/4'], ['x', 'x-y', '1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y', 'x'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', '2x', 'z'], ['-2x', '-x', 'z'], ['x', '-x', 'z'], ['-x', '-2x', 'z+1/2'], ['2x', 'x', 'z+1/2'], ['-x', 'x', 'z+1/2'], ['2x', 'x', '-z'], ['-x', '-2x', '-z'], ['-x', 'x', '-z'], ['-2x', '-x', '-z+1/2'], ['x', '2x', '-z+1/2'], ['x', '-x', '-z+1/2']],
            "matrices": array([[[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 2., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-2.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 2., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-y', 'x-y', 'z'], ['-x+y', '-x', 'z'], ['-x', '-y', 'z+1/2'], ['y', '-x+y', 'z+1/2'], ['x-y', 'x', 'z+1/2'], ['y', 'x', '-z'], ['x-y', '-y', '-z'], ['-x', '-x+y', '-z'], ['-y', '-x', '-z+1/2'], ['-x+y', 'y', '-z+1/2'], ['x', 'x-y', '-z+1/2'], ['-x', '-y', '-z'], ['y', '-x+y', '-z'], ['x-y', 'x', '-z'], ['x', 'y', '-z+1/2'], ['-y', 'x-y', '-z+1/2'], ['-x+y', '-x', '-z+1/2'], ['-y', '-x', 'z'], ['-x+y', 'y', 'z'], ['x', 'x-y', 'z'], ['y', 'x', 'z+1/2'], ['x-y', '-y', 'z+1/2'], ['-x', '-x+y', 'z+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1.,-1., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 1.]], [[ 1., 1., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    195: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2'], ['1/2', '1/2', 'x'], ['1/2', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    196: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.75, 0.75, 0.75]]),
            "expressions": [['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    197: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    198: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    199: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "b": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['1/4', 'x', '0'], ['3/4', '-x+1/2', '0'], ['0', '1/4', 'x'], ['0', '3/4', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    200: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2'], ['1/2', '1/2', 'x'], ['1/2', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['-x', '-x', '-x'], ['x', 'x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'z'},
        },
        "k": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z'], ['1/2', 'y', '-z'], ['1/2', '-y', '-z'], ['z', '1/2', 'y'], ['z', '1/2', '-y'], ['-z', '1/2', 'y'], ['-z', '1/2', '-y'], ['y', 'z', '1/2'], ['-y', 'z', '1/2'], ['y', '-z', '1/2'], ['-y', '-z', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'z'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    201: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['x+1/4', 'x+1/4', 'x+1/4'], ['-x+3/4', '-x+3/4', 'x+1/4'], ['-x+3/4', 'x+1/4', '-x+3/4'], ['x+1/4', '-x+3/4', '-x+3/4'], ['-x+1/4', '-x+1/4', '-x+1/4'], ['x+3/4', 'x+3/4', '-x+1/4'], ['x+3/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+3/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x+1/4', '1/2', '1/2'], ['-x+3/4', '1/2', '1/2'], ['1/2', 'x+1/4', '1/2'], ['1/2', '-x+3/4', '1/2'], ['1/2', '1/2', 'x+1/4'], ['1/2', '1/2', '-x+3/4'], ['-x+1/4', '0', '0'], ['x+3/4', '0', '0'], ['0', '-x+1/4', '0'], ['0', 'x+3/4', '0'], ['0', '0', '-x+1/4'], ['0', '0', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['x+1/4', '0', '1/2'], ['-x+3/4', '0', '1/2'], ['1/2', 'x+1/4', '0'], ['1/2', '-x+3/4', '0'], ['0', '1/2', 'x+1/4'], ['0', '1/2', '-x+3/4'], ['-x+1/4', '1/2', '0'], ['x+3/4', '1/2', '0'], ['0', '-x+1/4', '1/2'], ['0', 'x+3/4', '1/2'], ['1/2', '0', '-x+1/4'], ['1/2', '0', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25]]),
            "expressions": [['x+1/4', 'y+1/4', 'z+1/4'], ['-x+3/4', '-y+3/4', 'z+1/4'], ['-x+3/4', 'y+1/4', '-z+3/4'], ['x+1/4', '-y+3/4', '-z+3/4'], ['z+1/4', 'x+1/4', 'y+1/4'], ['z+1/4', '-x+3/4', '-y+3/4'], ['-z+3/4', '-x+3/4', 'y+1/4'], ['-z+3/4', 'x+1/4', '-y+3/4'], ['y+1/4', 'z+1/4', 'x+1/4'], ['-y+3/4', 'z+1/4', '-x+3/4'], ['y+1/4', '-z+3/4', '-x+3/4'], ['-y+3/4', '-z+3/4', 'x+1/4'], ['-x+1/4', '-y+1/4', '-z+1/4'], ['x+3/4', 'y+3/4', '-z+1/4'], ['x+3/4', '-y+1/4', 'z+3/4'], ['-x+1/4', 'y+3/4', 'z+3/4'], ['-z+1/4', '-x+1/4', '-y+1/4'], ['-z+1/4', 'x+3/4', 'y+3/4'], ['z+3/4', 'x+3/4', '-y+1/4'], ['z+3/4', '-x+1/4', 'y+3/4'], ['-y+1/4', '-z+1/4', '-x+1/4'], ['y+3/4', '-z+1/4', 'x+3/4'], ['-y+1/4', 'z+3/4', 'x+3/4'], ['y+3/4', 'z+3/4', '-x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    202: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4'], ['1/4', '0', '1/4'], ['1/4', '0', '3/4'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['-x', '-x', '-x'], ['x', 'x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.  , 0.75, 0.75], [ 0.  , 0.25, 0.75], [ 0.75, 0.  , 0.75], [ 0.75, 0.  , 0.25], [ 0.75, 0.75, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x'], ['-x', '3/4', '3/4'], ['x', '1/4', '3/4'], ['3/4', '-x', '3/4'], ['3/4', 'x', '1/4'], ['3/4', '3/4', '-x'], ['1/4', '3/4', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'z'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    203: {
        "a": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.  , 0.  , 0.  ]]),
            "expressions": [['1/4', '1/4', '1/4'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.5 , 0.5 , 0.5 ]]),
            "expressions": [['3/4', '3/4', '3/4'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875]]),
            "expressions": [['1/8', '1/8', '1/8'], ['7/8', '7/8', '1/8'], ['7/8', '1/8', '7/8'], ['1/8', '7/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.375, 0.375, 0.625], [ 0.375, 0.625, 0.375], [ 0.625, 0.375, 0.375]]),
            "expressions": [['5/8', '5/8', '5/8'], ['3/8', '3/8', '5/8'], ['3/8', '5/8', '3/8'], ['5/8', '3/8', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.375, 0.125], [ 0.375, 0.125, 0.375], [ 0.125, 0.375, 0.375]]),
            "expressions": [['x+1/8', 'x+1/8', 'x+1/8'], ['-x+7/8', '-x+7/8', 'x+1/8'], ['-x+7/8', 'x+1/8', '-x+7/8'], ['x+1/8', '-x+7/8', '-x+7/8'], ['-x+1/8', '-x+1/8', '-x+1/8'], ['x+3/8', 'x+3/8', '-x+1/8'], ['x+3/8', '-x+1/8', 'x+3/8'], ['-x+1/8', 'x+3/8', 'x+3/8']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.125, 0.25 , 0.25 ], [ 0.875, 0.75 , 0.25 ], [ 0.25 , 0.125, 0.25 ], [ 0.25 , 0.875, 0.75 ], [ 0.25 , 0.25 , 0.125], [ 0.75 , 0.25 , 0.875], [ 0.125, 0.   , 0.   ], [ 0.375, 0.5  , 0.   ], [ 0.   , 0.125, 0.   ], [ 0.   , 0.375, 0.5  ], [ 0.   , 0.   , 0.125], [ 0.5  , 0.   , 0.375]]),
            "expressions": [['x+1/8', '1/4', '1/4'], ['-x+7/8', '3/4', '1/4'], ['1/4', 'x+1/8', '1/4'], ['1/4', '-x+7/8', '3/4'], ['1/4', '1/4', 'x+1/8'], ['3/4', '1/4', '-x+7/8'], ['-x+1/8', '0', '0'], ['x+3/8', '1/2', '0'], ['0', '-x+1/8', '0'], ['0', 'x+3/8', '1/2'], ['0', '0', '-x+1/8'], ['1/2', '0', 'x+3/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875], [ 0.125, 0.125, 0.125], [ 0.125, 0.875, 0.875], [ 0.875, 0.875, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.125, 0.125], [ 0.875, 0.125, 0.875], [ 0.125, 0.875, 0.875], [ 0.875, 0.875, 0.125], [ 0.125, 0.125, 0.125], [ 0.375, 0.375, 0.125], [ 0.375, 0.125, 0.375], [ 0.125, 0.375, 0.375], [ 0.125, 0.125, 0.125], [ 0.125, 0.375, 0.375], [ 0.375, 0.375, 0.125], [ 0.375, 0.125, 0.375], [ 0.125, 0.125, 0.125], [ 0.375, 0.125, 0.375], [ 0.125, 0.375, 0.375], [ 0.375, 0.375, 0.125]]),
            "expressions": [['x+1/8', 'y+1/8', 'z+1/8'], ['-x+7/8', '-y+7/8', 'z+1/8'], ['-x+7/8', 'y+1/8', '-z+7/8'], ['x+1/8', '-y+7/8', '-z+7/8'], ['z+1/8', 'x+1/8', 'y+1/8'], ['z+1/8', '-x+7/8', '-y+7/8'], ['-z+7/8', '-x+7/8', 'y+1/8'], ['-z+7/8', 'x+1/8', '-y+7/8'], ['y+1/8', 'z+1/8', 'x+1/8'], ['-y+7/8', 'z+1/8', '-x+7/8'], ['y+1/8', '-z+7/8', '-x+7/8'], ['-y+7/8', '-z+7/8', 'x+1/8'], ['-x+1/8', '-y+1/8', '-z+1/8'], ['x+3/8', 'y+3/8', '-z+1/8'], ['x+3/8', '-y+1/8', 'z+3/8'], ['-x+1/8', 'y+3/8', 'z+3/8'], ['-z+1/8', '-x+1/8', '-y+1/8'], ['-z+1/8', 'x+3/8', 'y+3/8'], ['z+3/8', 'x+3/8', '-y+1/8'], ['z+3/8', '-x+1/8', 'y+3/8'], ['-y+1/8', '-z+1/8', '-x+1/8'], ['y+3/8', '-z+1/8', 'x+3/8'], ['-y+1/8', 'z+3/8', 'x+3/8'], ['y+3/8', 'z+3/8', '-x+1/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    204: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['-x', '-x', '-x'], ['x', 'x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'y', 'z'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    205: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '1/2', '0'], ['1/2', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['-x', '-x', '-x'], ['x+1/2', 'x', '-x+1/2'], ['x', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z'], ['-z', '-x', '-y'], ['-z+1/2', 'x+1/2', 'y'], ['z+1/2', 'x', '-y+1/2'], ['z', '-x+1/2', 'y+1/2'], ['-y', '-z', '-x'], ['y', '-z+1/2', 'x+1/2'], ['-y+1/2', 'z+1/2', 'x'], ['y+1/2', 'z', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    206: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['1/4', '3/4', '3/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['-x', '-x', '-x'], ['x+1/2', 'x', '-x+1/2'], ['x', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.75, 0.  , 0.  ], [ 0.25, 0.5 , 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.5 ]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['1/4', 'x', '0'], ['3/4', '-x+1/2', '0'], ['0', '1/4', 'x'], ['0', '3/4', '-x+1/2'], ['-x', '0', '3/4'], ['x+1/2', '0', '1/4'], ['3/4', '-x', '0'], ['1/4', 'x+1/2', '0'], ['0', '3/4', '-x'], ['0', '1/4', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0. , 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z'], ['-z', '-x', '-y'], ['-z+1/2', 'x+1/2', 'y'], ['z+1/2', 'x', '-y+1/2'], ['z', '-x+1/2', 'y+1/2'], ['-y', '-z', '-x'], ['y', '-z+1/2', 'x+1/2'], ['-y+1/2', 'z+1/2', 'x'], ['y+1/2', 'z', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    207: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2'], ['1/2', '1/2', 'x'], ['1/2', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '1/2', '-x'], ['0', '1/2', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'y'], ['1/2', '-y', 'y'], ['1/2', 'y', '-y'], ['1/2', '-y', '-y'], ['y', '1/2', 'y'], ['y', '1/2', '-y'], ['-y', '1/2', 'y'], ['-y', '1/2', '-y'], ['y', 'y', '1/2'], ['-y', 'y', '1/2'], ['y', '-y', '1/2'], ['-y', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    208: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0'], ['0', '1/2', '0'], ['1/2', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2'], ['1/2', '1/4', '0'], ['1/2', '3/4', '0'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x+1/2', 'x+1/2', '-x+1/2'], ['-x+1/2', '-x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x+1/2']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x'], ['1/2', 'x+1/2', '1/2'], ['1/2', '-x+1/2', '1/2'], ['x+1/2', '1/2', '1/2'], ['-x+1/2', '1/2', '1/2'], ['1/2', '1/2', '-x+1/2'], ['1/2', '1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x'], ['1/2', 'x+1/2', '0'], ['1/2', '-x+1/2', '0'], ['x+1/2', '0', '1/2'], ['-x+1/2', '0', '1/2'], ['0', '1/2', '-x+1/2'], ['0', '1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['0', 'x+1/2', '1/2'], ['0', '-x+1/2', '1/2'], ['x+1/2', '1/2', '0'], ['-x+1/2', '1/2', '0'], ['1/2', '0', '-x+1/2'], ['1/2', '0', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "k": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/4', 'y', '-y+1/2'], ['3/4', '-y', '-y+1/2'], ['3/4', 'y', 'y+1/2'], ['1/4', '-y', 'y+1/2'], ['-y+1/2', '1/4', 'y'], ['-y+1/2', '3/4', '-y'], ['y+1/2', '3/4', 'y'], ['y+1/2', '1/4', '-y'], ['y', '-y+1/2', '1/4'], ['-y', '-y+1/2', '3/4'], ['y', 'y+1/2', '3/4'], ['-y', 'y+1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "l": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/4', 'y', 'y+1/2'], ['3/4', '-y', 'y+1/2'], ['3/4', 'y', '-y+1/2'], ['1/4', '-y', '-y+1/2'], ['y+1/2', '1/4', 'y'], ['y+1/2', '3/4', '-y'], ['-y+1/2', '3/4', 'y'], ['-y+1/2', '1/4', '-y'], ['y', 'y+1/2', '1/4'], ['-y', 'y+1/2', '3/4'], ['y', '-y+1/2', '3/4'], ['-y', '-y+1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "m": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['x+1/2', 'z+1/2', '-y+1/2'], ['-x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', '-z+1/2', '-y+1/2'], ['x+1/2', '-z+1/2', 'y+1/2'], ['z+1/2', 'y+1/2', '-x+1/2'], ['z+1/2', '-y+1/2', 'x+1/2'], ['-z+1/2', 'y+1/2', 'x+1/2'], ['-z+1/2', '-y+1/2', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    209: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.25, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['1/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4'], ['1/4', '0', '1/4'], ['1/4', '0', '3/4'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'y'], ['1/2', '-y', 'y'], ['1/2', 'y', '-y'], ['1/2', '-y', '-y'], ['y', '1/2', 'y'], ['y', '1/2', '-y'], ['-y', '1/2', 'y'], ['-y', '1/2', '-y'], ['y', 'y', '1/2'], ['-y', 'y', '1/2'], ['y', '-y', '1/2'], ['-y', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.  , 0.75], [ 0.75, 0.  , 0.75], [ 0.  , 0.25, 0.75], [ 0.  , 0.25, 0.25], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x'], ['1/4', 'x', '3/4'], ['3/4', '-x', '3/4'], ['x', '1/4', '3/4'], ['-x', '1/4', '1/4'], ['1/4', '1/4', '-x'], ['1/4', '3/4', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    210: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.75, 0.25, 0.75]]),
            "expressions": [['0', '0', '0'], ['3/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5 , 0.5 , 0.5 ], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/2', '1/2', '1/2'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375]]),
            "expressions": [['1/8', '1/8', '1/8'], ['7/8', '3/8', '5/8'], ['3/8', '5/8', '7/8'], ['5/8', '7/8', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.375, 0.875, 0.125], [ 0.875, 0.125, 0.375], [ 0.125, 0.375, 0.875]]),
            "expressions": [['5/8', '5/8', '5/8'], ['3/8', '7/8', '1/8'], ['7/8', '1/8', '3/8'], ['1/8', '3/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', '-x'], ['x+1/2', '-x', '-x+1/2'], ['x+3/4', 'x+1/4', '-x+3/4'], ['-x+1/4', '-x+1/4', '-x+1/4'], ['x+1/4', '-x+3/4', 'x+3/4'], ['-x+3/4', 'x+3/4', 'x+1/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['x', '0', '0'], ['-x', '1/2', '1/2'], ['0', 'x', '0'], ['1/2', '-x', '1/2'], ['0', '0', 'x'], ['1/2', '1/2', '-x'], ['3/4', 'x+1/4', '3/4'], ['1/4', '-x+1/4', '1/4'], ['x+3/4', '1/4', '3/4'], ['-x+3/4', '3/4', '1/4'], ['3/4', '1/4', '-x+3/4'], ['1/4', '3/4', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.875, 0.5  , 0.75 ], [ 0.375, 0.5  , 0.75 ], [ 0.625, 0.   , 0.25 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.875, 0.5  ], [ 0.75 , 0.375, 0.5  ], [ 0.25 , 0.625, 0.   ], [ 0.   , 0.25 , 0.125], [ 0.5  , 0.75 , 0.875], [ 0.5  , 0.75 , 0.375], [ 0.   , 0.25 , 0.625]]),
            "expressions": [['1/8', 'y', '-y+1/4'], ['7/8', '-y+1/2', '-y+3/4'], ['3/8', 'y+1/2', 'y+3/4'], ['5/8', '-y', 'y+1/4'], ['-y+1/4', '1/8', 'y'], ['-y+3/4', '7/8', '-y+1/2'], ['y+3/4', '3/8', 'y+1/2'], ['y+1/4', '5/8', '-y'], ['y', '-y+1/4', '1/8'], ['-y+1/2', '-y+3/4', '7/8'], ['y+1/2', 'y+3/4', '3/8'], ['-y', 'y+1/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', '-z'], ['x+1/2', '-y', '-z+1/2'], ['z', 'x', 'y'], ['z+1/2', '-x', '-y+1/2'], ['-z', '-x+1/2', 'y+1/2'], ['-z+1/2', 'x+1/2', '-y'], ['y', 'z', 'x'], ['-y+1/2', 'z+1/2', '-x'], ['y+1/2', '-z', '-x+1/2'], ['-y', '-z+1/2', 'x+1/2'], ['y+3/4', 'x+1/4', '-z+3/4'], ['-y+1/4', '-x+1/4', '-z+1/4'], ['y+1/4', '-x+3/4', 'z+3/4'], ['-y+3/4', 'x+3/4', 'z+1/4'], ['x+3/4', 'z+1/4', '-y+3/4'], ['-x+3/4', 'z+3/4', 'y+1/4'], ['-x+1/4', '-z+1/4', '-y+1/4'], ['x+1/4', '-z+3/4', 'y+3/4'], ['z+3/4', 'y+1/4', '-x+3/4'], ['z+1/4', '-y+3/4', 'x+3/4'], ['-z+3/4', 'y+3/4', 'x+1/4'], ['-z+1/4', '-y+1/4', '-x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    211: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '1/2', '-x'], ['0', '1/2', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['1/4', 'y', '-y+1/2'], ['3/4', '-y', '-y+1/2'], ['3/4', 'y', 'y+1/2'], ['1/4', '-y', 'y+1/2'], ['-y+1/2', '1/4', 'y'], ['-y+1/2', '3/4', '-y'], ['y+1/2', '3/4', 'y'], ['y+1/2', '1/4', '-y'], ['y', '-y+1/2', '1/4'], ['-y', '-y+1/2', '3/4'], ['y', 'y+1/2', '3/4'], ['-y', 'y+1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    212: {
        "a": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875]]),
            "expressions": [['1/8', '1/8', '1/8'], ['3/8', '7/8', '5/8'], ['7/8', '5/8', '3/8'], ['5/8', '3/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.875, 0.375, 0.125], [ 0.375, 0.125, 0.875], [ 0.125, 0.875, 0.375]]),
            "expressions": [['5/8', '5/8', '5/8'], ['7/8', '3/8', '1/8'], ['3/8', '1/8', '7/8'], ['1/8', '7/8', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['x+1/4', 'x+3/4', '-x+3/4'], ['-x+1/4', '-x+1/4', '-x+1/4'], ['x+3/4', '-x+3/4', 'x+1/4'], ['-x+3/4', 'x+1/4', 'x+3/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.875, 0.5  , 0.25 ], [ 0.625, 0.5  , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.25 , 0.875, 0.5  ], [ 0.75 , 0.625, 0.5  ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.5  , 0.25 , 0.875], [ 0.5  , 0.75 , 0.625]]),
            "expressions": [['1/8', 'y', '-y+1/4'], ['3/8', '-y', '-y+3/4'], ['7/8', 'y+1/2', 'y+1/4'], ['5/8', '-y+1/2', 'y+3/4'], ['-y+1/4', '1/8', 'y'], ['-y+3/4', '3/8', '-y'], ['y+1/4', '7/8', 'y+1/2'], ['y+3/4', '5/8', '-y+1/2'], ['y', '-y+1/4', '1/8'], ['-y', '-y+3/4', '3/8'], ['y+1/2', 'y+1/4', '7/8'], ['-y+1/2', 'y+3/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['y+1/4', 'x+3/4', '-z+3/4'], ['-y+1/4', '-x+1/4', '-z+1/4'], ['y+3/4', '-x+3/4', 'z+1/4'], ['-y+3/4', 'x+1/4', 'z+3/4'], ['x+1/4', 'z+3/4', '-y+3/4'], ['-x+3/4', 'z+1/4', 'y+3/4'], ['-x+1/4', '-z+1/4', '-y+1/4'], ['x+3/4', '-z+3/4', 'y+1/4'], ['z+1/4', 'y+3/4', '-x+3/4'], ['z+3/4', '-y+3/4', 'x+1/4'], ['-z+3/4', 'y+1/4', 'x+3/4'], ['-z+1/4', '-y+1/4', '-x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    213: {
        "a": {
            "constants": array([[ 0.375, 0.375, 0.375], [ 0.125, 0.625, 0.875], [ 0.625, 0.875, 0.125], [ 0.875, 0.125, 0.625]]),
            "expressions": [['3/8', '3/8', '3/8'], ['1/8', '5/8', '7/8'], ['5/8', '7/8', '1/8'], ['7/8', '1/8', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.875, 0.875, 0.875], [ 0.625, 0.125, 0.375], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125]]),
            "expressions": [['7/8', '7/8', '7/8'], ['5/8', '1/8', '3/8'], ['1/8', '3/8', '5/8'], ['3/8', '5/8', '1/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['x+3/4', 'x+1/4', '-x+1/4'], ['-x+3/4', '-x+3/4', '-x+3/4'], ['x+1/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+1/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.875, 0.5  , 0.25 ], [ 0.625, 0.5  , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.25 , 0.875, 0.5  ], [ 0.75 , 0.625, 0.5  ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.5  , 0.25 , 0.875], [ 0.5  , 0.75 , 0.625]]),
            "expressions": [['1/8', 'y', 'y+1/4'], ['3/8', '-y', 'y+3/4'], ['7/8', 'y+1/2', '-y+1/4'], ['5/8', '-y+1/2', '-y+3/4'], ['y+1/4', '1/8', 'y'], ['y+3/4', '3/8', '-y'], ['-y+1/4', '7/8', 'y+1/2'], ['-y+3/4', '5/8', '-y+1/2'], ['y', 'y+1/4', '1/8'], ['-y', 'y+3/4', '3/8'], ['y+1/2', '-y+1/4', '7/8'], ['-y+1/2', '-y+3/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['y+3/4', 'x+1/4', '-z+1/4'], ['-y+3/4', '-x+3/4', '-z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-y+1/4', 'x+3/4', 'z+1/4'], ['x+3/4', 'z+1/4', '-y+1/4'], ['-x+1/4', 'z+3/4', 'y+1/4'], ['-x+3/4', '-z+3/4', '-y+3/4'], ['x+1/4', '-z+1/4', 'y+3/4'], ['z+3/4', 'y+1/4', '-x+1/4'], ['z+1/4', '-y+1/4', 'x+3/4'], ['-z+1/4', 'y+3/4', 'x+1/4'], ['-z+3/4', '-y+3/4', '-x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    214: {
        "a": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875]]),
            "expressions": [['1/8', '1/8', '1/8'], ['3/8', '7/8', '5/8'], ['7/8', '5/8', '3/8'], ['5/8', '3/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.875, 0.875, 0.875], [ 0.625, 0.125, 0.375], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125]]),
            "expressions": [['7/8', '7/8', '7/8'], ['5/8', '1/8', '3/8'], ['1/8', '3/8', '5/8'], ['3/8', '5/8', '1/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375]]),
            "expressions": [['1/8', '0', '1/4'], ['3/8', '0', '3/4'], ['1/4', '1/8', '0'], ['3/4', '3/8', '0'], ['0', '1/4', '1/8'], ['0', '3/4', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.625, 0.   , 0.25 ], [ 0.875, 0.   , 0.75 ], [ 0.25 , 0.625, 0.   ], [ 0.75 , 0.875, 0.   ], [ 0.   , 0.25 , 0.625], [ 0.   , 0.75 , 0.875]]),
            "expressions": [['5/8', '0', '1/4'], ['7/8', '0', '3/4'], ['1/4', '5/8', '0'], ['3/4', '7/8', '0'], ['0', '1/4', '5/8'], ['0', '3/4', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['x+3/4', 'x+1/4', '-x+1/4'], ['-x+3/4', '-x+3/4', '-x+3/4'], ['x+1/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+1/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.5 , 0.25], [ 0.25, 0.  , 0.25], [ 0.  , 0.25, 0.25], [ 0.5 , 0.25, 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['1/4', 'x', '0'], ['3/4', '-x+1/2', '0'], ['0', '1/4', 'x'], ['0', '3/4', '-x+1/2'], ['3/4', 'x+1/4', '0'], ['3/4', '-x+3/4', '1/2'], ['x+3/4', '1/2', '1/4'], ['-x+1/4', '0', '1/4'], ['0', '1/4', '-x+1/4'], ['1/2', '1/4', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.875, 0.5  , 0.25 ], [ 0.625, 0.5  , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.25 , 0.875, 0.5  ], [ 0.75 , 0.625, 0.5  ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.5  , 0.25 , 0.875], [ 0.5  , 0.75 , 0.625]]),
            "expressions": [['1/8', 'y', 'y+1/4'], ['3/8', '-y', 'y+3/4'], ['7/8', 'y+1/2', '-y+1/4'], ['5/8', '-y+1/2', '-y+3/4'], ['y+1/4', '1/8', 'y'], ['y+3/4', '3/8', '-y'], ['-y+1/4', '7/8', 'y+1/2'], ['-y+3/4', '5/8', '-y+1/2'], ['y', 'y+1/4', '1/8'], ['-y', 'y+3/4', '3/8'], ['y+1/2', '-y+1/4', '7/8'], ['-y+1/2', '-y+3/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.875, 0.5  , 0.25 ], [ 0.625, 0.5  , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.25 , 0.875, 0.5  ], [ 0.75 , 0.625, 0.5  ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.5  , 0.25 , 0.875], [ 0.5  , 0.75 , 0.625]]),
            "expressions": [['1/8', 'y', '-y+1/4'], ['3/8', '-y', '-y+3/4'], ['7/8', 'y+1/2', 'y+1/4'], ['5/8', '-y+1/2', 'y+3/4'], ['-y+1/4', '1/8', 'y'], ['-y+3/4', '3/8', '-y'], ['y+1/4', '7/8', 'y+1/2'], ['y+3/4', '5/8', '-y+1/2'], ['y', '-y+1/4', '1/8'], ['-y', '-y+3/4', '3/8'], ['y+1/2', 'y+1/4', '7/8'], ['-y+1/2', 'y+3/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['y+3/4', 'x+1/4', '-z+1/4'], ['-y+3/4', '-x+3/4', '-z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-y+1/4', 'x+3/4', 'z+1/4'], ['x+3/4', 'z+1/4', '-y+1/4'], ['-x+1/4', 'z+3/4', 'y+1/4'], ['-x+3/4', '-z+3/4', '-y+3/4'], ['x+1/4', '-z+1/4', 'y+3/4'], ['z+3/4', 'y+1/4', '-x+1/4'], ['z+1/4', '-y+1/4', 'x+3/4'], ['-z+1/4', 'y+3/4', 'x+1/4'], ['-z+3/4', '-y+3/4', '-x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    215: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2'], ['1/2', '1/2', 'x'], ['1/2', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '1/2', 'x'], ['0', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'z', 'x'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', 'z'], ['-y', '-x', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['z', 'y', 'x'], ['z', '-y', '-x'], ['-z', 'y', '-x'], ['-z', '-y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    216: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.75, 0.75, 0.75]]),
            "expressions": [['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'z', 'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', 'z'], ['-y', '-x', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['z', 'y', 'x'], ['z', '-y', '-x'], ['-z', 'y', '-x'], ['-z', '-y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    217: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '1/2', 'x'], ['0', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]]]),
            "variables": {'z', 'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', 'z'], ['-y', '-x', 'z'], ['y', '-x', '-z'], ['-y', 'x', '-z'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['z', 'y', 'x'], ['z', '-y', '-x'], ['-z', 'y', '-x'], ['-z', '-y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    218: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0'], ['0', '1/2', '0'], ['1/2', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2'], ['1/2', '1/4', '0'], ['1/2', '3/4', '0'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x+1/2', 'x+1/2', 'x+1/2'], ['-x+1/2', '-x+1/2', 'x+1/2'], ['x+1/2', '-x+1/2', '-x+1/2'], ['-x+1/2', 'x+1/2', '-x+1/2']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x'], ['1/2', 'x+1/2', '1/2'], ['1/2', '-x+1/2', '1/2'], ['x+1/2', '1/2', '1/2'], ['-x+1/2', '1/2', '1/2'], ['1/2', '1/2', 'x+1/2'], ['1/2', '1/2', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['0', 'x+1/2', '1/2'], ['0', '-x+1/2', '1/2'], ['x+1/2', '1/2', '0'], ['-x+1/2', '1/2', '0'], ['1/2', '0', 'x+1/2'], ['1/2', '0', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x'], ['1/2', 'x+1/2', '0'], ['1/2', '-x+1/2', '0'], ['x+1/2', '0', '1/2'], ['-x+1/2', '0', '1/2'], ['0', '1/2', 'x+1/2'], ['0', '1/2', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y+1/2', 'x+1/2', 'z+1/2'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', '-x+1/2', '-z+1/2'], ['-y+1/2', 'x+1/2', '-z+1/2'], ['x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', 'z+1/2', '-y+1/2'], ['-x+1/2', '-z+1/2', 'y+1/2'], ['x+1/2', '-z+1/2', '-y+1/2'], ['z+1/2', 'y+1/2', 'x+1/2'], ['z+1/2', '-y+1/2', '-x+1/2'], ['-z+1/2', 'y+1/2', '-x+1/2'], ['-z+1/2', '-y+1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    219: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4'], ['1/4', '0', '1/4'], ['1/4', '0', '3/4'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['1/4', '0', '0'], ['3/4', '0', '0'], ['0', '1/4', '0'], ['0', '3/4', '0'], ['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x+1/2', 'x+1/2', 'x+1/2'], ['-x+1/2', '-x+1/2', 'x+1/2'], ['x+1/2', '-x+1/2', '-x+1/2'], ['-x+1/2', 'x+1/2', '-x+1/2']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x'], ['1/2', 'x+1/2', '1/2'], ['1/2', '-x+1/2', '1/2'], ['x+1/2', '1/2', '1/2'], ['-x+1/2', '1/2', '1/2'], ['1/2', '1/2', 'x+1/2'], ['1/2', '1/2', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.5 , 0.75], [ 0.25, 0.5 , 0.75], [ 0.5 , 0.75, 0.75], [ 0.5 , 0.75, 0.25], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.25, 0.5 ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x'], ['3/4', 'x+1/2', '3/4'], ['1/4', '-x+1/2', '3/4'], ['x+1/2', '3/4', '3/4'], ['-x+1/2', '3/4', '1/4'], ['3/4', '3/4', 'x+1/2'], ['3/4', '1/4', '-x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y+1/2', 'x+1/2', 'z+1/2'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', '-x+1/2', '-z+1/2'], ['-y+1/2', 'x+1/2', '-z+1/2'], ['x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', 'z+1/2', '-y+1/2'], ['-x+1/2', '-z+1/2', 'y+1/2'], ['x+1/2', '-z+1/2', '-y+1/2'], ['z+1/2', 'y+1/2', 'x+1/2'], ['z+1/2', '-y+1/2', '-x+1/2'], ['-z+1/2', 'y+1/2', '-x+1/2'], ['-z+1/2', '-y+1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    220: {
        "a": {
            "constants": array([[ 0.375, 0.   , 0.25 ], [ 0.125, 0.   , 0.75 ], [ 0.25 , 0.375, 0.   ], [ 0.75 , 0.125, 0.   ], [ 0.   , 0.25 , 0.375], [ 0.   , 0.75 , 0.125]]),
            "expressions": [['3/8', '0', '1/4'], ['1/8', '0', '3/4'], ['1/4', '3/8', '0'], ['3/4', '1/8', '0'], ['0', '1/4', '3/8'], ['0', '3/4', '1/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.875, 0.   , 0.25 ], [ 0.625, 0.   , 0.75 ], [ 0.25 , 0.875, 0.   ], [ 0.75 , 0.625, 0.   ], [ 0.   , 0.25 , 0.875], [ 0.   , 0.75 , 0.625]]),
            "expressions": [['7/8', '0', '1/4'], ['5/8', '0', '3/4'], ['1/4', '7/8', '0'], ['3/4', '5/8', '0'], ['0', '1/4', '7/8'], ['0', '3/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['x+1/4', 'x+1/4', 'x+1/4'], ['-x+1/4', '-x+3/4', 'x+3/4'], ['x+3/4', '-x+1/4', '-x+3/4'], ['-x+3/4', 'x+3/4', '-x+1/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "d": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.25, 0.25, 0.5 ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.5 , 0.25], [ 0.75, 0.  , 0.25], [ 0.5 , 0.25, 0.25], [ 0.  , 0.25, 0.75]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['1/4', 'x', '0'], ['3/4', '-x+1/2', '0'], ['0', '1/4', 'x'], ['0', '3/4', '-x+1/2'], ['1/4', 'x+1/4', '1/2'], ['1/4', '-x+3/4', '0'], ['x+1/4', '1/2', '1/4'], ['-x+3/4', '0', '1/4'], ['1/2', '1/4', 'x+1/4'], ['0', '1/4', '-x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['y+1/4', 'x+1/4', 'z+1/4'], ['-y+1/4', '-x+3/4', 'z+3/4'], ['y+3/4', '-x+1/4', '-z+3/4'], ['-y+3/4', 'x+3/4', '-z+1/4'], ['x+1/4', 'z+1/4', 'y+1/4'], ['-x+3/4', 'z+3/4', '-y+1/4'], ['-x+1/4', '-z+3/4', 'y+3/4'], ['x+3/4', '-z+1/4', '-y+3/4'], ['z+1/4', 'y+1/4', 'x+1/4'], ['z+3/4', '-y+1/4', '-x+3/4'], ['-z+3/4', 'y+3/4', '-x+1/4'], ['-z+1/4', '-y+3/4', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    221: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ]]),
            "expressions": [['x', '1/2', '1/2'], ['-x', '1/2', '1/2'], ['1/2', 'x', '1/2'], ['1/2', '-x', '1/2'], ['1/2', '1/2', 'x'], ['1/2', '1/2', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['x', '0', '1/2'], ['-x', '0', '1/2'], ['0', '1/2', '-x'], ['0', '1/2', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'y'], ['1/2', '-y', 'y'], ['1/2', 'y', '-y'], ['1/2', '-y', '-y'], ['y', '1/2', 'y'], ['y', '1/2', '-y'], ['-y', '1/2', 'y'], ['-y', '1/2', '-y'], ['y', 'y', '1/2'], ['-y', 'y', '1/2'], ['y', '-y', '1/2'], ['-y', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0'], ['y', '0', '-z'], ['-y', '0', '-z'], ['y', '0', 'z'], ['-y', '0', 'z'], ['0', 'z', '-y'], ['0', 'z', 'y'], ['0', '-z', '-y'], ['0', '-z', 'y'], ['z', 'y', '0'], ['z', '-y', '0'], ['-z', 'y', '0'], ['-z', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "l": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'z'], ['1/2', '-y', 'z'], ['1/2', 'y', '-z'], ['1/2', '-y', '-z'], ['z', '1/2', 'y'], ['z', '1/2', '-y'], ['-z', '1/2', 'y'], ['-z', '1/2', '-y'], ['y', 'z', '1/2'], ['-y', 'z', '1/2'], ['y', '-z', '1/2'], ['-y', '-z', '1/2'], ['y', '1/2', '-z'], ['-y', '1/2', '-z'], ['y', '1/2', 'z'], ['-y', '1/2', 'z'], ['1/2', 'z', '-y'], ['1/2', 'z', 'y'], ['1/2', '-z', '-y'], ['1/2', '-z', 'y'], ['z', 'y', '1/2'], ['z', '-y', '1/2'], ['-z', 'y', '1/2'], ['-z', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "m": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x'], ['x', 'x', '-z'], ['-x', '-x', '-z'], ['x', '-x', 'z'], ['-x', 'x', 'z'], ['x', 'z', '-x'], ['-x', 'z', 'x'], ['-x', '-z', '-x'], ['x', '-z', 'x'], ['z', 'x', '-x'], ['z', '-x', 'x'], ['-z', 'x', 'x'], ['-z', '-x', '-x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]]]),
            "variables": {'z', 'x'},
        },
        "n": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x'], ['-y', '-x', 'z'], ['y', 'x', 'z'], ['-y', 'x', '-z'], ['y', '-x', '-z'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-z', '-y', 'x'], ['-z', 'y', '-x'], ['z', '-y', '-x'], ['z', 'y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    222: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0'], ['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['3/4', '3/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2'], ['1/2', '1/4', '0'], ['1/2', '3/4', '0'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['1/2', '0', '3/4'], ['1/2', '0', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x+1/4', '1/2', '1/2'], ['-x+3/4', '1/2', '1/2'], ['1/2', 'x+1/4', '1/2'], ['1/2', '-x+3/4', '1/2'], ['1/2', '1/2', 'x+1/4'], ['1/2', '1/2', '-x+3/4'], ['-x+1/4', '0', '0'], ['x+3/4', '0', '0'], ['0', '-x+1/4', '0'], ['0', 'x+3/4', '0'], ['0', '0', '-x+1/4'], ['0', '0', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['x+1/4', 'x+1/4', 'x+1/4'], ['-x+3/4', '-x+3/4', 'x+1/4'], ['-x+3/4', 'x+1/4', '-x+3/4'], ['x+1/4', '-x+3/4', '-x+3/4'], ['x+1/4', 'x+1/4', '-x+3/4'], ['-x+3/4', '-x+3/4', '-x+3/4'], ['x+1/4', '-x+3/4', 'x+1/4'], ['-x+3/4', 'x+1/4', 'x+1/4'], ['-x+1/4', '-x+1/4', '-x+1/4'], ['x+3/4', 'x+3/4', '-x+1/4'], ['x+3/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+3/4'], ['-x+1/4', '-x+1/4', 'x+3/4'], ['x+3/4', 'x+3/4', 'x+3/4'], ['-x+1/4', 'x+3/4', '-x+1/4'], ['x+3/4', '-x+1/4', '-x+1/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['x+1/4', '0', '1/2'], ['-x+3/4', '0', '1/2'], ['1/2', 'x+1/4', '0'], ['1/2', '-x+3/4', '0'], ['0', '1/2', 'x+1/4'], ['0', '1/2', '-x+3/4'], ['0', 'x+1/4', '1/2'], ['0', '-x+3/4', '1/2'], ['x+1/4', '1/2', '0'], ['-x+3/4', '1/2', '0'], ['1/2', '0', '-x+3/4'], ['1/2', '0', 'x+1/4'], ['-x+1/4', '1/2', '0'], ['x+3/4', '1/2', '0'], ['0', '-x+1/4', '1/2'], ['0', 'x+3/4', '1/2'], ['1/2', '0', '-x+1/4'], ['1/2', '0', 'x+3/4'], ['1/2', '-x+1/4', '0'], ['1/2', 'x+3/4', '0'], ['-x+1/4', '0', '1/2'], ['x+3/4', '0', '1/2'], ['0', '1/2', 'x+3/4'], ['0', '1/2', '-x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.5 , 0.25, 0.25], [ 0.5 , 0.75, 0.25], [ 0.5 , 0.25, 0.75], [ 0.5 , 0.75, 0.75], [ 0.25, 0.5 , 0.25], [ 0.25, 0.5 , 0.75], [ 0.75, 0.5 , 0.25], [ 0.75, 0.5 , 0.75], [ 0.25, 0.25, 0.5 ], [ 0.75, 0.25, 0.5 ], [ 0.25, 0.75, 0.5 ], [ 0.75, 0.75, 0.5 ], [ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.  , 0.25, 0.75], [ 0.  , 0.75, 0.75], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.75, 0.  , 0.25], [ 0.75, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.75, 0.  ], [ 0.75, 0.75, 0.  ]]),
            "expressions": [['1/2', 'y+1/4', 'y+1/4'], ['1/2', '-y+3/4', 'y+1/4'], ['1/2', 'y+1/4', '-y+3/4'], ['1/2', '-y+3/4', '-y+3/4'], ['y+1/4', '1/2', 'y+1/4'], ['y+1/4', '1/2', '-y+3/4'], ['-y+3/4', '1/2', 'y+1/4'], ['-y+3/4', '1/2', '-y+3/4'], ['y+1/4', 'y+1/4', '1/2'], ['-y+3/4', 'y+1/4', '1/2'], ['y+1/4', '-y+3/4', '1/2'], ['-y+3/4', '-y+3/4', '1/2'], ['0', '-y+1/4', '-y+1/4'], ['0', 'y+3/4', '-y+1/4'], ['0', '-y+1/4', 'y+3/4'], ['0', 'y+3/4', 'y+3/4'], ['-y+1/4', '0', '-y+1/4'], ['-y+1/4', '0', 'y+3/4'], ['y+3/4', '0', '-y+1/4'], ['y+3/4', '0', 'y+3/4'], ['-y+1/4', '-y+1/4', '0'], ['y+3/4', '-y+1/4', '0'], ['-y+1/4', 'y+3/4', '0'], ['y+3/4', 'y+3/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['x+1/4', 'y+1/4', 'z+1/4'], ['-x+3/4', '-y+3/4', 'z+1/4'], ['-x+3/4', 'y+1/4', '-z+3/4'], ['x+1/4', '-y+3/4', '-z+3/4'], ['z+1/4', 'x+1/4', 'y+1/4'], ['z+1/4', '-x+3/4', '-y+3/4'], ['-z+3/4', '-x+3/4', 'y+1/4'], ['-z+3/4', 'x+1/4', '-y+3/4'], ['y+1/4', 'z+1/4', 'x+1/4'], ['-y+3/4', 'z+1/4', '-x+3/4'], ['y+1/4', '-z+3/4', '-x+3/4'], ['-y+3/4', '-z+3/4', 'x+1/4'], ['y+1/4', 'x+1/4', '-z+3/4'], ['-y+3/4', '-x+3/4', '-z+3/4'], ['y+1/4', '-x+3/4', 'z+1/4'], ['-y+3/4', 'x+1/4', 'z+1/4'], ['x+1/4', 'z+1/4', '-y+3/4'], ['-x+3/4', 'z+1/4', 'y+1/4'], ['-x+3/4', '-z+3/4', '-y+3/4'], ['x+1/4', '-z+3/4', 'y+1/4'], ['z+1/4', 'y+1/4', '-x+3/4'], ['z+1/4', '-y+3/4', 'x+1/4'], ['-z+3/4', 'y+1/4', 'x+1/4'], ['-z+3/4', '-y+3/4', '-x+3/4'], ['-x+1/4', '-y+1/4', '-z+1/4'], ['x+3/4', 'y+3/4', '-z+1/4'], ['x+3/4', '-y+1/4', 'z+3/4'], ['-x+1/4', 'y+3/4', 'z+3/4'], ['-z+1/4', '-x+1/4', '-y+1/4'], ['-z+1/4', 'x+3/4', 'y+3/4'], ['z+3/4', 'x+3/4', '-y+1/4'], ['z+3/4', '-x+1/4', 'y+3/4'], ['-y+1/4', '-z+1/4', '-x+1/4'], ['y+3/4', '-z+1/4', 'x+3/4'], ['-y+1/4', 'z+3/4', 'x+3/4'], ['y+3/4', 'z+3/4', '-x+1/4'], ['-y+1/4', '-x+1/4', 'z+3/4'], ['y+3/4', 'x+3/4', 'z+3/4'], ['-y+1/4', 'x+3/4', '-z+1/4'], ['y+3/4', '-x+1/4', '-z+1/4'], ['-x+1/4', '-z+1/4', 'y+3/4'], ['x+3/4', '-z+1/4', '-y+1/4'], ['x+3/4', 'z+3/4', 'y+3/4'], ['-x+1/4', 'z+3/4', '-y+1/4'], ['-z+1/4', '-y+1/4', 'x+3/4'], ['-z+1/4', 'y+3/4', '-x+1/4'], ['z+3/4', '-y+1/4', '-x+1/4'], ['z+3/4', 'y+3/4', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    223: {
        "a": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0. , 0. , 0.5]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0'], ['0', '1/2', '0'], ['1/2', '0', '0'], ['0', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2'], ['1/2', '1/4', '0'], ['1/2', '3/4', '0'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75]]),
            "expressions": [['1/4', '1/2', '0'], ['3/4', '1/2', '0'], ['0', '1/4', '1/2'], ['0', '3/4', '1/2'], ['1/2', '0', '1/4'], ['1/2', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "f": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x'], ['1/2', 'x+1/2', '1/2'], ['1/2', '-x+1/2', '1/2'], ['x+1/2', '1/2', '1/2'], ['-x+1/2', '1/2', '1/2'], ['1/2', '1/2', '-x+1/2'], ['1/2', '1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x'], ['1/2', 'x+1/2', '0'], ['1/2', '-x+1/2', '0'], ['x+1/2', '0', '1/2'], ['-x+1/2', '0', '1/2'], ['0', '1/2', '-x+1/2'], ['0', '1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ], [ 0.5, 0.5, 0. ], [ 0.5, 0. , 0.5], [ 0.5, 0. , 0.5]]),
            "expressions": [['x', '1/2', '0'], ['-x', '1/2', '0'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['1/2', '0', 'x'], ['1/2', '0', '-x'], ['0', 'x+1/2', '1/2'], ['0', '-x+1/2', '1/2'], ['x+1/2', '1/2', '0'], ['-x+1/2', '1/2', '0'], ['1/2', '0', '-x+1/2'], ['1/2', '0', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x+1/2', 'x+1/2', '-x+1/2'], ['-x+1/2', '-x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x+1/2'], ['-x', '-x', '-x'], ['x', 'x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x'], ['-x+1/2', '-x+1/2', 'x+1/2'], ['x+1/2', 'x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x+1/2']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "j": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', 'y', 'y+1/2'], ['3/4', '-y', 'y+1/2'], ['3/4', 'y', '-y+1/2'], ['1/4', '-y', '-y+1/2'], ['y+1/2', '1/4', 'y'], ['y+1/2', '3/4', '-y'], ['-y+1/2', '3/4', 'y'], ['-y+1/2', '1/4', '-y'], ['y', 'y+1/2', '1/4'], ['-y', 'y+1/2', '3/4'], ['y', '-y+1/2', '3/4'], ['-y', '-y+1/2', '1/4'], ['3/4', '-y', '-y+1/2'], ['1/4', 'y', '-y+1/2'], ['1/4', '-y', 'y+1/2'], ['3/4', 'y', 'y+1/2'], ['-y+1/2', '3/4', '-y'], ['-y+1/2', '1/4', 'y'], ['y+1/2', '1/4', '-y'], ['y+1/2', '3/4', 'y'], ['-y', '-y+1/2', '3/4'], ['y', '-y+1/2', '1/4'], ['-y', 'y+1/2', '1/4'], ['y', 'y+1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0'], ['y+1/2', '1/2', '-z+1/2'], ['-y+1/2', '1/2', '-z+1/2'], ['y+1/2', '1/2', 'z+1/2'], ['-y+1/2', '1/2', 'z+1/2'], ['1/2', 'z+1/2', '-y+1/2'], ['1/2', 'z+1/2', 'y+1/2'], ['1/2', '-z+1/2', '-y+1/2'], ['1/2', '-z+1/2', 'y+1/2'], ['z+1/2', 'y+1/2', '1/2'], ['z+1/2', '-y+1/2', '1/2'], ['-z+1/2', 'y+1/2', '1/2'], ['-z+1/2', '-y+1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "l": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['x+1/2', 'z+1/2', '-y+1/2'], ['-x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', '-z+1/2', '-y+1/2'], ['x+1/2', '-z+1/2', 'y+1/2'], ['z+1/2', 'y+1/2', '-x+1/2'], ['z+1/2', '-y+1/2', 'x+1/2'], ['-z+1/2', 'y+1/2', 'x+1/2'], ['-z+1/2', '-y+1/2', '-x+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2'], ['-y+1/2', 'x+1/2', '-z+1/2'], ['y+1/2', '-x+1/2', '-z+1/2'], ['-x+1/2', '-z+1/2', 'y+1/2'], ['x+1/2', '-z+1/2', '-y+1/2'], ['x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', 'z+1/2', '-y+1/2'], ['-z+1/2', '-y+1/2', 'x+1/2'], ['-z+1/2', 'y+1/2', '-x+1/2'], ['z+1/2', '-y+1/2', '-x+1/2'], ['z+1/2', 'y+1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    224: {
        "a": {
            "constants": array([[ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25]]),
            "expressions": [['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4'], ['3/4', '1/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0.5, 0. , 0.5], [ 0. , 0.5, 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['1/2', '0', '0'], ['0', '1/2', '0'], ['0', '0', '1/2'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['x+1/4', 'x+1/4', 'x+1/4'], ['-x+3/4', '-x+3/4', 'x+1/4'], ['-x+3/4', 'x+1/4', '-x+3/4'], ['x+1/4', '-x+3/4', '-x+3/4'], ['x+3/4', 'x+3/4', '-x+1/4'], ['-x+1/4', '-x+1/4', '-x+1/4'], ['x+3/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+3/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.25, 0.5 ], [ 0.5 , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25]]),
            "expressions": [['3/4', '1/2', '0'], ['1/4', '1/2', '0'], ['0', '3/4', '1/2'], ['0', '1/4', '1/2'], ['1/2', '0', '3/4'], ['1/2', '0', '1/4'], ['3/4', '0', '1/2'], ['1/4', '0', '1/2'], ['1/2', '3/4', '0'], ['1/2', '1/4', '0'], ['0', '1/2', '3/4'], ['0', '1/2', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "g": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.5 , 0.5 ], [ 0.5 , 0.25, 0.5 ], [ 0.5 , 0.75, 0.5 ], [ 0.5 , 0.5 , 0.25], [ 0.5 , 0.5 , 0.75], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['x+1/4', '1/2', '1/2'], ['-x+3/4', '1/2', '1/2'], ['1/2', 'x+1/4', '1/2'], ['1/2', '-x+3/4', '1/2'], ['1/2', '1/2', 'x+1/4'], ['1/2', '1/2', '-x+3/4'], ['0', 'x+3/4', '0'], ['0', '-x+1/4', '0'], ['x+3/4', '0', '0'], ['-x+1/4', '0', '0'], ['0', '0', '-x+1/4'], ['0', '0', 'x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.25, 0.5 , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.  , 0.75, 0.5 ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.  , 0.75, 0.5 ], [ 0.  , 0.25, 0.5 ], [ 0.75, 0.5 , 0.  ], [ 0.25, 0.5 , 0.  ], [ 0.5 , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['x+1/4', '1/2', '0'], ['-x+3/4', '1/2', '0'], ['0', 'x+1/4', '1/2'], ['0', '-x+3/4', '1/2'], ['1/2', '0', 'x+1/4'], ['1/2', '0', '-x+3/4'], ['0', 'x+3/4', '1/2'], ['0', '-x+1/4', '1/2'], ['x+3/4', '1/2', '0'], ['-x+1/4', '1/2', '0'], ['1/2', '0', '-x+1/4'], ['1/2', '0', 'x+3/4'], ['-x+1/4', '0', '1/2'], ['x+3/4', '0', '1/2'], ['1/2', '-x+1/4', '0'], ['1/2', 'x+3/4', '0'], ['0', '1/2', '-x+1/4'], ['0', '1/2', 'x+3/4'], ['1/2', '-x+3/4', '0'], ['1/2', 'x+1/4', '0'], ['-x+3/4', '0', '1/2'], ['x+1/4', '0', '1/2'], ['0', '1/2', 'x+1/4'], ['0', '1/2', '-x+3/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "i": {
            "constants": array([[ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75]]),
            "expressions": [['3/4', 'y+1/4', 'y+3/4'], ['1/4', '-y+3/4', 'y+3/4'], ['1/4', 'y+1/4', '-y+1/4'], ['3/4', '-y+3/4', '-y+1/4'], ['y+3/4', '3/4', 'y+1/4'], ['y+3/4', '1/4', '-y+3/4'], ['-y+1/4', '1/4', 'y+1/4'], ['-y+1/4', '3/4', '-y+3/4'], ['y+1/4', 'y+3/4', '3/4'], ['-y+3/4', 'y+3/4', '1/4'], ['y+1/4', '-y+1/4', '1/4'], ['-y+3/4', '-y+1/4', '3/4'], ['3/4', '-y+1/4', '-y+3/4'], ['1/4', 'y+3/4', '-y+3/4'], ['1/4', '-y+1/4', 'y+1/4'], ['3/4', 'y+3/4', 'y+1/4'], ['-y+3/4', '3/4', '-y+1/4'], ['-y+3/4', '1/4', 'y+3/4'], ['y+1/4', '1/4', '-y+1/4'], ['y+1/4', '3/4', 'y+3/4'], ['-y+1/4', '-y+3/4', '3/4'], ['y+3/4', '-y+3/4', '1/4'], ['-y+1/4', 'y+1/4', '1/4'], ['y+3/4', 'y+1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.75, 0.75], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['3/4', 'y+1/4', '-y+1/4'], ['1/4', '-y+3/4', '-y+1/4'], ['1/4', 'y+1/4', 'y+3/4'], ['3/4', '-y+3/4', 'y+3/4'], ['-y+1/4', '3/4', 'y+1/4'], ['-y+1/4', '1/4', '-y+3/4'], ['y+3/4', '1/4', 'y+1/4'], ['y+3/4', '3/4', '-y+3/4'], ['y+1/4', '-y+1/4', '3/4'], ['-y+3/4', '-y+1/4', '1/4'], ['y+1/4', 'y+3/4', '1/4'], ['-y+3/4', 'y+3/4', '3/4'], ['3/4', '-y+1/4', 'y+1/4'], ['1/4', 'y+3/4', 'y+1/4'], ['1/4', '-y+1/4', '-y+3/4'], ['3/4', 'y+3/4', '-y+3/4'], ['y+1/4', '3/4', '-y+1/4'], ['y+1/4', '1/4', 'y+3/4'], ['-y+3/4', '1/4', '-y+1/4'], ['-y+3/4', '3/4', 'y+3/4'], ['-y+1/4', 'y+1/4', '3/4'], ['y+3/4', 'y+1/4', '1/4'], ['-y+1/4', '-y+3/4', '1/4'], ['y+3/4', '-y+3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "k": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x+1/4', 'x+1/4', 'z+1/4'], ['-x+3/4', '-x+3/4', 'z+1/4'], ['-x+3/4', 'x+1/4', '-z+3/4'], ['x+1/4', '-x+3/4', '-z+3/4'], ['z+1/4', 'x+1/4', 'x+1/4'], ['z+1/4', '-x+3/4', '-x+3/4'], ['-z+3/4', '-x+3/4', 'x+1/4'], ['-z+3/4', 'x+1/4', '-x+3/4'], ['x+1/4', 'z+1/4', 'x+1/4'], ['-x+3/4', 'z+1/4', '-x+3/4'], ['x+1/4', '-z+3/4', '-x+3/4'], ['-x+3/4', '-z+3/4', 'x+1/4'], ['x+3/4', 'x+3/4', '-z+1/4'], ['-x+1/4', '-x+1/4', '-z+1/4'], ['x+3/4', '-x+1/4', 'z+3/4'], ['-x+1/4', 'x+3/4', 'z+3/4'], ['x+3/4', 'z+3/4', '-x+1/4'], ['-x+1/4', 'z+3/4', 'x+3/4'], ['-x+1/4', '-z+1/4', '-x+1/4'], ['x+3/4', '-z+1/4', 'x+3/4'], ['z+3/4', 'x+3/4', '-x+1/4'], ['z+3/4', '-x+1/4', 'x+3/4'], ['-z+1/4', 'x+3/4', 'x+3/4'], ['-z+1/4', '-x+1/4', '-x+1/4']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.25, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x+1/4', 'y+1/4', 'z+1/4'], ['-x+3/4', '-y+3/4', 'z+1/4'], ['-x+3/4', 'y+1/4', '-z+3/4'], ['x+1/4', '-y+3/4', '-z+3/4'], ['z+1/4', 'x+1/4', 'y+1/4'], ['z+1/4', '-x+3/4', '-y+3/4'], ['-z+3/4', '-x+3/4', 'y+1/4'], ['-z+3/4', 'x+1/4', '-y+3/4'], ['y+1/4', 'z+1/4', 'x+1/4'], ['-y+3/4', 'z+1/4', '-x+3/4'], ['y+1/4', '-z+3/4', '-x+3/4'], ['-y+3/4', '-z+3/4', 'x+1/4'], ['y+3/4', 'x+3/4', '-z+1/4'], ['-y+1/4', '-x+1/4', '-z+1/4'], ['y+3/4', '-x+1/4', 'z+3/4'], ['-y+1/4', 'x+3/4', 'z+3/4'], ['x+3/4', 'z+3/4', '-y+1/4'], ['-x+1/4', 'z+3/4', 'y+3/4'], ['-x+1/4', '-z+1/4', '-y+1/4'], ['x+3/4', '-z+1/4', 'y+3/4'], ['z+3/4', 'y+3/4', '-x+1/4'], ['z+3/4', '-y+1/4', 'x+3/4'], ['-z+1/4', 'y+3/4', 'x+3/4'], ['-z+1/4', '-y+1/4', '-x+1/4'], ['-x+1/4', '-y+1/4', '-z+1/4'], ['x+3/4', 'y+3/4', '-z+1/4'], ['x+3/4', '-y+1/4', 'z+3/4'], ['-x+1/4', 'y+3/4', 'z+3/4'], ['-z+1/4', '-x+1/4', '-y+1/4'], ['-z+1/4', 'x+3/4', 'y+3/4'], ['z+3/4', 'x+3/4', '-y+1/4'], ['z+3/4', '-x+1/4', 'y+3/4'], ['-y+1/4', '-z+1/4', '-x+1/4'], ['y+3/4', '-z+1/4', 'x+3/4'], ['-y+1/4', 'z+3/4', 'x+3/4'], ['y+3/4', 'z+3/4', '-x+1/4'], ['-y+3/4', '-x+3/4', 'z+1/4'], ['y+1/4', 'x+1/4', 'z+1/4'], ['-y+3/4', 'x+1/4', '-z+3/4'], ['y+1/4', '-x+3/4', '-z+3/4'], ['-x+3/4', '-z+3/4', 'y+1/4'], ['x+1/4', '-z+3/4', '-y+3/4'], ['x+1/4', 'z+1/4', 'y+1/4'], ['-x+3/4', 'z+1/4', '-y+3/4'], ['-z+3/4', '-y+3/4', 'x+1/4'], ['-z+3/4', 'y+1/4', '-x+3/4'], ['z+1/4', '-y+3/4', '-x+3/4'], ['z+1/4', 'y+1/4', 'x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([]),
    },
    225: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5, 0.5, 0.5]]),
            "expressions": [['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.25, 0.25, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['1/4', '1/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4'], ['1/4', '0', '1/4'], ['1/4', '0', '3/4'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.25, 0.  , 0.75], [ 0.75, 0.  , 0.75], [ 0.  , 0.25, 0.75], [ 0.  , 0.25, 0.25], [ 0.25, 0.25, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x'], ['1/4', 'x', '3/4'], ['3/4', '-x', '3/4'], ['x', '1/4', '3/4'], ['-x', '1/4', '1/4'], ['1/4', '1/4', '-x'], ['1/4', '3/4', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5]]),
            "expressions": [['1/2', 'y', 'y'], ['1/2', '-y', 'y'], ['1/2', 'y', '-y'], ['1/2', '-y', '-y'], ['y', '1/2', 'y'], ['y', '1/2', '-y'], ['-y', '1/2', 'y'], ['-y', '1/2', '-y'], ['y', 'y', '1/2'], ['-y', 'y', '1/2'], ['y', '-y', '1/2'], ['-y', '-y', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0'], ['y', '0', '-z'], ['-y', '0', '-z'], ['y', '0', 'z'], ['-y', '0', 'z'], ['0', 'z', '-y'], ['0', 'z', 'y'], ['0', '-z', '-y'], ['0', '-z', 'y'], ['z', 'y', '0'], ['z', '-y', '0'], ['-z', 'y', '0'], ['-z', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x'], ['x', 'x', '-z'], ['-x', '-x', '-z'], ['x', '-x', 'z'], ['-x', 'x', 'z'], ['x', 'z', '-x'], ['-x', 'z', 'x'], ['-x', '-z', '-x'], ['x', '-z', 'x'], ['z', 'x', '-x'], ['z', '-x', 'x'], ['-z', 'x', 'x'], ['-z', '-x', '-x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x'], ['-y', '-x', 'z'], ['y', 'x', 'z'], ['-y', 'x', '-z'], ['y', '-x', '-z'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-z', '-y', 'x'], ['-z', 'y', '-x'], ['z', '-y', '-x'], ['z', 'y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    226: {
        "a": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', '0', '0'], ['1/2', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['1/4', '0', '0'], ['3/4', '0', '0'], ['0', '1/4', '0'], ['0', '3/4', '0'], ['0', '0', '1/4'], ['0', '0', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['0', '1/4', '1/4'], ['0', '3/4', '1/4'], ['1/4', '0', '1/4'], ['1/4', '0', '3/4'], ['1/4', '1/4', '0'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x'], ['1/2', 'x+1/2', '1/2'], ['1/2', '-x+1/2', '1/2'], ['x+1/2', '1/2', '1/2'], ['-x+1/2', '1/2', '1/2'], ['1/2', '1/2', '-x+1/2'], ['1/2', '1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.25, 0.25], [ 0.  , 0.75, 0.25], [ 0.25, 0.  , 0.25], [ 0.25, 0.  , 0.75], [ 0.25, 0.25, 0.  ], [ 0.75, 0.25, 0.  ], [ 0.  , 0.75, 0.75], [ 0.  , 0.25, 0.75], [ 0.75, 0.  , 0.75], [ 0.75, 0.  , 0.25], [ 0.75, 0.75, 0.  ], [ 0.25, 0.75, 0.  ]]),
            "expressions": [['x', '1/4', '1/4'], ['-x', '3/4', '1/4'], ['1/4', 'x', '1/4'], ['1/4', '-x', '3/4'], ['1/4', '1/4', 'x'], ['3/4', '1/4', '-x'], ['-x', '3/4', '3/4'], ['x', '1/4', '3/4'], ['3/4', '-x', '3/4'], ['3/4', 'x', '1/4'], ['3/4', '3/4', '-x'], ['1/4', '3/4', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x+1/2', 'x+1/2', '-x+1/2'], ['-x+1/2', '-x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x+1/2'], ['-x', '-x', '-x'], ['x', 'x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x'], ['-x+1/2', '-x+1/2', 'x+1/2'], ['x+1/2', 'x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x+1/2']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.75, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.25, 0.  , 0.  ], [ 0.75, 0.  , 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.  , 0.75], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.25], [ 0.  , 0.  , 0.75]]),
            "expressions": [['1/4', 'y', 'y'], ['3/4', '-y', 'y'], ['3/4', 'y', '-y'], ['1/4', '-y', '-y'], ['y', '1/4', 'y'], ['y', '3/4', '-y'], ['-y', '3/4', 'y'], ['-y', '1/4', '-y'], ['y', 'y', '1/4'], ['-y', 'y', '3/4'], ['y', '-y', '3/4'], ['-y', '-y', '1/4'], ['3/4', '-y', '-y'], ['1/4', 'y', '-y'], ['1/4', '-y', 'y'], ['3/4', 'y', 'y'], ['-y', '3/4', '-y'], ['-y', '1/4', 'y'], ['y', '1/4', '-y'], ['y', '3/4', 'y'], ['-y', '-y', '3/4'], ['y', '-y', '1/4'], ['-y', 'y', '1/4'], ['y', 'y', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0'], ['y+1/2', '1/2', '-z+1/2'], ['-y+1/2', '1/2', '-z+1/2'], ['y+1/2', '1/2', 'z+1/2'], ['-y+1/2', '1/2', 'z+1/2'], ['1/2', 'z+1/2', '-y+1/2'], ['1/2', 'z+1/2', 'y+1/2'], ['1/2', '-z+1/2', '-y+1/2'], ['1/2', '-z+1/2', 'y+1/2'], ['z+1/2', 'y+1/2', '1/2'], ['z+1/2', '-y+1/2', '1/2'], ['-z+1/2', 'y+1/2', '1/2'], ['-z+1/2', '-y+1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "j": {
            "constants": array([[ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0. , 0. , 0. ], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5], [ 0.5, 0.5, 0.5]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y+1/2', 'x+1/2', '-z+1/2'], ['-y+1/2', '-x+1/2', '-z+1/2'], ['y+1/2', '-x+1/2', 'z+1/2'], ['-y+1/2', 'x+1/2', 'z+1/2'], ['x+1/2', 'z+1/2', '-y+1/2'], ['-x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', '-z+1/2', '-y+1/2'], ['x+1/2', '-z+1/2', 'y+1/2'], ['z+1/2', 'y+1/2', '-x+1/2'], ['z+1/2', '-y+1/2', 'x+1/2'], ['-z+1/2', 'y+1/2', 'x+1/2'], ['-z+1/2', '-y+1/2', '-x+1/2'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x'], ['-y+1/2', '-x+1/2', 'z+1/2'], ['y+1/2', 'x+1/2', 'z+1/2'], ['-y+1/2', 'x+1/2', '-z+1/2'], ['y+1/2', '-x+1/2', '-z+1/2'], ['-x+1/2', '-z+1/2', 'y+1/2'], ['x+1/2', '-z+1/2', '-y+1/2'], ['x+1/2', 'z+1/2', 'y+1/2'], ['-x+1/2', 'z+1/2', '-y+1/2'], ['-z+1/2', '-y+1/2', 'x+1/2'], ['-z+1/2', 'y+1/2', '-x+1/2'], ['z+1/2', '-y+1/2', '-x+1/2'], ['z+1/2', 'y+1/2', 'x+1/2']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    227: {
        "a": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.  , 0.5 , 0.5 ]]),
            "expressions": [['1/4', '1/4', '1/4'], ['0', '1/2', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.5 , 0.5 , 0.5 ], [ 0.25, 0.75, 0.25]]),
            "expressions": [['1/2', '1/2', '1/2'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375]]),
            "expressions": [['1/8', '1/8', '1/8'], ['7/8', '3/8', '5/8'], ['3/8', '5/8', '7/8'], ['5/8', '7/8', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.375, 0.875, 0.125], [ 0.875, 0.125, 0.375], [ 0.125, 0.375, 0.875]]),
            "expressions": [['5/8', '5/8', '5/8'], ['3/8', '7/8', '1/8'], ['7/8', '1/8', '3/8'], ['1/8', '3/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375]]),
            "expressions": [['x+1/8', 'x+1/8', 'x+1/8'], ['-x+7/8', '-x+3/8', 'x+5/8'], ['-x+3/8', 'x+5/8', '-x+7/8'], ['x+5/8', '-x+7/8', '-x+3/8'], ['x+7/8', 'x+3/8', '-x+5/8'], ['-x+1/8', '-x+1/8', '-x+1/8'], ['x+3/8', '-x+5/8', 'x+7/8'], ['-x+5/8', 'x+7/8', 'x+3/8']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.125, 0.25 , 0.25 ], [ 0.875, 0.25 , 0.75 ], [ 0.25 , 0.125, 0.25 ], [ 0.75 , 0.875, 0.25 ], [ 0.25 , 0.25 , 0.125], [ 0.25 , 0.75 , 0.875], [ 0.   , 0.375, 0.5  ], [ 0.   , 0.125, 0.   ], [ 0.875, 0.5  , 0.5  ], [ 0.625, 0.   , 0.5  ], [ 0.   , 0.5  , 0.625], [ 0.5  , 0.5  , 0.875]]),
            "expressions": [['x+1/8', '1/4', '1/4'], ['-x+7/8', '1/4', '3/4'], ['1/4', 'x+1/8', '1/4'], ['3/4', '-x+7/8', '1/4'], ['1/4', '1/4', 'x+1/8'], ['1/4', '3/4', '-x+7/8'], ['0', 'x+3/8', '1/2'], ['0', '-x+1/8', '0'], ['x+7/8', '1/2', '1/2'], ['-x+5/8', '0', '1/2'], ['0', '1/2', '-x+5/8'], ['1/2', '1/2', 'x+7/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.875, 0.375, 0.625], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125]]),
            "expressions": [['x+1/8', 'x+1/8', 'z+1/8'], ['-x+7/8', '-x+3/8', 'z+5/8'], ['-x+3/8', 'x+5/8', '-z+7/8'], ['x+5/8', '-x+7/8', '-z+3/8'], ['z+1/8', 'x+1/8', 'x+1/8'], ['z+5/8', '-x+7/8', '-x+3/8'], ['-z+7/8', '-x+3/8', 'x+5/8'], ['-z+3/8', 'x+5/8', '-x+7/8'], ['x+1/8', 'z+1/8', 'x+1/8'], ['-x+3/8', 'z+5/8', '-x+7/8'], ['x+5/8', '-z+7/8', '-x+3/8'], ['-x+7/8', '-z+3/8', 'x+5/8'], ['x+7/8', 'x+3/8', '-z+5/8'], ['-x+1/8', '-x+1/8', '-z+1/8'], ['x+3/8', '-x+5/8', 'z+7/8'], ['-x+5/8', 'x+7/8', 'z+3/8'], ['x+7/8', 'z+3/8', '-x+5/8'], ['-x+5/8', 'z+7/8', 'x+3/8'], ['-x+1/8', '-z+1/8', '-x+1/8'], ['x+3/8', '-z+5/8', 'x+7/8'], ['z+7/8', 'x+3/8', '-x+5/8'], ['z+3/8', '-x+5/8', 'x+7/8'], ['-z+5/8', 'x+7/8', 'x+3/8'], ['-z+1/8', '-x+1/8', '-x+1/8']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]]]),
            "variables": {'z', 'x'},
        },
        "h": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.125, 0.125, 0.125], [ 0.625, 0.375, 0.875], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.125, 0.125, 0.125], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.375, 0.875, 0.625]]),
            "expressions": [['1/8', 'y+1/8', '-y+1/8'], ['7/8', '-y+3/8', '-y+5/8'], ['3/8', 'y+5/8', 'y+7/8'], ['5/8', '-y+7/8', 'y+3/8'], ['-y+1/8', '1/8', 'y+1/8'], ['-y+5/8', '7/8', '-y+3/8'], ['y+7/8', '3/8', 'y+5/8'], ['y+3/8', '5/8', '-y+7/8'], ['y+1/8', '-y+1/8', '1/8'], ['-y+3/8', '-y+5/8', '7/8'], ['y+5/8', 'y+7/8', '3/8'], ['-y+7/8', 'y+3/8', '5/8'], ['1/8', '-y+1/8', 'y+1/8'], ['3/8', 'y+7/8', 'y+5/8'], ['7/8', '-y+5/8', '-y+3/8'], ['5/8', 'y+3/8', '-y+7/8'], ['y+1/8', '1/8', '-y+1/8'], ['y+5/8', '3/8', 'y+7/8'], ['-y+3/8', '7/8', '-y+5/8'], ['-y+7/8', '5/8', 'y+3/8'], ['-y+1/8', 'y+1/8', '1/8'], ['y+7/8', 'y+5/8', '3/8'], ['-y+5/8', '-y+3/8', '7/8'], ['y+3/8', '-y+7/8', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.875, 0.375, 0.625], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.875, 0.375, 0.625], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.375, 0.625, 0.875], [ 0.875, 0.375, 0.625], [ 0.375, 0.625, 0.875], [ 0.625, 0.875, 0.375], [ 0.125, 0.125, 0.125], [ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.125, 0.125, 0.125], [ 0.625, 0.375, 0.875], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.125, 0.125, 0.125], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.375, 0.875, 0.625], [ 0.375, 0.875, 0.625], [ 0.125, 0.125, 0.125], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.375, 0.875, 0.625], [ 0.625, 0.375, 0.875], [ 0.125, 0.125, 0.125], [ 0.875, 0.625, 0.375], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.125, 0.125, 0.125]]),
            "expressions": [['x+1/8', 'y+1/8', 'z+1/8'], ['-x+7/8', '-y+3/8', 'z+5/8'], ['-x+3/8', 'y+5/8', '-z+7/8'], ['x+5/8', '-y+7/8', '-z+3/8'], ['z+1/8', 'x+1/8', 'y+1/8'], ['z+5/8', '-x+7/8', '-y+3/8'], ['-z+7/8', '-x+3/8', 'y+5/8'], ['-z+3/8', 'x+5/8', '-y+7/8'], ['y+1/8', 'z+1/8', 'x+1/8'], ['-y+3/8', 'z+5/8', '-x+7/8'], ['y+5/8', '-z+7/8', '-x+3/8'], ['-y+7/8', '-z+3/8', 'x+5/8'], ['y+7/8', 'x+3/8', '-z+5/8'], ['-y+1/8', '-x+1/8', '-z+1/8'], ['y+3/8', '-x+5/8', 'z+7/8'], ['-y+5/8', 'x+7/8', 'z+3/8'], ['x+7/8', 'z+3/8', '-y+5/8'], ['-x+5/8', 'z+7/8', 'y+3/8'], ['-x+1/8', '-z+1/8', '-y+1/8'], ['x+3/8', '-z+5/8', 'y+7/8'], ['z+7/8', 'y+3/8', '-x+5/8'], ['z+3/8', '-y+5/8', 'x+7/8'], ['-z+5/8', 'y+7/8', 'x+3/8'], ['-z+1/8', '-y+1/8', '-x+1/8'], ['-x+1/8', '-y+1/8', '-z+1/8'], ['x+3/8', 'y+7/8', '-z+5/8'], ['x+7/8', '-y+5/8', 'z+3/8'], ['-x+5/8', 'y+3/8', 'z+7/8'], ['-z+1/8', '-x+1/8', '-y+1/8'], ['-z+5/8', 'x+3/8', 'y+7/8'], ['z+3/8', 'x+7/8', '-y+5/8'], ['z+7/8', '-x+5/8', 'y+3/8'], ['-y+1/8', '-z+1/8', '-x+1/8'], ['y+7/8', '-z+5/8', 'x+3/8'], ['-y+5/8', 'z+3/8', 'x+7/8'], ['y+3/8', 'z+7/8', '-x+5/8'], ['-y+3/8', '-x+7/8', 'z+5/8'], ['y+1/8', 'x+1/8', 'z+1/8'], ['-y+7/8', 'x+5/8', '-z+3/8'], ['y+5/8', '-x+3/8', '-z+7/8'], ['-x+3/8', '-z+7/8', 'y+5/8'], ['x+5/8', '-z+3/8', '-y+7/8'], ['x+1/8', 'z+1/8', 'y+1/8'], ['-x+7/8', 'z+5/8', '-y+3/8'], ['-z+3/8', '-y+7/8', 'x+5/8'], ['-z+7/8', 'y+5/8', '-x+3/8'], ['z+5/8', '-y+3/8', '-x+7/8'], ['z+1/8', 'y+1/8', 'x+1/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    228: {
        "a": {
            "constants": array([[ 0.5 , 0.5 , 0.5 ], [ 0.25, 0.75, 0.25], [ 0.25, 0.25, 0.25], [ 0.5 , 0.  , 0.5 ]]),
            "expressions": [['1/2', '1/2', '1/2'], ['1/4', '3/4', '1/4'], ['1/4', '1/4', '1/4'], ['1/2', '0', '1/2']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.625, 0.625, 0.625], [ 0.375, 0.875, 0.125], [ 0.875, 0.125, 0.375], [ 0.125, 0.375, 0.875], [ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875]]),
            "expressions": [['5/8', '5/8', '5/8'], ['3/8', '7/8', '1/8'], ['7/8', '1/8', '3/8'], ['1/8', '3/8', '7/8'], ['1/8', '1/8', '1/8'], ['3/8', '7/8', '5/8'], ['7/8', '5/8', '3/8'], ['5/8', '3/8', '7/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.375, 0.375, 0.375], [ 0.625, 0.125, 0.875], [ 0.125, 0.875, 0.625], [ 0.875, 0.625, 0.125], [ 0.125, 0.625, 0.375], [ 0.875, 0.875, 0.875], [ 0.625, 0.375, 0.125], [ 0.375, 0.125, 0.625]]),
            "expressions": [['3/8', '3/8', '3/8'], ['5/8', '1/8', '7/8'], ['1/8', '7/8', '5/8'], ['7/8', '5/8', '1/8'], ['1/8', '5/8', '3/8'], ['7/8', '7/8', '7/8'], ['5/8', '3/8', '1/8'], ['3/8', '1/8', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.5 , 0.5 ], [ 0.75, 0.  , 0.  ], [ 0.5 , 0.25, 0.5 ], [ 0.  , 0.75, 0.  ], [ 0.5 , 0.5 , 0.25], [ 0.  , 0.  , 0.75], [ 0.25, 0.5 , 0.25], [ 0.75, 0.  , 0.75], [ 0.  , 0.75, 0.25], [ 0.5 , 0.25, 0.75], [ 0.25, 0.75, 0.5 ], [ 0.75, 0.25, 0.  ]]),
            "expressions": [['1/4', '1/2', '1/2'], ['3/4', '0', '0'], ['1/2', '1/4', '1/2'], ['0', '3/4', '0'], ['1/2', '1/2', '1/4'], ['0', '0', '3/4'], ['1/4', '1/2', '1/4'], ['3/4', '0', '3/4'], ['0', '3/4', '1/4'], ['1/2', '1/4', '3/4'], ['1/4', '3/4', '1/2'], ['3/4', '1/4', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.375, 0.375, 0.375], [ 0.625, 0.125, 0.875], [ 0.125, 0.875, 0.625], [ 0.875, 0.625, 0.125], [ 0.125, 0.625, 0.375], [ 0.875, 0.875, 0.875], [ 0.625, 0.375, 0.125], [ 0.375, 0.125, 0.625], [ 0.375, 0.375, 0.375], [ 0.125, 0.625, 0.875], [ 0.625, 0.875, 0.125], [ 0.875, 0.125, 0.625], [ 0.625, 0.125, 0.375], [ 0.875, 0.875, 0.875], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125]]),
            "expressions": [['x+3/8', 'x+3/8', 'x+3/8'], ['-x+5/8', '-x+1/8', 'x+7/8'], ['-x+1/8', 'x+7/8', '-x+5/8'], ['x+7/8', '-x+5/8', '-x+1/8'], ['x+1/8', 'x+5/8', '-x+3/8'], ['-x+7/8', '-x+7/8', '-x+7/8'], ['x+5/8', '-x+3/8', 'x+1/8'], ['-x+3/8', 'x+1/8', 'x+5/8'], ['-x+3/8', '-x+3/8', '-x+3/8'], ['x+1/8', 'x+5/8', '-x+7/8'], ['x+5/8', '-x+7/8', 'x+1/8'], ['-x+7/8', 'x+1/8', 'x+5/8'], ['-x+5/8', '-x+1/8', 'x+3/8'], ['x+7/8', 'x+7/8', 'x+7/8'], ['-x+1/8', 'x+3/8', '-x+5/8'], ['x+3/8', '-x+5/8', '-x+1/8']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.375, 0.5  , 0.5  ], [ 0.625, 0.   , 0.   ], [ 0.5  , 0.375, 0.5  ], [ 0.   , 0.625, 0.   ], [ 0.5  , 0.5  , 0.375], [ 0.   , 0.   , 0.625], [ 0.25 , 0.625, 0.25 ], [ 0.75 , 0.875, 0.75 ], [ 0.125, 0.75 , 0.25 ], [ 0.375, 0.25 , 0.75 ], [ 0.25 , 0.75 , 0.375], [ 0.75 , 0.25 , 0.125], [ 0.375, 0.25 , 0.25 ], [ 0.125, 0.75 , 0.75 ], [ 0.25 , 0.375, 0.25 ], [ 0.75 , 0.125, 0.75 ], [ 0.25 , 0.25 , 0.375], [ 0.75 , 0.75 , 0.125], [ 0.5  , 0.125, 0.5  ], [ 0.   , 0.875, 0.   ], [ 0.625, 0.   , 0.5  ], [ 0.375, 0.5  , 0.   ], [ 0.5  , 0.   , 0.375], [ 0.   , 0.5  , 0.625]]),
            "expressions": [['x+3/8', '1/2', '1/2'], ['-x+5/8', '0', '0'], ['1/2', 'x+3/8', '1/2'], ['0', '-x+5/8', '0'], ['1/2', '1/2', 'x+3/8'], ['0', '0', '-x+5/8'], ['1/4', 'x+5/8', '1/4'], ['3/4', '-x+7/8', '3/4'], ['x+1/8', '3/4', '1/4'], ['-x+3/8', '1/4', '3/4'], ['1/4', '3/4', '-x+3/8'], ['3/4', '1/4', 'x+1/8'], ['-x+3/8', '1/4', '1/4'], ['x+1/8', '3/4', '3/4'], ['1/4', '-x+3/8', '1/4'], ['3/4', 'x+1/8', '3/4'], ['1/4', '1/4', '-x+3/8'], ['3/4', '3/4', 'x+1/8'], ['1/2', '-x+1/8', '1/2'], ['0', 'x+7/8', '0'], ['-x+5/8', '0', '1/2'], ['x+3/8', '1/2', '0'], ['1/2', '0', 'x+3/8'], ['0', '1/2', '-x+5/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.625, 0.375, 0.375], [ 0.375, 0.125, 0.875], [ 0.875, 0.875, 0.625], [ 0.125, 0.625, 0.125], [ 0.375, 0.625, 0.375], [ 0.875, 0.375, 0.125], [ 0.625, 0.875, 0.875], [ 0.125, 0.125, 0.625], [ 0.375, 0.375, 0.625], [ 0.125, 0.875, 0.375], [ 0.875, 0.625, 0.875], [ 0.625, 0.125, 0.125], [ 0.125, 0.375, 0.375], [ 0.375, 0.625, 0.875], [ 0.875, 0.875, 0.125], [ 0.625, 0.125, 0.625], [ 0.375, 0.125, 0.375], [ 0.875, 0.375, 0.625], [ 0.125, 0.875, 0.875], [ 0.625, 0.625, 0.125], [ 0.375, 0.375, 0.125], [ 0.625, 0.875, 0.375], [ 0.875, 0.125, 0.875], [ 0.125, 0.625, 0.625]]),
            "expressions": [['5/8', 'y+3/8', '-y+3/8'], ['3/8', '-y+1/8', '-y+7/8'], ['7/8', 'y+7/8', 'y+5/8'], ['1/8', '-y+5/8', 'y+1/8'], ['-y+3/8', '5/8', 'y+3/8'], ['-y+7/8', '3/8', '-y+1/8'], ['y+5/8', '7/8', 'y+7/8'], ['y+1/8', '1/8', '-y+5/8'], ['y+3/8', '-y+3/8', '5/8'], ['-y+1/8', '-y+7/8', '3/8'], ['y+7/8', 'y+5/8', '7/8'], ['-y+5/8', 'y+1/8', '1/8'], ['1/8', '-y+3/8', 'y+3/8'], ['3/8', 'y+5/8', 'y+7/8'], ['7/8', '-y+7/8', '-y+1/8'], ['5/8', 'y+1/8', '-y+5/8'], ['y+3/8', '1/8', '-y+3/8'], ['y+7/8', '3/8', 'y+5/8'], ['-y+1/8', '7/8', '-y+7/8'], ['-y+5/8', '5/8', 'y+1/8'], ['-y+3/8', 'y+3/8', '1/8'], ['y+5/8', 'y+7/8', '3/8'], ['-y+7/8', '-y+1/8', '7/8'], ['y+1/8', '-y+5/8', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.375, 0.375, 0.375], [ 0.625, 0.125, 0.875], [ 0.125, 0.875, 0.625], [ 0.875, 0.625, 0.125], [ 0.375, 0.375, 0.375], [ 0.875, 0.625, 0.125], [ 0.625, 0.125, 0.875], [ 0.125, 0.875, 0.625], [ 0.375, 0.375, 0.375], [ 0.125, 0.875, 0.625], [ 0.875, 0.625, 0.125], [ 0.625, 0.125, 0.875], [ 0.125, 0.625, 0.375], [ 0.875, 0.875, 0.875], [ 0.625, 0.375, 0.125], [ 0.375, 0.125, 0.625], [ 0.125, 0.625, 0.375], [ 0.375, 0.125, 0.625], [ 0.875, 0.875, 0.875], [ 0.625, 0.375, 0.125], [ 0.125, 0.625, 0.375], [ 0.625, 0.375, 0.125], [ 0.375, 0.125, 0.625], [ 0.875, 0.875, 0.875], [ 0.375, 0.375, 0.375], [ 0.125, 0.625, 0.875], [ 0.625, 0.875, 0.125], [ 0.875, 0.125, 0.625], [ 0.375, 0.375, 0.375], [ 0.875, 0.125, 0.625], [ 0.125, 0.625, 0.875], [ 0.625, 0.875, 0.125], [ 0.375, 0.375, 0.375], [ 0.625, 0.875, 0.125], [ 0.875, 0.125, 0.625], [ 0.125, 0.625, 0.875], [ 0.625, 0.125, 0.375], [ 0.875, 0.875, 0.875], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125], [ 0.625, 0.125, 0.375], [ 0.375, 0.625, 0.125], [ 0.875, 0.875, 0.875], [ 0.125, 0.375, 0.625], [ 0.625, 0.125, 0.375], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125], [ 0.875, 0.875, 0.875]]),
            "expressions": [['x+3/8', 'y+3/8', 'z+3/8'], ['-x+5/8', '-y+1/8', 'z+7/8'], ['-x+1/8', 'y+7/8', '-z+5/8'], ['x+7/8', '-y+5/8', '-z+1/8'], ['z+3/8', 'x+3/8', 'y+3/8'], ['z+7/8', '-x+5/8', '-y+1/8'], ['-z+5/8', '-x+1/8', 'y+7/8'], ['-z+1/8', 'x+7/8', '-y+5/8'], ['y+3/8', 'z+3/8', 'x+3/8'], ['-y+1/8', 'z+7/8', '-x+5/8'], ['y+7/8', '-z+5/8', '-x+1/8'], ['-y+5/8', '-z+1/8', 'x+7/8'], ['y+1/8', 'x+5/8', '-z+3/8'], ['-y+7/8', '-x+7/8', '-z+7/8'], ['y+5/8', '-x+3/8', 'z+1/8'], ['-y+3/8', 'x+1/8', 'z+5/8'], ['x+1/8', 'z+5/8', '-y+3/8'], ['-x+3/8', 'z+1/8', 'y+5/8'], ['-x+7/8', '-z+7/8', '-y+7/8'], ['x+5/8', '-z+3/8', 'y+1/8'], ['z+1/8', 'y+5/8', '-x+3/8'], ['z+5/8', '-y+3/8', 'x+1/8'], ['-z+3/8', 'y+1/8', 'x+5/8'], ['-z+7/8', '-y+7/8', '-x+7/8'], ['-x+3/8', '-y+3/8', '-z+3/8'], ['x+1/8', 'y+5/8', '-z+7/8'], ['x+5/8', '-y+7/8', 'z+1/8'], ['-x+7/8', 'y+1/8', 'z+5/8'], ['-z+3/8', '-x+3/8', '-y+3/8'], ['-z+7/8', 'x+1/8', 'y+5/8'], ['z+1/8', 'x+5/8', '-y+7/8'], ['z+5/8', '-x+7/8', 'y+1/8'], ['-y+3/8', '-z+3/8', '-x+3/8'], ['y+5/8', '-z+7/8', 'x+1/8'], ['-y+7/8', 'z+1/8', 'x+5/8'], ['y+1/8', 'z+5/8', '-x+7/8'], ['-y+5/8', '-x+1/8', 'z+3/8'], ['y+7/8', 'x+7/8', 'z+7/8'], ['-y+1/8', 'x+3/8', '-z+5/8'], ['y+3/8', '-x+5/8', '-z+1/8'], ['-x+5/8', '-z+1/8', 'y+3/8'], ['x+3/8', '-z+5/8', '-y+1/8'], ['x+7/8', 'z+7/8', 'y+7/8'], ['-x+1/8', 'z+3/8', '-y+5/8'], ['-z+5/8', '-y+1/8', 'x+3/8'], ['-z+1/8', 'y+3/8', '-x+5/8'], ['z+3/8', '-y+5/8', '-x+1/8'], ['z+7/8', 'y+7/8', 'x+7/8']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
    },
    229: {
        "a": {
            "constants": array([[ 0., 0., 0.]]),
            "expressions": [['0', '0', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0. , 0.5, 0.5], [ 0.5, 0. , 0.5], [ 0.5, 0.5, 0. ]]),
            "expressions": [['0', '1/2', '1/2'], ['1/2', '0', '1/2'], ['1/2', '1/2', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75]]),
            "expressions": [['1/4', '1/4', '1/4'], ['3/4', '3/4', '1/4'], ['3/4', '1/4', '3/4'], ['1/4', '3/4', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', '0', '1/2'], ['3/4', '0', '1/2'], ['1/2', '1/4', '0'], ['1/2', '3/4', '0'], ['0', '1/2', '1/4'], ['0', '1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', '0', '0'], ['-x', '0', '0'], ['0', 'x', '0'], ['0', '-x', '0'], ['0', '0', 'x'], ['0', '0', '-x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'x'], ['-x', '-x', 'x'], ['-x', 'x', '-x'], ['x', '-x', '-x'], ['x', 'x', '-x'], ['-x', '-x', '-x'], ['x', '-x', 'x'], ['-x', 'x', 'x']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0. , 0. , 0.5], [ 0. , 0. , 0.5], [ 0. , 0.5, 0. ], [ 0. , 0.5, 0. ], [ 0.5, 0. , 0. ], [ 0.5, 0. , 0. ]]),
            "expressions": [['x', '0', '1/2'], ['-x', '0', '1/2'], ['1/2', 'x', '0'], ['1/2', '-x', '0'], ['0', '1/2', 'x'], ['0', '1/2', '-x'], ['0', 'x', '1/2'], ['0', '-x', '1/2'], ['x', '1/2', '0'], ['-x', '1/2', '0'], ['1/2', '0', '-x'], ['1/2', '0', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "h": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'y'], ['0', '-y', 'y'], ['0', 'y', '-y'], ['0', '-y', '-y'], ['y', '0', 'y'], ['y', '0', '-y'], ['-y', '0', 'y'], ['-y', '0', '-y'], ['y', 'y', '0'], ['-y', 'y', '0'], ['y', '-y', '0'], ['-y', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "i": {
            "constants": array([[ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.75, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.25, 0.  , 0.5 ], [ 0.75, 0.  , 0.5 ], [ 0.5 , 0.75, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.25, 0.  ], [ 0.5 , 0.75, 0.  ], [ 0.  , 0.5 , 0.75], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.25], [ 0.  , 0.5 , 0.75]]),
            "expressions": [['1/4', 'y', '-y+1/2'], ['3/4', '-y', '-y+1/2'], ['3/4', 'y', 'y+1/2'], ['1/4', '-y', 'y+1/2'], ['-y+1/2', '1/4', 'y'], ['-y+1/2', '3/4', '-y'], ['y+1/2', '3/4', 'y'], ['y+1/2', '1/4', '-y'], ['y', '-y+1/2', '1/4'], ['-y', '-y+1/2', '3/4'], ['y', 'y+1/2', '3/4'], ['-y', 'y+1/2', '1/4'], ['3/4', '-y', 'y+1/2'], ['1/4', 'y', 'y+1/2'], ['1/4', '-y', '-y+1/2'], ['3/4', 'y', '-y+1/2'], ['y+1/2', '3/4', '-y'], ['y+1/2', '1/4', 'y'], ['-y+1/2', '1/4', '-y'], ['-y+1/2', '3/4', 'y'], ['-y', 'y+1/2', '3/4'], ['y', 'y+1/2', '1/4'], ['-y', '-y+1/2', '1/4'], ['y', '-y+1/2', '3/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "j": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['0', 'y', 'z'], ['0', '-y', 'z'], ['0', 'y', '-z'], ['0', '-y', '-z'], ['z', '0', 'y'], ['z', '0', '-y'], ['-z', '0', 'y'], ['-z', '0', '-y'], ['y', 'z', '0'], ['-y', 'z', '0'], ['y', '-z', '0'], ['-y', '-z', '0'], ['y', '0', '-z'], ['-y', '0', '-z'], ['y', '0', 'z'], ['-y', '0', 'z'], ['0', 'z', '-y'], ['0', 'z', 'y'], ['0', '-z', '-y'], ['0', '-z', 'y'], ['z', 'y', '0'], ['z', '-y', '0'], ['-z', 'y', '0'], ['-z', '-y', '0']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 0., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[ 0., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 0.],  [-1., 0., 0.]]]),
            "variables": {'y', 'z'},
        },
        "k": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'x', 'z'], ['-x', '-x', 'z'], ['-x', 'x', '-z'], ['x', '-x', '-z'], ['z', 'x', 'x'], ['z', '-x', '-x'], ['-z', '-x', 'x'], ['-z', 'x', '-x'], ['x', 'z', 'x'], ['-x', 'z', '-x'], ['x', '-z', '-x'], ['-x', '-z', 'x'], ['x', 'x', '-z'], ['-x', '-x', '-z'], ['x', '-x', 'z'], ['-x', 'x', 'z'], ['x', 'z', '-x'], ['-x', 'z', 'x'], ['-x', '-z', '-x'], ['x', '-z', 'x'], ['z', 'x', '-x'], ['z', '-x', 'x'], ['-z', 'x', 'x'], ['-z', '-x', '-x']],
            "matrices": array([[[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[-1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0.,-1.]], [[ 1.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[-1., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0.,-1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0., 1.],  [ 0., 0., 0.],  [ 0., 1., 0.]], [[-1., 0.,-1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 1., 0., 1.],  [ 0., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1.,-1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0.,-1., 1.],  [ 0., 0., 0.],  [ 1., 0., 0.]], [[ 0., 1., 1.],  [ 0., 0., 0.],  [-1., 0., 0.]], [[ 0.,-1.,-1.],  [ 0., 0., 0.],  [-1., 0., 0.]]]),
            "variables": {'z', 'x'},
        },
        "l": {
            "constants": array([[ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.], [ 0., 0., 0.]]),
            "expressions": [['x', 'y', 'z'], ['-x', '-y', 'z'], ['-x', 'y', '-z'], ['x', '-y', '-z'], ['z', 'x', 'y'], ['z', '-x', '-y'], ['-z', '-x', 'y'], ['-z', 'x', '-y'], ['y', 'z', 'x'], ['-y', 'z', '-x'], ['y', '-z', '-x'], ['-y', '-z', 'x'], ['y', 'x', '-z'], ['-y', '-x', '-z'], ['y', '-x', 'z'], ['-y', 'x', 'z'], ['x', 'z', '-y'], ['-x', 'z', 'y'], ['-x', '-z', '-y'], ['x', '-z', 'y'], ['z', 'y', '-x'], ['z', '-y', 'x'], ['-z', 'y', 'x'], ['-z', '-y', '-x'], ['-x', '-y', '-z'], ['x', 'y', '-z'], ['x', '-y', 'z'], ['-x', 'y', 'z'], ['-z', '-x', '-y'], ['-z', 'x', 'y'], ['z', 'x', '-y'], ['z', '-x', 'y'], ['-y', '-z', '-x'], ['y', '-z', 'x'], ['-y', 'z', 'x'], ['y', 'z', '-x'], ['-y', '-x', 'z'], ['y', 'x', 'z'], ['-y', 'x', '-z'], ['y', '-x', '-z'], ['-x', '-z', 'y'], ['x', '-z', '-y'], ['x', 'z', 'y'], ['-x', 'z', '-y'], ['-z', '-y', 'x'], ['-z', 'y', '-x'], ['z', '-y', '-x'], ['z', 'y', 'x']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
    230: {
        "a": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25]]),
            "expressions": [['0', '0', '0'], ['1/2', '0', '1/2'], ['0', '1/2', '1/2'], ['1/2', '1/2', '0'], ['3/4', '1/4', '1/4'], ['3/4', '3/4', '3/4'], ['1/4', '1/4', '3/4'], ['1/4', '3/4', '1/4']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "b": {
            "constants": array([[ 0.125, 0.125, 0.125], [ 0.375, 0.875, 0.625], [ 0.875, 0.625, 0.375], [ 0.625, 0.375, 0.875], [ 0.875, 0.875, 0.875], [ 0.625, 0.125, 0.375], [ 0.125, 0.375, 0.625], [ 0.375, 0.625, 0.125]]),
            "expressions": [['1/8', '1/8', '1/8'], ['3/8', '7/8', '5/8'], ['7/8', '5/8', '3/8'], ['5/8', '3/8', '7/8'], ['7/8', '7/8', '7/8'], ['5/8', '1/8', '3/8'], ['1/8', '3/8', '5/8'], ['3/8', '5/8', '1/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "c": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.875, 0.   , 0.75 ], [ 0.625, 0.   , 0.25 ], [ 0.75 , 0.875, 0.   ], [ 0.25 , 0.625, 0.   ], [ 0.   , 0.75 , 0.875], [ 0.   , 0.25 , 0.625]]),
            "expressions": [['1/8', '0', '1/4'], ['3/8', '0', '3/4'], ['1/4', '1/8', '0'], ['3/4', '3/8', '0'], ['0', '1/4', '1/8'], ['0', '3/4', '3/8'], ['7/8', '0', '3/4'], ['5/8', '0', '1/4'], ['3/4', '7/8', '0'], ['1/4', '5/8', '0'], ['0', '3/4', '7/8'], ['0', '1/4', '5/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "d": {
            "constants": array([[ 0.375, 0.   , 0.25 ], [ 0.125, 0.   , 0.75 ], [ 0.25 , 0.375, 0.   ], [ 0.75 , 0.125, 0.   ], [ 0.   , 0.25 , 0.375], [ 0.   , 0.75 , 0.125], [ 0.75 , 0.625, 0.   ], [ 0.75 , 0.375, 0.5  ], [ 0.125, 0.5  , 0.25 ], [ 0.875, 0.   , 0.25 ], [ 0.   , 0.25 , 0.875], [ 0.5  , 0.25 , 0.125]]),
            "expressions": [['3/8', '0', '1/4'], ['1/8', '0', '3/4'], ['1/4', '3/8', '0'], ['3/4', '1/8', '0'], ['0', '1/4', '3/8'], ['0', '3/4', '1/8'], ['3/4', '5/8', '0'], ['3/4', '3/8', '1/2'], ['1/8', '1/2', '1/4'], ['7/8', '0', '1/4'], ['0', '1/4', '7/8'], ['1/2', '1/4', '1/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": set(),
        },
        "e": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75]]),
            "expressions": [['x', 'x', 'x'], ['-x+1/2', '-x', 'x+1/2'], ['-x', 'x+1/2', '-x+1/2'], ['x+1/2', '-x+1/2', '-x'], ['x+3/4', 'x+1/4', '-x+1/4'], ['-x+3/4', '-x+3/4', '-x+3/4'], ['x+1/4', '-x+1/4', 'x+3/4'], ['-x+1/4', 'x+3/4', 'x+1/4'], ['-x', '-x', '-x'], ['x+1/2', 'x', '-x+1/2'], ['x', '-x+1/2', 'x+1/2'], ['-x+1/2', 'x+1/2', 'x'], ['-x+1/4', '-x+3/4', 'x+3/4'], ['x+1/4', 'x+1/4', 'x+1/4'], ['-x+3/4', 'x+3/4', '-x+1/4'], ['x+3/4', '-x+1/4', '-x+3/4']],
            "matrices": array([[[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1.,-1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 1., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1.,-1.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "f": {
            "constants": array([[ 0.  , 0.  , 0.25], [ 0.5 , 0.  , 0.75], [ 0.25, 0.  , 0.  ], [ 0.75, 0.5 , 0.  ], [ 0.  , 0.25, 0.  ], [ 0.  , 0.75, 0.5 ], [ 0.75, 0.25, 0.  ], [ 0.75, 0.75, 0.5 ], [ 0.75, 0.5 , 0.25], [ 0.25, 0.  , 0.25], [ 0.  , 0.25, 0.25], [ 0.5 , 0.25, 0.75], [ 0.  , 0.  , 0.75], [ 0.5 , 0.  , 0.25], [ 0.75, 0.  , 0.  ], [ 0.25, 0.5 , 0.  ], [ 0.  , 0.75, 0.  ], [ 0.  , 0.25, 0.5 ], [ 0.25, 0.75, 0.  ], [ 0.25, 0.25, 0.5 ], [ 0.25, 0.5 , 0.75], [ 0.75, 0.  , 0.75], [ 0.  , 0.75, 0.75], [ 0.5 , 0.75, 0.25]]),
            "expressions": [['x', '0', '1/4'], ['-x+1/2', '0', '3/4'], ['1/4', 'x', '0'], ['3/4', '-x+1/2', '0'], ['0', '1/4', 'x'], ['0', '3/4', '-x+1/2'], ['3/4', 'x+1/4', '0'], ['3/4', '-x+3/4', '1/2'], ['x+3/4', '1/2', '1/4'], ['-x+1/4', '0', '1/4'], ['0', '1/4', '-x+1/4'], ['1/2', '1/4', 'x+3/4'], ['-x', '0', '3/4'], ['x+1/2', '0', '1/4'], ['3/4', '-x', '0'], ['1/4', 'x+1/2', '0'], ['0', '3/4', '-x'], ['0', '1/4', 'x+1/2'], ['1/4', '-x+3/4', '0'], ['1/4', 'x+1/4', '1/2'], ['-x+1/4', '1/2', '3/4'], ['x+3/4', '0', '3/4'], ['0', '3/4', 'x+3/4'], ['1/2', '3/4', '-x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[-1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 1., 0., 0.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0., 1.],  [ 0., 0., 0.],  [ 0., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 0., 0.],  [ 0., 0., 0.]]]),
            "variables": {'x'},
        },
        "g": {
            "constants": array([[ 0.125, 0.   , 0.25 ], [ 0.375, 0.   , 0.75 ], [ 0.875, 0.5  , 0.25 ], [ 0.625, 0.5  , 0.75 ], [ 0.25 , 0.125, 0.   ], [ 0.75 , 0.375, 0.   ], [ 0.25 , 0.875, 0.5  ], [ 0.75 , 0.625, 0.5  ], [ 0.   , 0.25 , 0.125], [ 0.   , 0.75 , 0.375], [ 0.5  , 0.25 , 0.875], [ 0.5  , 0.75 , 0.625], [ 0.875, 0.   , 0.75 ], [ 0.625, 0.   , 0.25 ], [ 0.125, 0.5  , 0.75 ], [ 0.375, 0.5  , 0.25 ], [ 0.75 , 0.875, 0.   ], [ 0.25 , 0.625, 0.   ], [ 0.75 , 0.125, 0.5  ], [ 0.25 , 0.375, 0.5  ], [ 0.   , 0.75 , 0.875], [ 0.   , 0.25 , 0.625], [ 0.5  , 0.75 , 0.125], [ 0.5  , 0.25 , 0.375]]),
            "expressions": [['1/8', 'y', '-y+1/4'], ['3/8', '-y', '-y+3/4'], ['7/8', 'y+1/2', 'y+1/4'], ['5/8', '-y+1/2', 'y+3/4'], ['-y+1/4', '1/8', 'y'], ['-y+3/4', '3/8', '-y'], ['y+1/4', '7/8', 'y+1/2'], ['y+3/4', '5/8', '-y+1/2'], ['y', '-y+1/4', '1/8'], ['-y', '-y+3/4', '3/8'], ['y+1/2', 'y+1/4', '7/8'], ['-y+1/2', 'y+3/4', '5/8'], ['7/8', '-y', 'y+3/4'], ['5/8', 'y', 'y+1/4'], ['1/8', '-y+1/2', '-y+3/4'], ['3/8', 'y+1/2', '-y+1/4'], ['y+3/4', '7/8', '-y'], ['y+1/4', '5/8', 'y'], ['-y+3/4', '1/8', '-y+1/2'], ['-y+1/4', '3/8', 'y+1/2'], ['-y', 'y+3/4', '7/8'], ['y', 'y+1/4', '5/8'], ['-y+1/2', '-y+3/4', '1/8'], ['y+1/2', '-y+1/4', '3/8']],
            "matrices": array([[[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0.,-1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 0., 1.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0.,-1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 0., 1.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1., 1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [-1.,-1., 0.],  [ 0., 0., 0.]], [[ 0., 0., 0.],  [ 1.,-1., 0.],  [ 0., 0., 0.]]]),
            "variables": {'y'},
        },
        "h": {
            "constants": array([[ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.75, 0.25, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.25, 0.25], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.25, 0.25, 0.75], [ 0.75, 0.25, 0.25], [ 0.25, 0.25, 0.75], [ 0.25, 0.75, 0.25], [ 0.75, 0.75, 0.75], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.  , 0.  , 0.  ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.  , 0.5 , 0.5 ], [ 0.  , 0.  , 0.  ], [ 0.  , 0.5 , 0.5 ], [ 0.5 , 0.5 , 0.  ], [ 0.5 , 0.  , 0.5 ], [ 0.25, 0.75, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.75, 0.75], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25], [ 0.75, 0.75, 0.25], [ 0.25, 0.75, 0.75], [ 0.75, 0.75, 0.25], [ 0.75, 0.25, 0.75], [ 0.25, 0.25, 0.25]]),
            "expressions": [['x', 'y', 'z'], ['-x+1/2', '-y', 'z+1/2'], ['-x', 'y+1/2', '-z+1/2'], ['x+1/2', '-y+1/2', '-z'], ['z', 'x', 'y'], ['z+1/2', '-x+1/2', '-y'], ['-z+1/2', '-x', 'y+1/2'], ['-z', 'x+1/2', '-y+1/2'], ['y', 'z', 'x'], ['-y', 'z+1/2', '-x+1/2'], ['y+1/2', '-z+1/2', '-x'], ['-y+1/2', '-z', 'x+1/2'], ['y+3/4', 'x+1/4', '-z+1/4'], ['-y+3/4', '-x+3/4', '-z+3/4'], ['y+1/4', '-x+1/4', 'z+3/4'], ['-y+1/4', 'x+3/4', 'z+1/4'], ['x+3/4', 'z+1/4', '-y+1/4'], ['-x+1/4', 'z+3/4', 'y+1/4'], ['-x+3/4', '-z+3/4', '-y+3/4'], ['x+1/4', '-z+1/4', 'y+3/4'], ['z+3/4', 'y+1/4', '-x+1/4'], ['z+1/4', '-y+1/4', 'x+3/4'], ['-z+1/4', 'y+3/4', 'x+1/4'], ['-z+3/4', '-y+3/4', '-x+3/4'], ['-x', '-y', '-z'], ['x+1/2', 'y', '-z+1/2'], ['x', '-y+1/2', 'z+1/2'], ['-x+1/2', 'y+1/2', 'z'], ['-z', '-x', '-y'], ['-z+1/2', 'x+1/2', 'y'], ['z+1/2', 'x', '-y+1/2'], ['z', '-x+1/2', 'y+1/2'], ['-y', '-z', '-x'], ['y', '-z+1/2', 'x+1/2'], ['-y+1/2', 'z+1/2', 'x'], ['y+1/2', 'z', '-x+1/2'], ['-y+1/4', '-x+3/4', 'z+3/4'], ['y+1/4', 'x+1/4', 'z+1/4'], ['-y+3/4', 'x+3/4', '-z+1/4'], ['y+3/4', '-x+1/4', '-z+3/4'], ['-x+1/4', '-z+3/4', 'y+3/4'], ['x+3/4', '-z+1/4', '-y+3/4'], ['x+1/4', 'z+1/4', 'y+1/4'], ['-x+3/4', 'z+3/4', '-y+1/4'], ['-z+1/4', '-y+3/4', 'x+3/4'], ['-z+3/4', 'y+3/4', '-x+1/4'], ['z+3/4', '-y+1/4', '-x+3/4'], ['z+1/4', 'y+1/4', 'x+1/4']],
            "matrices": array([[[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[-1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0.,-1.]], [[ 1., 0., 0.],  [ 0.,-1., 0.],  [ 0., 0., 1.]], [[-1., 0., 0.],  [ 0., 1., 0.],  [ 0., 0., 1.]], [[ 0.,-1., 0.],  [ 0., 0.,-1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0., 1.],  [-1., 0., 0.]], [[ 0., 1., 0.],  [ 0., 0.,-1.],  [ 1., 0., 0.]], [[ 0.,-1., 0.],  [ 0., 0., 1.],  [ 1., 0., 0.]], [[ 0., 0.,-1.],  [-1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [ 1., 0., 0.],  [ 0.,-1., 0.]], [[ 0., 0., 1.],  [-1., 0., 0.],  [ 0., 1., 0.]], [[ 0., 0.,-1.],  [ 1., 0., 0.],  [ 0., 1., 0.]], [[ 0.,-1., 0.],  [-1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [ 1., 0., 0.],  [ 0., 0., 1.]], [[ 0., 1., 0.],  [-1., 0., 0.],  [ 0., 0.,-1.]], [[ 0.,-1., 0.],  [ 1., 0., 0.],  [ 0., 0.,-1.]], [[-1., 0., 0.],  [ 0., 0., 1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0.,-1.],  [ 0.,-1., 0.]], [[ 1., 0., 0.],  [ 0., 0., 1.],  [ 0., 1., 0.]], [[-1., 0., 0.],  [ 0., 0.,-1.],  [ 0., 1., 0.]], [[ 0., 0., 1.],  [ 0.,-1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0., 1., 0.],  [-1., 0., 0.]], [[ 0., 0.,-1.],  [ 0.,-1., 0.],  [ 1., 0., 0.]], [[ 0., 0., 1.],  [ 0., 1., 0.],  [ 1., 0., 0.]]]),
            "variables": {'y', 'x', 'z'},
        },
        "translations": array([[ 0.5, 0.5, 0.5]]),
    },
}

PROPER_RIGID_TRANSFORMATIONS = {   2: [   {   'permutations': {   'a': 'd',
                                   'b': 'f',
                                   'c': 'e',
                                   'd': 'a',
                                   'e': 'c',
                                   'f': 'b',
                                   'g': 'h',
                                   'h': 'g',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'c',
                                   'b': 'g',
                                   'c': 'a',
                                   'd': 'e',
                                   'e': 'd',
                                   'f': 'h',
                                   'g': 'b',
                                   'h': 'f',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'b',
                                   'b': 'a',
                                   'c': 'g',
                                   'd': 'f',
                                   'e': 'h',
                                   'f': 'd',
                                   'g': 'c',
                                   'h': 'e',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'e',
                                   'b': 'h',
                                   'c': 'd',
                                   'd': 'c',
                                   'e': 'a',
                                   'f': 'g',
                                   'g': 'f',
                                   'h': 'b',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'f',
                                   'b': 'd',
                                   'c': 'h',
                                   'd': 'b',
                                   'e': 'g',
                                   'f': 'a',
                                   'g': 'e',
                                   'h': 'c',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'g',
                                   'b': 'c',
                                   'c': 'b',
                                   'd': 'h',
                                   'e': 'f',
                                   'f': 'e',
                                   'g': 'a',
                                   'h': 'd',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'h',
                                   'b': 'e',
                                   'c': 'f',
                                   'd': 'g',
                                   'e': 'b',
                                   'f': 'c',
                                   'g': 'd',
                                   'h': 'a',
                                   'i': 'i'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    3: [   {   'permutations': {   'a': 'c',
                                   'b': 'd',
                                   'c': 'a',
                                   'd': 'b',
                                   'e': 'e'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'b',
                                   'b': 'a',
                                   'c': 'd',
                                   'd': 'c',
                                   'e': 'e'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'd',
                                   'b': 'c',
                                   'c': 'b',
                                   'd': 'a',
                                   'e': 'e'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    4: [   {   'permutations': {'a': 'a'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    5: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    6: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    7: [   {   'permutations': {'a': 'a'},
               'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    10: [   {   'permutations': {   'a': 'd',
                                    'b': 'e',
                                    'c': 'g',
                                    'd': 'a',
                                    'e': 'b',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'g',
                                    'e': 'h',
                                    'f': 'b',
                                    'g': 'd',
                                    'h': 'e',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'd',
                                    'c': 'h',
                                    'd': 'b',
                                    'e': 'a',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'c',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'h',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'h',
                                    'e': 'g',
                                    'f': 'a',
                                    'g': 'e',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'g',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    11: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    12: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    13: [   {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    14: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    15: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    16: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'e',
                                    'c': 'a',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'h',
                                    'g': 'd',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r',
                                    's': 's',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'd',
                                    'c': 'h',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'a',
                                    'g': 'e',
                                    'h': 'c',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'h',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'e',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'g',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'd',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'e',
                                    'c': 'g',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'b',
                                    'g': 'd',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'e',
                                    'c': 'a',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'h',
                                    'g': 'd',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'e',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'd',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'd',
                                    'c': 'h',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'a',
                                    'g': 'e',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'h',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'e',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'e',
                                    'c': 'f',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'c',
                                    'g': 'd',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'd',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'f',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'e',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'f',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'd',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'e',
                                    'c': 'f',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'c',
                                    'g': 'd',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'e',
                                    'c': 'g',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'b',
                                    'g': 'd',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'c',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'g',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    17: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.5 ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.5 ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.5 ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.5 ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    18: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    19: [   {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    20: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    21: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    22: [   {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'j',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'j',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'e',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'j',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'j',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'e',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'i',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'i',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'i',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'f',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'i',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'i',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'f',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'j',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    23: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    24: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    25: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    26: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    27: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    28: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    29: [   {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    30: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    31: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    32: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    33: [   {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    34: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    35: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    36: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    37: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    38: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    39: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    40: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    41: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    42: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    43: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  , -0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    44: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    45: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    46: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    47: [   {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r',
                                    's': 's',
                                    't': 't',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'e',
                                    'c': 'h',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'a',
                                    'g': 'd',
                                    'h': 'c',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'h',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'a',
                                    'b': 'c',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'd',
                                    'c': 'f',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'c',
                                    'g': 'e',
                                    'h': 'g',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'd',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'e',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'e',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'f',
                                    'g': 'd',
                                    'h': 'b',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'f',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'a',
                                    'b': 'e',
                                    'c': 'b',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'g',
                                    'g': 'd',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'd',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'g',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'e',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'd',
                                    'c': 'g',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'b',
                                    'g': 'e',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    48: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    49: [   {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    50: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    51: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    52: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    53: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    54: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    55: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    56: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    57: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    58: [   {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    59: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    60: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    61: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    62: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    63: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    64: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    65: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'r'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    66: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    67: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    68: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    69: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'g',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'o',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'g',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'o',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    70: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'h'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'h'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    71: [   {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'l',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'n',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'l',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'n',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'l',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'n',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'l',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'n',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    72: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    73: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'c',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'e',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    74: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    75: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    76: [   {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    77: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    78: [   {   'permutations': {'a': 'a'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    79: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    80: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    81: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    82: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-0.  , -1.  , -0.  , -0.  ],
       [-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    83: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    84: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    85: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    86: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    87: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    88: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    89: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'o',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'l',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'n',
                                    'm': 'o',
                                    'n': 'l',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    90: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    91: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    92: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    93: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'm',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'j',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'l',
                                    'k': 'm',
                                    'l': 'j',
                                    'm': 'k',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    94: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    95: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    96: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    97: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    98: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    99: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    100: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    101: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    102: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    103: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    104: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    105: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    106: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    111: [   {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'l',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'i',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'k',
                                     'j': 'l',
                                     'k': 'i',
                                     'l': 'j',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    112: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'i',
                                     'h': 'j',
                                     'i': 'g',
                                     'j': 'h',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'd',
                                     'c': 'c',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'j',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'g',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'b',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    113: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    114: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    115: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    116: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    117: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    118: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    119: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    120: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'h',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'e',
                                     'i': 'i'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'h',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'e',
                                     'i': 'i'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    121: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    122: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    123: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'n',
                                     'm': 'o',
                                     'n': 'l',
                                     'o': 'm',
                                     'p': 'p',
                                     'q': 'q',
                                     'r': 'r',
                                     's': 't',
                                     't': 's',
                                     'u': 'u'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'o',
                                     'o': 'n',
                                     'p': 'q',
                                     'q': 'p',
                                     'r': 'r',
                                     's': 's',
                                     't': 't',
                                     'u': 'u'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'o',
                                     'm': 'n',
                                     'n': 'm',
                                     'o': 'l',
                                     'p': 'q',
                                     'q': 'p',
                                     'r': 'r',
                                     's': 't',
                                     't': 's',
                                     'u': 'u'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    124: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    125: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    126: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    127: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    128: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    129: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    130: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    131: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'm',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'j',
                                     'n': 'n',
                                     'o': 'p',
                                     'p': 'o',
                                     'q': 'q',
                                     'r': 'r'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'l',
                                     'k': 'm',
                                     'l': 'j',
                                     'm': 'k',
                                     'n': 'n',
                                     'o': 'o',
                                     'p': 'p',
                                     'q': 'q',
                                     'r': 'r'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'p',
                                     'p': 'o',
                                     'q': 'q',
                                     'r': 'r'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    132: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o',
                                     'p': 'p'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o',
                                     'p': 'p'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o',
                                     'p': 'p'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    133: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    134: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    135: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    136: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    137: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    138: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    139: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    140: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    141: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    142: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    143: [   {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    144: [   {   'permutations': {'a': 'a'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    145: [   {   'permutations': {'a': 'a'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    146: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    147: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    148: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    149: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    150: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    151: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    152: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    153: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    154: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    155: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    156: [   {   'permutations': {   'a': 'b',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'a',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'b',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    157: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    158: [   {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    159: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    162: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    163: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    164: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    165: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    166: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    167: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    168: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    169: [   {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    170: [   {   'permutations': {'a': 'a'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    171: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    172: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    173: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    174: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    175: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    176: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    177: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    178: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    179: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    180: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    181: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    182: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    187: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    188: [   {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    189: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    190: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    191: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o',
                                     'p': 'q',
                                     'q': 'p',
                                     'r': 'r'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    192: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    193: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    194: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    195: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'i',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'f',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'i',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'f',
                                     'j': 'j'},
                 'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    196: [   {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    197: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    198: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    199: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    200: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'h',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'e',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    201: [   {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    202: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    203: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    205: [   {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    207: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    208: [   {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    209: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    210: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    212: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    213: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    215: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    216: [   {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    218: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    219: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    221: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    222: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    223: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    224: [   {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    225: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    226: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    227: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    228: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}]}

IMPROPER_RIGID_TRANSFORMATIONS = {   1: [   {   'permutations': {'a': 'a'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    3: [   {   'permutations': {   'a': 'a',
                                   'b': 'b',
                                   'c': 'c',
                                   'd': 'd',
                                   'e': 'e'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
           {   'permutations': {   'a': 'c',
                                   'b': 'd',
                                   'c': 'a',
                                   'd': 'b',
                                   'e': 'e'},
               'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'b',
                                   'b': 'a',
                                   'c': 'd',
                                   'd': 'c',
                                   'e': 'e'},
               'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {   'a': 'd',
                                   'b': 'c',
                                   'c': 'b',
                                   'd': 'a',
                                   'e': 'e'},
               'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    4: [   {   'permutations': {'a': 'a'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    5: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
           {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
               'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    6: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
           {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
               'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    7: [   {   'permutations': {'a': 'a'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
           {   'permutations': {'a': 'a'},
               'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    8: [   {   'permutations': {'a': 'a', 'b': 'b'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    9: [   {   'permutations': {'a': 'a'},
               'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    16: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r',
                                    's': 's',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'e',
                                    'c': 'a',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'h',
                                    'g': 'd',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r',
                                    's': 's',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'd',
                                    'c': 'h',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'a',
                                    'g': 'e',
                                    'h': 'c',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'r',
                                    'r': 'q',
                                    's': 't',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'h',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 's',
                                    'r': 't',
                                    's': 'q',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 't',
                                    'r': 's',
                                    's': 'r',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'e',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'i',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'l',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'g',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'j',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'k',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'd',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'k',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'j',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'e',
                                    'c': 'g',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'b',
                                    'g': 'd',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'l',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'i',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'e',
                                    'c': 'a',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'h',
                                    'g': 'd',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'e',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'd',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'd',
                                    'c': 'h',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'a',
                                    'g': 'e',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'h',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'm',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'p',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'e',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'e',
                                    'c': 'f',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'c',
                                    'g': 'd',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'o',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'd',
                                    'i': 'o',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'n',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'f',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'm',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'e',
                                    'i': 'q',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 't',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'f',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'i',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'l',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 's',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 'r',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'r',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 's',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'j',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'k',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'd',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'k',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'j',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'e',
                                    'c': 'f',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'c',
                                    'g': 'd',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 'q',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'l',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'i',
                                    'u': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 'q',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 't',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'e',
                                    'c': 'g',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'b',
                                    'g': 'd',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'm',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'p',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'f',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'c',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 'r',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 's',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'e',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'o',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'n',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'g',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 's',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 'r',
                                    'q': 'n',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'o',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'h',
                                    'b': 'g',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 't',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'm',
                                    'u': 'u'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    17: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.5 ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.5 ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.5 ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.5 ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    18: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    19: [   {   'permutations': {'a': 'a'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    20: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  ,  0.  ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    21: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    22: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'j',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'j',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'e',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'j',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'j',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'e',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.25],
       [-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. ,  0.5],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'i',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0.  , -0.  , -1.  ,  0.75],
       [-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'i',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'i',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'f',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'j',
                                    'i': 'i',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'i',
                                    'g': 'j',
                                    'h': 'e',
                                    'i': 'f',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'j',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    23: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    24: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                'transformation': array([[-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0., -0., -1., -0.],
       [-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                'transformation': array([[-0. , -0. , -1. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    25: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    26: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    27: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    28: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    29: [   {   'permutations': {'a': 'a'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    30: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    31: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    32: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    33: [   {   'permutations': {'a': 'a'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    34: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    35: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    36: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    37: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    38: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    39: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    40: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    41: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    42: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    43: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  , -0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    44: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    45: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    46: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    47: [   {   'permutations': {   'A': 'A',
                                    'a': 'a',
                                    'b': 'e',
                                    'c': 'c',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'f',
                                    'g': 'd',
                                    'h': 'h',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'a',
                                    'c': 'g',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'b',
                                    'g': 'h',
                                    'h': 'd',
                                    'i': 'm',
                                    'j': 'n',
                                    'k': 'o',
                                    'l': 'p',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'f',
                                    'c': 'd',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'e',
                                    'g': 'c',
                                    'h': 'g',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'i',
                                    'n': 'j',
                                    'o': 'k',
                                    'p': 'l',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'g',
                                    'c': 'a',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'h',
                                    'g': 'b',
                                    'h': 'f',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 'q',
                                    'r': 's',
                                    's': 'r',
                                    't': 't',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'b',
                                    'c': 'h',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'a',
                                    'g': 'g',
                                    'h': 'c',
                                    'i': 'o',
                                    'j': 'p',
                                    'k': 'm',
                                    'l': 'n',
                                    'm': 'k',
                                    'n': 'l',
                                    'o': 'i',
                                    'p': 'j',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'y',
                                    'z': 'z'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'c',
                                    'c': 'e',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'd',
                                    'g': 'f',
                                    'h': 'b',
                                    'i': 'n',
                                    'j': 'm',
                                    'k': 'p',
                                    'l': 'o',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 'r',
                                    'r': 't',
                                    's': 'q',
                                    't': 's',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'u',
                                    'x': 'v',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'h',
                                    'c': 'b',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'g',
                                    'g': 'a',
                                    'h': 'e',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'j',
                                    'n': 'i',
                                    'o': 'l',
                                    'p': 'k',
                                    'q': 's',
                                    'r': 'q',
                                    's': 't',
                                    't': 'r',
                                    'u': 'w',
                                    'v': 'x',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'd',
                                    'c': 'f',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'c',
                                    'g': 'e',
                                    'h': 'a',
                                    'i': 'p',
                                    'j': 'o',
                                    'k': 'n',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'k',
                                    'o': 'j',
                                    'p': 'i',
                                    'q': 't',
                                    'r': 'r',
                                    's': 's',
                                    't': 'q',
                                    'u': 'x',
                                    'v': 'w',
                                    'w': 'v',
                                    'x': 'u',
                                    'y': 'z',
                                    'z': 'y'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'q',
                                    'j': 's',
                                    'k': 'r',
                                    'l': 't',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'g',
                                    'c': 'f',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'c',
                                    'g': 'b',
                                    'h': 'd',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'g',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'i',
                                    'r': 'k',
                                    's': 'j',
                                    't': 'l',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'e',
                                    'c': 'h',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'a',
                                    'g': 'd',
                                    'h': 'b',
                                    'i': 'r',
                                    'j': 't',
                                    'k': 'q',
                                    'l': 's',
                                    'm': 'n',
                                    'n': 'p',
                                    'o': 'm',
                                    'p': 'o',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'u',
                                    'z': 'v'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'e',
                                    'i': 's',
                                    'j': 'q',
                                    'k': 't',
                                    'l': 'r',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'j',
                                    'r': 'l',
                                    's': 'i',
                                    't': 'k',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'w',
                                    'x': 'x',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'h',
                                    'c': 'e',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'd',
                                    'g': 'a',
                                    'h': 'c',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'o',
                                    'n': 'm',
                                    'o': 'p',
                                    'p': 'n',
                                    'q': 'k',
                                    'r': 'i',
                                    's': 'l',
                                    't': 'j',
                                    'u': 'y',
                                    'v': 'z',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'f',
                                    'c': 'g',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'b',
                                    'g': 'c',
                                    'h': 'a',
                                    'i': 't',
                                    'j': 'r',
                                    'k': 's',
                                    'l': 'q',
                                    'm': 'p',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'm',
                                    'q': 'l',
                                    'r': 'j',
                                    's': 'k',
                                    't': 'i',
                                    'u': 'z',
                                    'v': 'y',
                                    'w': 'x',
                                    'x': 'w',
                                    'y': 'v',
                                    'z': 'u'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'c',
                                    'b': 'd',
                                    'c': 'g',
                                    'd': 'h',
                                    'e': 'a',
                                    'f': 'b',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 'q',
                                    'n': 'r',
                                    'o': 's',
                                    'p': 't',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'e',
                                    'b': 'f',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'c',
                                    'h': 'd',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'm',
                                    'r': 'n',
                                    's': 'o',
                                    't': 'p',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'd',
                                    'b': 'c',
                                    'c': 'h',
                                    'd': 'g',
                                    'e': 'b',
                                    'f': 'a',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'k',
                                    'm': 's',
                                    'n': 't',
                                    'o': 'q',
                                    'p': 'r',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'w',
                                    'z': 'x'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'f',
                                    'b': 'e',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'd',
                                    'h': 'c',
                                    'i': 'k',
                                    'j': 'i',
                                    'k': 'l',
                                    'l': 'j',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'o',
                                    'r': 'p',
                                    's': 'm',
                                    't': 'n',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'y',
                                    'x': 'z',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'g',
                                    'b': 'h',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'a',
                                    'h': 'b',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 'r',
                                    'n': 'q',
                                    'o': 't',
                                    'p': 's',
                                    'q': 'n',
                                    'r': 'm',
                                    's': 'p',
                                    't': 'o',
                                    'u': 'u',
                                    'v': 'v',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'A': 'A',
                                    'a': 'h',
                                    'b': 'g',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'b',
                                    'h': 'a',
                                    'i': 'l',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'i',
                                    'm': 't',
                                    'n': 's',
                                    'o': 'r',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'o',
                                    's': 'n',
                                    't': 'm',
                                    'u': 'v',
                                    'v': 'u',
                                    'w': 'z',
                                    'x': 'y',
                                    'y': 'x',
                                    'z': 'w'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    48: [   {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'l',
                                    'h': 'k',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'h',
                                    'l': 'g',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'k',
                                    'h': 'l',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'g',
                                    'l': 'h',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    49: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'g',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'p',
                                    'p': 'o',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'e',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'g',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'f',
                                    'i': 'k',
                                    'j': 'l',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'o',
                                    'n': 'p',
                                    'o': 'n',
                                    'p': 'm',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'g',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'i',
                                    'l': 'j',
                                    'm': 'p',
                                    'n': 'o',
                                    'o': 'm',
                                    'p': 'n',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'e',
                                    'i': 'l',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'i',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    50: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    55: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    56: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    58: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    59: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    65: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p',
                                    'q': 'q',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'q',
                                    'q': 'p',
                                    'r': 'r'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    66: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    67: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'g',
                                    'h': 'j',
                                    'i': 'k',
                                    'j': 'h',
                                    'k': 'i',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  ,  0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'f',
                                    'e': 'c',
                                    'f': 'd',
                                    'g': 'g',
                                    'h': 'j',
                                    'i': 'k',
                                    'j': 'h',
                                    'k': 'i',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  ,  0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'g',
                                    'h': 'k',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'h',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.5 ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'f',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'c',
                                    'g': 'g',
                                    'h': 'k',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'h',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.5 ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    68: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  ,  0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  ,  0.  ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.5 ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.5 ],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    69: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'h',
                                    'i': 'g',
                                    'j': 'l',
                                    'k': 'k',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'n',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'h',
                                    'i': 'g',
                                    'j': 'l',
                                    'k': 'k',
                                    'l': 'j',
                                    'm': 'o',
                                    'n': 'n',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    70: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'h'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'f',
                                    'g': 'e',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    71: [   {   'permutations': {   'a': 'a',
                                    'b': 'd',
                                    'c': 'c',
                                    'd': 'b',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'd',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'm',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  1.,  0.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'a',
                                    'c': 'b',
                                    'd': 'c',
                                    'e': 'g',
                                    'f': 'h',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'b',
                                    'e': 'i',
                                    'f': 'j',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'm',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'c',
                                    'c': 'd',
                                    'd': 'a',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'e',
                                    'h': 'f',
                                    'i': 'j',
                                    'j': 'i',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'a',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'f',
                                    'j': 'e',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'm',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'i',
                                    'h': 'j',
                                    'i': 'h',
                                    'j': 'g',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'b',
                                    'c': 'a',
                                    'd': 'd',
                                    'e': 'h',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'e',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'n',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'c',
                                    'e': 'j',
                                    'f': 'i',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'e',
                                    'j': 'f',
                                    'k': 'k',
                                    'l': 'n',
                                    'm': 'm',
                                    'n': 'l',
                                    'o': 'o'},
                'transformation': array([[ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'j',
                                    'h': 'i',
                                    'i': 'g',
                                    'j': 'h',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'o'},
                'transformation': array([[ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  1. ,  0. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    72: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    73: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'e',
                                    'd': 'd',
                                    'e': 'c',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f'},
                'transformation': array([[ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  1.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    74: [   {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'g',
                                    'g': 'f',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    75: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    77: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    79: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    80: [   {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {'a': 'a', 'b': 'b'},
                'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. ,  0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    81: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    82: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[ 0.  ,  1.  ,  0.  ,  0.  ],
       [ 1.  ,  0.  ,  0.  , -0.5 ],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    83: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'l'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    84: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    85: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    86: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. ,  0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    87: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i'},
                'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    88: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f'},
                'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    89: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'c',
                                    'b': 'd',
                                    'c': 'a',
                                    'd': 'b',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'o',
                                    'm': 'n',
                                    'n': 'm',
                                    'o': 'l',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'n',
                                    'm': 'o',
                                    'n': 'l',
                                    'o': 'm',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'd',
                                    'b': 'c',
                                    'c': 'b',
                                    'd': 'a',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    90: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    93: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k',
                                    'l': 'l',
                                    'm': 'm',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'm',
                                    'k': 'l',
                                    'l': 'k',
                                    'm': 'j',
                                    'n': 'o',
                                    'o': 'n',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'd',
                                    'd': 'c',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'l',
                                    'k': 'm',
                                    'l': 'j',
                                    'm': 'k',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'h',
                                    'h': 'g',
                                    'i': 'i',
                                    'j': 'k',
                                    'k': 'j',
                                    'l': 'm',
                                    'm': 'l',
                                    'n': 'n',
                                    'o': 'o',
                                    'p': 'p'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    94: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    97: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'h',
                                    'i': 'i',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g',
                                    'h': 'i',
                                    'i': 'h',
                                    'j': 'j',
                                    'k': 'k'},
                'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    98: [   {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
            {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'e',
                                    'e': 'd',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    99: [   {   'permutations': {   'a': 'a',
                                    'b': 'b',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'e',
                                    'f': 'f',
                                    'g': 'g'},
                'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
            {   'permutations': {   'a': 'b',
                                    'b': 'a',
                                    'c': 'c',
                                    'd': 'd',
                                    'e': 'f',
                                    'f': 'e',
                                    'g': 'g'},
                'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    100: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    101: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    102: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    103: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    104: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    105: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    106: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    107: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    108: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    109: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    110: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    111: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'l',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'i',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'k',
                                     'j': 'l',
                                     'k': 'i',
                                     'l': 'j',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    112: [   {   'permutations': {   'a': 'a',
                                     'b': 'd',
                                     'c': 'c',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'j',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'g',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'b',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'i',
                                     'h': 'j',
                                     'i': 'g',
                                     'j': 'h',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    113: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    114: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    115: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    116: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    117: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    118: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. , -0. ],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    119: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    120: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'h',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'e',
                                     'i': 'i'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'h',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'e',
                                     'i': 'i'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    121: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    122: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.5 ],
       [-0.  , -1.  , -0.  , -0.  ],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    143: [   {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.33333333],
       [-1.        , -0.        , -0.        ,  0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-0.        , -1.        , -0.        ,  0.66666667],
       [-1.        , -0.        , -0.        ,  0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    146: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    147: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    148: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-0., -1., -0., -0.],
       [-1., -0., -0., -0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[-0. , -1. , -0. , -0. ],
       [-1. , -0. , -0. , -0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    149: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'h',
                                     'h': 'i',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'i',
                                     'h': 'g',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    150: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g'},
                 'transformation': array([[ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  1. ,  0. ,  0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    155: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'f'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    156: [   {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'b',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'a',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    157: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    158: [   {   'permutations': {'a': 'a', 'b': 'c', 'c': 'b', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'c', 'b': 'b', 'c': 'a', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'b', 'b': 'a', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'b', 'b': 'c', 'c': 'a', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  1.        ,  0.        , -0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {'a': 'c', 'b': 'a', 'c': 'b', 'd': 'd'},
                 'transformation': array([[ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  1.        ,  0.        , -0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    159: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 1.,  0.,  0.,  0.],
       [ 0.,  1.,  0.,  0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    160: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    161: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    168: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    173: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    174: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        ,  0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.33333333],
       [ 1.        ,  0.        ,  0.        , -0.66666667],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 0.        ,  1.        ,  0.        , -0.66666667],
       [ 1.        ,  0.        ,  0.        , -0.33333333],
       [ 0.        ,  0.        ,  1.        , -0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    175: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    176: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 0. ,  1. ,  0. ,  0. ],
       [ 1. ,  0. ,  0. ,  0. ],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    177: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    182: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    183: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    184: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    185: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    186: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c', 'd': 'd'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    187: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'f',
                                     'd': 'e',
                                     'e': 'd',
                                     'f': 'c',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'f',
                                     'b': 'e',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'b',
                                     'f': 'a',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'm',
                                     'm': 'l',
                                     'n': 'n',
                                     'o': 'o'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    188: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        , -0.        ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'e',
                                     'd': 'f',
                                     'e': 'c',
                                     'f': 'd',
                                     'g': 'g',
                                     'h': 'i',
                                     'i': 'h',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'e',
                                     'b': 'f',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'a',
                                     'f': 'b',
                                     'g': 'i',
                                     'h': 'h',
                                     'i': 'g',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.66666667],
       [-0.        , -1.        , -0.        ,  0.33333333],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1.        , -0.        , -0.        ,  0.33333333],
       [-0.        , -1.        , -0.        ,  0.66666667],
       [-0.        , -0.        , -1.        ,  0.5       ],
       [ 0.        ,  0.        ,  0.        ,  1.        ]])}],
    189: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    190: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. , -0. ],
       [-0. , -1. , -0. , -0. ],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    195: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'i',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'f',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'i',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'f',
                                     'j': 'j'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    196: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    197: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    198: [   {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {'a': 'a', 'b': 'b'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.75],
       [ 1.  ,  0.  ,  0.  , -0.75],
       [ 0.  ,  0.  ,  1.  , -0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    199: [   {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {'a': 'a', 'b': 'b', 'c': 'c'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    200: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k',
                                     'l': 'l'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'h',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'e',
                                     'i': 'i',
                                     'j': 'k',
                                     'k': 'j',
                                     'l': 'l'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    201: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    202: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    203: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g'},
                 'transformation': array([[ 0. ,  1. ,  0. , -0.5],
       [ 1. ,  0. ,  0. , -0.5],
       [ 0. ,  0. ,  1. , -0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    204: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[ 0.,  1.,  0.,  0.],
       [ 1.,  0.,  0.,  0.],
       [ 0.,  0.,  1.,  0.],
       [ 0.,  0.,  0.,  1.]])}],
    206: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[ 0.  ,  1.  ,  0.  , -0.25],
       [ 1.  ,  0.  ,  0.  , -0.25],
       [ 0.  ,  0.  ,  1.  , -0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    207: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'k'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    208: [   {   'permutations': {   'a': 'a',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j',
                                     'k': 'l',
                                     'l': 'k',
                                     'm': 'm'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'f',
                                     'f': 'e',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'j',
                                     'j': 'i',
                                     'k': 'k',
                                     'l': 'l',
                                     'm': 'm'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    209: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    210: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    211: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    214: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    215: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i',
                                     'j': 'j'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    216: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'c',
                                     'b': 'd',
                                     'c': 'a',
                                     'd': 'b',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'd',
                                     'b': 'c',
                                     'c': 'b',
                                     'd': 'a',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    217: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}],
    218: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h',
                                     'i': 'i'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'h',
                                     'h': 'g',
                                     'i': 'i'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])}],
    219: [   {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.25],
       [-0.  , -1.  , -0.  ,  0.25],
       [-0.  , -0.  , -1.  ,  0.25],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])},
             {   'permutations': {   'a': 'a',
                                     'b': 'b',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e',
                                     'f': 'f',
                                     'g': 'g',
                                     'h': 'h'},
                 'transformation': array([[-1. , -0. , -0. ,  0.5],
       [-0. , -1. , -0. ,  0.5],
       [-0. , -0. , -1. ,  0.5],
       [ 0. ,  0. ,  0. ,  1. ]])},
             {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'd',
                                     'd': 'c',
                                     'e': 'e',
                                     'f': 'g',
                                     'g': 'f',
                                     'h': 'h'},
                 'transformation': array([[-1.  , -0.  , -0.  ,  0.75],
       [-0.  , -1.  , -0.  ,  0.75],
       [-0.  , -0.  , -1.  ,  0.75],
       [ 0.  ,  0.  ,  0.  ,  1.  ]])}],
    220: [   {   'permutations': {   'a': 'b',
                                     'b': 'a',
                                     'c': 'c',
                                     'd': 'd',
                                     'e': 'e'},
                 'transformation': array([[-1., -0., -0., -0.],
       [-0., -1., -0., -0.],
       [-0., -0., -1., -0.],
       [ 0.,  0.,  0.,  1.]])}]}
